#ifndef ARTIST_H
#define ARTIST_H

#include "Item.h"

namespace Ovi {

class SearchRequest;

/*!
 * \class Artist
 *
 * \brief A class that represents an artist.
 */
class OVIMUSICAPISHARED_EXPORT Artist : public Item
{
    friend class ItemFactory;

    Q_OBJECT

public:
    /*!
     * Get a list of releases by this artist.  The search is performed using the categories, orderBy 
     * and sortOrder properties of the request.  Other request properties are ignored.
     */
    Q_INVOKABLE StoreItemList* releases(Ovi::SearchRequest *request) const;

    /*!
     * Get a list of other recommended artists for this artist.
     */
    Q_INVOKABLE StoreItemList* recommendedArtists() const;

    /*!
     * Get a list of top albums by this artist.
     */
    Q_INVOKABLE StoreItemList* topAlbums() const;

    /*!
     * Get a list of top tracks by this artist.
     */
    Q_INVOKABLE StoreItemList* topTracks() const;
    
    virtual QString artistId() const;
    virtual QString artistName() const;

protected:
    Artist(const QSharedPointer<ICallBuilderFactory> &callFactory, const Account* account, const QVariantMap& properties);
};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::Artist*)

#endif // ARTIST_H
