#ifndef AUTHENTICATIONINFO_H
#define AUTHENTICATIONINFO_H

#include "OviMusicExport.h"
#include <QString>
#include <QSharedDataPointer>

namespace Ovi
{
    class IAuthentication;
    class AuthenticationInfoPrivate;

    /// \class AuthenticationInfo
    /// \brief Container for information related to authentication passed from the client application.
    class OVIMUSICAPISHARED_EXPORT AuthenticationInfo
    {
    public:
        enum DeviceType
        {
            Unknown = 0,
            Pc = 1,
            Mc = 2
        };

        /// \param publicToken The token sent to Ovi's public API in non-secure calls.
        AuthenticationInfo(const QString &publicToken);
        /// \param publicAccessToken The token sent to Ovi's public API in non-secure calls.
        /// \param consumerKey The consumer key, used in OAuth requests to Ovi's Secure Public Api.
        /// \param authProvider The chosen implementation to provide authentication sevices such as getting the
        AuthenticationInfo(const QString &publicAccessToken, const QString &consumerKey, IAuthentication* authProvider);
        AuthenticationInfo(const AuthenticationInfo& authInfo);
        AuthenticationInfo& operator=(const AuthenticationInfo& other);
        ~AuthenticationInfo();

        /// The token sent to Ovi's public API in non-secure calls.
        QString publicAccessToken() const;
        /// The consumer key, used in OAuth requests to Ovi's Secure Public Api.
        QString secureConsumerKey() const;
        /// The chosen implementation to provide authentication sevices such as getting the
        IAuthentication* authProvider() const;

        void setDevice(const QString &deviceId, DeviceType deviceType);
        QString deviceId() const;
        DeviceType deviceType() const;

    private:
        QSharedDataPointer<AuthenticationInfoPrivate> d;
    };
} // End Ovi namespace

#endif //AUTHENTICATIONINFO_H
