#ifndef CHARTSLIST_H
#define CHARTSLIST_H

#include <QAbstractListModel>

#include "OviMusicExport.h"

namespace Ovi {

class StoreItemList;
class RequestStatus;

/*!
 * \class ChartsList
 *
 * \brief Class which contains a list of available charts for a Store.
 */
class OVIMUSICAPISHARED_EXPORT ChartsList : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(Ovi::RequestStatus * status READ status CONSTANT)

public:
    ~ChartsList();

    enum Roles
    {
        TitleRole = Qt::DisplayRole
    };

    virtual RequestStatus *status() const = 0;

    /*!
     * Get the titles of available charts.
     */
    virtual QStringList chartTitles() const = 0;

    /*!
     * Get a list of items for a given chart title.
     */
    virtual StoreItemList *charts(const QString &title) = 0;

protected:
    ChartsList(QObject *parent=0);
};

} /* end Ovi namespace */

#endif //CHARTSLIST_H
