#ifndef DOWNLOADCOMMAND_H
#define DOWNLOADCOMMAND_H

#include "Command.h"

#include <QScopedPointer>
#include <QUrl>
#include <QMetaType>

namespace Ovi {

class ICallBuilderFactory;
class DownloadRequest;
class DownloadCommandPrivate;
class DownloadResultPrivate;
class PaymentInfo;

/*!
 * \class DownloadResult
 *
 * \brief This class contains the Download command results
 * when the command completes.
 */
class OVIMUSICAPISHARED_EXPORT DownloadResult : public QObject
{
    friend class DownloadCommandPrivate;

    Q_OBJECT

    Q_PROPERTY(QString releaseId READ releaseId CONSTANT)
    Q_PROPERTY(QUrl downloadUri READ downloadUri CONSTANT)
    Q_PROPERTY(QUrl licenseUri READ licenseUri CONSTANT)
    Q_PROPERTY(QString errorSource READ errorSource CONSTANT)
    Q_PROPERTY(QString errorDescription READ errorDescription CONSTANT)

public:
    ~DownloadResult();
    QString releaseId() const;
    QUrl downloadUri() const;
    QUrl licenseUri() const;
    QString errorSource() const;
    QString errorDescription() const;

private:
    DownloadResult(QObject *parent=0);

    QScopedPointer<DownloadResultPrivate> d;
};

/*!
 * \class DownloadCommand
 *
 * \brief Class for executing a download action.
 */
class OVIMUSICAPISHARED_EXPORT DownloadCommand : public Command
{
    Q_OBJECT

    friend class DownloadCommandTest;

    Q_ENUMS(UsageType);

public:
    enum UsageType
    {
        UnknownUsage = 0,
        ALCUsage = 1,
        CWMUsage = 2
    };

    ~DownloadCommand();

    Q_INVOKABLE int count() const;
    Q_INVOKABLE Ovi::DownloadResult * resultAt(int index) const;

    Q_INVOKABLE Ovi::PaymentInfo *paymentInfo() const;

private:    
    DownloadCommand(DownloadCommandPrivate *d);

private:
    Q_DECLARE_PRIVATE(DownloadCommand);
};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::DownloadCommand*)
Q_DECLARE_METATYPE(Ovi::DownloadResult*)
Q_DECLARE_METATYPE(Ovi::DownloadCommand::UsageType)

#endif //DOWNLOADCOMMAND_H
