#ifndef GENRE_H
#define GENRE_H

#include <QObject>
#include <QMetaType>

#include "OviMusicExport.h"

namespace Ovi {

class StoreItemList;

/*!
 * \class Genre
 *
 * Class representing a genre.
 */
class OVIMUSICAPISHARED_EXPORT Genre : public QObject
{
    Q_OBJECT

    Q_PROPERTY( QString id READ id );
    Q_PROPERTY( QString title READ title );

public:
    virtual ~Genre();

    /*!
     * Get the genre id.
     */
    virtual QString id() const = 0;

    /*!
     * Get the genre title.
     */
    virtual QString title() const = 0;

    /*!
     * Get new albums in the genre.
     */
    Q_INVOKABLE virtual Ovi::StoreItemList* newAlbumReleases() const = 0;

    /*!
     * Get new singles in the genre.
     */
    Q_INVOKABLE virtual Ovi::StoreItemList* newSingleReleases() const = 0;

    /*!
     * Get new tracks in the genre.
     */
    Q_INVOKABLE virtual Ovi::StoreItemList* newTrackReleases() const = 0;

    /*!
     * Get top albums in the genre.
     */
    Q_INVOKABLE virtual Ovi::StoreItemList* topAlbums() const = 0;

    /*!
     * Get top tracks in the genre.
     */
    Q_INVOKABLE virtual Ovi::StoreItemList* topTracks() const = 0;

protected:
    Genre(QObject *parent=0);
};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::Genre*)

#endif // GENRE_H
