#ifndef GENRELIST_H
#define GENRELIST_H

#include <QAbstractListModel>
#include <QScopedPointer>

#include "OviMusicExport.h"

namespace Ovi {

class Store;
class Genre;
class RequestStatus;

/*!
 * \class GenreList
 *
 * \brief Model which contains a list of Genre objects.
 *
 * The genre list is obtained by calling Store::genres().
 *
 * The list is populated asynchronously, and is not ready until
 * the finished() signal is emitted.  If an error occurs while
 * retrieving genre information, the error() signal is emitted.
 *
 * You can call isReady() to determine if the list of genres has been 
 * retrieved.
 */
class OVIMUSICAPISHARED_EXPORT GenreList : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(Ovi::RequestStatus* status READ status CONSTANT)

public:
    ~GenreList();

    enum Roles
    {
        TitleRole = Qt::UserRole + 1,
        IdRole = Qt::UserRole + 2,
        GenreRole = Qt::UserRole + 3
    };

    virtual RequestStatus *status() const = 0;

    /*!
     * Get the list of genre objects.
     */
    virtual QList<Genre*> genres() const = 0;

signals:
    void statusChanged(Ovi::RequestStatus *status);

protected:
    GenreList(QObject *parent=0);
};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::GenreList*)

#endif //GENRELIST_H
