#ifndef ITEMLIST_H
#define ITEMLIST_H

#include <QAbstractListModel>

#include "OviMusicExport.h"

namespace Ovi {

class Item;
class ItemListPrivate;

/*!
 * \class ItemList
 *
 * \brief Model which provides a list of Items
 *
 * The available roles are defined in the Roles enum.  They are mapped
 * to role names which are the same as the equivalent properties in Item.
 */
class OVIMUSICAPISHARED_EXPORT ItemList : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(int count READ count NOTIFY updated)

public:
    ItemList(QObject* parent = 0);
    ~ItemList();

    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;

    Q_INVOKABLE int count() const;
    Q_INVOKABLE Item* at(int index);

    /*!
     * \enum Roles
     */
    enum Roles
    {
        NameRole = Qt::UserRole + 1,
        ItemRole = Qt::UserRole + 2
    };

signals:
    void updated(Ovi::ItemList* model);

public:
    Item* operator[](int index);

    typedef QList<Item*>::const_iterator const_iterator;
    const_iterator begin() const;
    const_iterator end() const;

protected:
    QList<Item*>& getItems();
    void appendItems(const QList<Item*> &items);

private:
    QScopedPointer<ItemListPrivate> d;

};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::ItemList*)

#endif // ITEMLIST_H
