#ifndef LOGGING_H
#define LOGGING_H

#include <QDebug>
#include <QWeakPointer>

#include "OviMusicExport.h"

namespace Ovi {
    /*!
     * Interface for creating a QDebug instance to use for logging.
     */
    class ILogOutputFactory
    {
    public:
        virtual ~ILogOutputFactory() {}
        virtual QDebug create() = 0;
    };

    class QDebugLogFactory : public ILogOutputFactory
    {
    public:
        QDebug create() { return qDebug(); }
    };

    class IODeviceLogFactory : public ILogOutputFactory
    {
    public:
        IODeviceLogFactory(QIODevice* device) : device(device){}
        QDebug create() { return QDebug(device.data()); }

    private:
        QWeakPointer<QIODevice> device;
    };


    class OVIMUSICAPISHARED_EXPORT Logger
    {
    public:
        enum Type
        {
            Debug,
            Network
        };

        /*!
         * Get a QDebug object for logging.
         */
        static QDebug log(Type type);

        /*!
         * Set the factory used for log messages with given type.
         */
        static void setFactory(Type type, ILogOutputFactory* factory);
    };


} /* end Ovi namespace */


#endif //LOGGING_H
