#ifndef PLAYLISTS_H
#define PLAYLISTS_H

#include <QAbstractListModel>
#include "OviMusicExport.h"

namespace Ovi {

class RequestStatus;
class StoreItemList;
class GetStreamUrlsCommand;

/*!
 * \class Playlists
 *
 * \brief Model which contains a list of Playlist objects.
 *
 * The playlists are obtained by calling Store::playlists().
 *
 * The list is populated asynchronously, and is not ready until
 * the finished() signal is emitted.  If an error occurs while
 * retrieving playlist information, the error() signal is emitted.
 *
 * You can call isReady() to determine if the list of playlists
 * has been retrieved.
 */
class OVIMUSICAPISHARED_EXPORT Playlists : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(Ovi::RequestStatus * status READ status CONSTANT)

public:
    ~Playlists();

    enum Roles
    {
        TitleRole = Qt::UserRole + 1,
        IdRole = Qt::UserRole + 2,
    };

    virtual RequestStatus *status() const = 0;

    /*!
     * Get the titles of available playlists.
     */
    virtual QStringList playlistTitles() const = 0;

    /*!
     * Get a list of items for a given playlist.
     * \param playlistId Playlist identifier obtained from the IdRole.
     */
    Q_INVOKABLE virtual StoreItemList *getPlaylist(const QString &playlistId) = 0;

    /*!
     * Create a command to get the full-length stream urls for a given playlist.
     */
    Q_INVOKABLE virtual GetStreamUrlsCommand* fullLengthStreamUrls(const QString &playlistId) const = 0;

protected:
    Playlists(QObject* parent=0);
};

} /* end Ovi namespace */

#endif // PLAYLISTS_H
