#ifndef REDEEMCREDITPINCOMMAND_H
#define REDEEMCREDITPINCOMMAND_H

#include "Command.h"

#include <QMetaType>

namespace Ovi {

    class RedeemCreditPinCommandPrivate;

/*!
 * \class RedeemCreditPinCommand
 *
 * \brief Class for executing a redeeming a credit pin action.
 */
class OVIMUSICAPISHARED_EXPORT RedeemCreditPinCommand : public Command
{
    Q_OBJECT

    Q_ENUMS(CommerceError)

    Q_PROPERTY(double creditBalance READ creditBalance NOTIFY creditBalanceChanged)
    Q_PROPERTY(Ovi::RedeemCreditPinCommand::CommerceError commerceError READ commerceError)

public:
    ~RedeemCreditPinCommand();

    /*!
     * Credit balance.
     */
    Q_INVOKABLE double creditBalance() const;

    /*!
     * \enum CommerceError
     *
     * Indicates error conditions which may occur from the commerce command.
     */
    enum CommerceError
    {
        NoCommerceError, /*!< No error condition. */
        InvalidPinError, /*! Pin code is invalid. */
        PinNotActiveError, /*! Promotion associated with pin is not active. */
        ExpiredPinError, /*! Promotion associated with pin has expired. */
        IncorrectTerritoryPinError, /*! Pin is associated with different territory. */
        AlreadyRedeedemPinError, /*! Pin has already been redeemed. */
        AlreadyRedeedemByYouPinError, /*! Pin has already been redeemed by this user. */
        PinRedemptionLimitMetError, /*! Pin has already been redeemed maximum amount of times. */
        PinWrongOfferingTypeError, /*! Promotion associated with pin is of wrong type. */
        InvalidLicenseError, /*! Pin promotion does not match LPG license. */
        UnknownDeviceIdError, /*! IMEI not found in LPG. */
        BlackListedError, /*! Device is blacklisted. */
        InvalidPublicIdError, /*! Device's public id doesn't match requested public id. */
        DeviceWrongOfferingTypeError, /*! Device has no unredeedem licenses of the specified offering types. */
        LicensesNotActiveError, /*! Associated promition are not active at the time. */
        IncorrectTerritoryError /*! Device license is associated with a different territory. */
    };

    /*!
     * Get the error that occurred during the commerce request.  If no error occurred, returns NoError.
     */
    Ovi::RedeemCreditPinCommand::CommerceError commerceError() const;

signals:
    void creditBalanceChanged();

private:
    RedeemCreditPinCommand(RedeemCreditPinCommandPrivate *d);

private:
    Q_DECLARE_PRIVATE(RedeemCreditPinCommand);
};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::RedeemCreditPinCommand*)
Q_DECLARE_METATYPE(Ovi::RedeemCreditPinCommand::CommerceError)

#endif // REDEEMCREDITPINCOMMAND_H
