#ifndef REQUESTSTATUS_H
#define REQUESTSTATUS_H

#include "OviMusicExport.h"
#include <QObject>
#include <QNetworkReply>
#include <QMetaType>
#include <QScopedPointer>

namespace Ovi {

class RequestStatusPrivate;

/*!
 * \class RequestStatus
 *
 * \brief Class encapsulating the status of calls to the Public API
 */
class OVIMUSICAPISHARED_EXPORT RequestStatus : public QObject
{
    Q_OBJECT

    Q_ENUMS(Status)
    Q_ENUMS(QNetworkReply::NetworkError)

    Q_PROPERTY(Ovi::RequestStatus::Status status READ status NOTIFY changed)
    Q_PROPERTY(QNetworkReply::NetworkError networkError READ networkError NOTIFY changed)

public:
    /*!
     * \enum Status
     *
     * Flags for the current state of a request.
     */
    enum Status
    {
        Idle = 0, /*!< The request has not yet been executed. */
        Running = 1, /*!< The request is running and waiting for a response. */
        Success = 2, /*!< The request was successful. */
        NetworkError = 3, /*!< There was a network error. */
        DataError = 4, /*! Could not parse the retrieved data. */
        RequestError = 5, /*! Could not process the request. */
        PermissionError = 6, /*! User is concurrently logged in. */
        UnknownError = 7 /*! There was an unspecified error. */
    };

    RequestStatus(QObject *parent=0);
    ~RequestStatus();

    /*!
     * Get the current status.
     */
    Status status() const;

    /*!
     * Get the network error code in the case that status is NetworkError.
     */
    QNetworkReply::NetworkError networkError() const;

    /*!
     * Get if there was an error.  True if status is NetworkError or UnknownError.
     */
    bool hasError() const;

    void update(Status status);
    void update(QNetworkReply::NetworkError error);

signals:
    void changed(Ovi::RequestStatus::Status status);

private:
    QScopedPointer<RequestStatusPrivate> d;
};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::RequestStatus*)
Q_DECLARE_METATYPE(Ovi::RequestStatus::Status)

#endif //REQUESTSTATUS_H
