#ifndef STOREFACTORY_H
#define STOREFACTORY_H

#include <QObject>
#include <QScopedPointer>

#include "OviMusicExport.h"

#include "AuthenticationInfo.h"

class QNetworkAccessManager;

namespace Ovi {

class ICallBuilderFactory;
class Store;
class StoreInfoList;
class StoreFactoryPrivate;
class StoreInfo;

/*!
 * \brief Creates territory-specific Store instances
 */
class OVIMUSICAPISHARED_EXPORT StoreFactory : public QObject
{
    friend class StoreFactoryTest;
    friend class StoreTest;

    Q_OBJECT

public:
    StoreFactory(const AuthenticationInfo& auth, QObject* parent = 0);
    StoreFactory(const AuthenticationInfo& auth, const QString& storeHost, QObject* parent = 0);
    ~StoreFactory();

    QNetworkAccessManager& networkAccessManager() const;
    void setNetworkAccessManager(QNetworkAccessManager& nam);

    Store* getIpMappedStore(QObject *parent=0) const;
    Store* getStoreForTerritory(const QString& isoCountryCode, QObject *parent=0) const;
    Store* getStoreForMobileCountryCode(int mobileCountryCode, QObject *parent=0) const;

    StoreInfoList *getStores();
    Store *getStore(const StoreInfo &info, QObject *parent=0);

private:
    void setCallBuilderFactory(ICallBuilderFactory* factory);

private:
    QScopedPointer<StoreFactoryPrivate> d;
};

} /* end Ovi namespace */

#endif // STOREFACTORY_H
