#ifndef STOREITEMLIST_H
#define STOREITEMLIST_H

#include <QScopedPointer>
#include <QSharedPointer>
#include "ItemList.h"

namespace Ovi {

class ICallBuilderFactory;
class ICallBuilder;
class StoreItemListPrivate;
class RequestStatus;
class Account;

/*!
 * \class StoreItemList
 *
 * \brief Model which provides a list of Items from the store.
 *
 * Retrieves items a page at a time using the itemsPerPage setting
 * used to create the list.
 *
 * More items can be retrieved using getMore().
 */
class OVIMUSICAPISHARED_EXPORT StoreItemList : public ItemList
{
    friend class StoreImpl;
    friend class StoreItemListPrivate;

    Q_OBJECT

    Q_PROPERTY(int availableCount READ availableCount)
    Q_PROPERTY(QString searchSuggestion READ searchSuggestion)    
    Q_PROPERTY(Ovi::RequestStatus * status READ status CONSTANT)

public:
    StoreItemList(const QSharedPointer<ICallBuilderFactory> &callFactory, ICallBuilder* source, const Account* account, QObject* parent = 0);
    ~StoreItemList();

    RequestStatus *status() const;

public:
    /*!
     * Get the total number of available items.
     */
    Q_INVOKABLE int availableCount() const;

    /*!
     * Get the suggested search term if one is available.
     */
    Q_INVOKABLE QString searchSuggestion() const;

    /*!
     * Retrieve another page of items and add them to the list.
     *
     * The \a status is updated as the request for more items is executed. 
     */
    Q_INVOKABLE bool getMore();

private:
    StoreItemList(QObject* parent = 0);
    Q_DISABLE_COPY(StoreItemList);

    QScopedPointer<StoreItemListPrivate> d;
};

} /* end Ovi namespace */

Q_DECLARE_METATYPE(Ovi::StoreItemList*)

#endif // STOREITEMLIST_H
