#ifndef SUBSCRIPTIONS_H
#define SUBSCRIPTIONS_H

#include <QAbstractListModel>
#include "OviMusicExport.h"

namespace Ovi {

class RequestStatus;
class StoreItemList;

/*!
 * \class Subscriptions
 *
 * \brief Model which contains a list of subscription objects.
 *
 * The subscriptions are obtained by calling Store::subscriptions().
 *
 * The list is populated asynchronously, and is not ready until
 * the finished() signal is emitted.  If an error occurs while
 * retrieving subscription information, the error() signal is emitted.
 *
 * You can call isReady() to determine if the list of subscriptions
 * has been retrieved.
 */
class OVIMUSICAPISHARED_EXPORT Subscriptions : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(Ovi::RequestStatus * status READ status CONSTANT)

public:
    ~Subscriptions();

    enum Roles
    {
        TitleRole = Qt::UserRole + 1,
        IdRole = Qt::UserRole + 2,
        PriceRole = Qt::UserRole + 3,
        ValueRole = Qt::UserRole + 4,
        TypeRole = Qt::UserRole + 5
    };

    virtual RequestStatus *status() const = 0;

    /*!
     * Get the titles of available subscriptions.
     */
    virtual QStringList subscriptionTitles() const = 0;

protected:
    Subscriptions(QObject* parent=0);
};

} /* end Ovi namespace */

#endif // SUBSCRIPTIONS_H
