//.pragma library

Qt.include("settings.js");
Qt.include("xhr.js");
Qt.include("dataUtils.js");
Qt.include("uri.js");
Qt.include("lookupTables.js");

function loadGSD (URI, targetModel, callBack, errorBack) {

    var i, successCB, gsdOptions, a, translatedText;

    successCB = function (responseObject) {

        var numItems = responseObject.workspace.length, storeConfig;

        if(typeof(targetModel) !== 'undefined') {
            targetModel.clear();
        }

	// cache the master GSD for later use.
	settings.setMasterGSD(responseObject);

        a = responseObject.workspace;

	for (i = 0; i < numItems; i += 1) {
	    translatedText = qsTranslate("TerritoryNames","t[" + a[i].countryCode);
	    a[i].translatedCountry = translatedText;	
	}

        a.sort(sortAlphaByTranslatedCountry);

	for (i = 0; i < numItems; i += 1) {
	    // hide all CWM-only stores
            storeConfig = a[i].settings;
            if (typeof storeConfig.alcEnabled === "string" && storeConfig.alcEnabled === "true") {
                console.log("added alcEnabled store with countryCode: " + a[i].countryCode + "=" + a[i].translatedCountry);
	        targetModel.append(a[i]);
            }
	}

        console.log("loadGSD: loaded");
        callBack(responseObject);
    };

    // use an options object as we would like to ignore the 404
    gsdOptions = {
        headers: {"X": "Overridden"},
        uri: URI,
        ignore404: true // currently ineffective due to the XMLHttpRequest implementation :(
    };

    return xhr.jsonGET(gsdOptions, successCB, errorBack);
}

//Parses and appends a list of products to the model specified in the targetModel argument
function loadProductList (URI, targetModel, callBack, errorBack) {

    var i, successCB;

    successCB = function (responseObject) {
        var numItems = responseObject.items.length, currItem;

        targetModel.clear();

        for (i = 0; i < numItems; i += 1) {
            currItem = responseObject.items[i];
            targetModel.append({
                index: i,
                name: currItem.name,
                type: currItem.type,
                artistName: getValueFromStringOrArray(currItem.artistName),
                artistID: getValueFromStringOrArray(currItem.artistId),
                variousArtists: currItem.variousArtists,
                albumArt100: currItem.albumArt100,
                albumArt200: currItem.albumArt200,
                takenFrom: currItem.takenFrom,
                takenFromID: currItem.takenFromId,
                genre: currItem.genreName,
                genreID: currItem.genreId,
                label: currItem.label,
                dataProductID: currItem.id,
                trackCount: currItem.trackCount,
                durationLength: currItem.duration,
                currencyCode: currItem.priceCurrency,
                price: currItem.priceValue,
                trackUrl: currItem.wmaClip || "",
                streetReleaseDate: currItem.streetReleaseDate,                              
                cwmAvailable: currItem.cwm,
                cwmBitRate: (typeof currItem.cwmMediaInfo === "object") ? currItem.cwmMediaInfo.bitRate : "",
                cwmFormat: (typeof currItem.cwmMediaInfo === "object") ? currItem.cwmMediaInfo.fileType : "",
                alcAvailable: currItem.alc,
                alcBitRate: (typeof currItem.alcMediaInfo === "object") ? currItem.alcMediaInfo.bitRate : "",
                alcFormat: (typeof currItem.alcMediaInfo === "object") ? currItem.alcMediaInfo.fileType : ""
            });
        }
        console.log("Product list loaded");
        callBack(responseObject);
    };

    return xhr.jsonGET(URI, successCB, errorBack);
}

function loadGenreList (URI, targetModel, callBack, errorBack) {
    console.log("genreListURI: " + URI);
    var i, successCB;

    successCB = function (responseObject) {

        var numItems = responseObject.workspace[0].collection.length, a;

        targetModel.clear();

        a = responseObject.workspace[0].collection;

        a.sort(sortAlphaByTitle);

	for (i = 0; i < numItems; i += 1) {
	    console.log("added genre: " + a[i].title + " with id: " + a[i].genreId);	
	    targetModel.append(a[i]);
	}

        console.log("loadGenreList: loaded");
        callBack(responseObject);
    };

    return xhr.jsonGET(URI, successCB, errorBack);
}

function loadSimilarArtists(URI, targetModel, callBack, errorBack) {

    var successCB = function (responseObject) {
        var numItems = responseObject.items.length, currItem, i;

        targetModel.clear();

        for (i = 0; i < numItems; i += 1) {
            currItem = responseObject.items[i];
            targetModel.append({
                index: i,
                artistName: currItem.name,
                artistId: currItem.id
            });
        }
        callBack(responseObject);
    };
    return xhr.jsonGET(URI, successCB, errorBack);
}

