//.pragma library

var settings = settings || (function () {

    var FAIL = "com.nokia.musicstore.settings.FAIL",

    collection = {},

    getCachedValue = function (key) {
        var result = FAIL,
            possible;

        if (collection.hasOwnProperty(key) && typeof collection[key] !== "undefined") {
            result = collection[key];
        }

        return result;
    },
    setCachedValue = function (key, value) {
        
        collection[key] = value; 

        return true;
    },

    clearCache = function () {
        collection = {};
    },

    set = function (key, value) {
        morpheusSettings.set(key, value);
    };

    return {

        FAIL: FAIL,

        // convenience methods
        getPAPI: function () {

            var papi = getCachedValue("papi"), i;

            if (papi === FAIL) {

                papi = {
                    protocol: null,
                    host: null,
                    version: null,
                    clientDeviceToken: null
                };
	        for (i in papi) {
                    if (papi.hasOwnProperty(i)) {
	                papi[i] = morpheusSettings.get("ServiceProviders/NokiaMusic/PAPI/" + i);
                    }
                }

                setCachedValue("papi", papi);
            }

	    return papi;
        },

        // convenience methods
        getStoreConfig: function () {

            var storeConfig = getCachedValue("storeConfig"), i;

            if (storeConfig === FAIL) {

                storeConfig = {
                    alcEnabled: null,
                    alcVoucherOnly: null,
                    assetRootUri: null,
                    cwmBrowserEnabled: null,
                    cwmEnabled: null,
                    cwmExtensionGracePeriodDays: null,
                    dateFormatDMY: null,
                    desktopClipUri: null,
                    displayPriceIncludesVAT: null,
                    emailMeOptionCheckedByDefault: null,
                    inclusiveTaxRatePercent: null,
                    maxCwmUnusedDays: null,
                    mobileClipUri: null,
                    mobileCountryDialingCode: null,
                    textMeOptionCheckedByDefault: null,
                    timeZone: null
                };
	        for (i in storeConfig) {
                    if (storeConfig.hasOwnProperty(i)) {
	                storeConfig[i] = morpheusSettings.get("User/NokiaMusic/StoreConfig/" + i);
                    }
                }

                setCachedValue("storeConfig", storeConfig);
            }

	    return storeConfig;
        },

        setStoreConfig: function (storeConfig) {
            var success = false, i;

            if (typeof storeConfig === "object" && storeConfig !== null) {
                console.log("setting storeConfig");
	        for (i in storeConfig) {
                    if (storeConfig.hasOwnProperty(i)) {
	                morpheusSettings.set("User/NokiaMusic/StoreConfig/" + i, storeConfig[i]);
                    }
                }
                success = true;    
            }
            return success;
        },


        getTerritory: function () {
            return morpheusSettings.get("User/territory");
        },
        // need to use specific setter so we emit the territory changed signal
        setTerritory: function (territoryCode) {
            return morpheusSettings.setTerritory(territoryCode); 
        },


	// get/set the store from which the master has been redirected. eg. belarus.
        getRedirectedTerritory: function () {
            return morpheusSettings.get("User/originalTerritory");
        },
        setRedirectedTerritory: function (territoryCode) {
            return morpheusSettings.set("User/originalTerritory", territoryCode); 
        },

        getMasterGSD: function () {
            return morpheusSettings.get("ResourceCache/JSON/masterGSD");
        },
        setMasterGSD: function (masterGSD) {
            return morpheusSettings.set("ResourceCache/JSON/masterGSD", masterGSD); 
        },

        getMCC: function () {
            morpheusSettings.updateSystemInfo();
            return morpheusSettings.get("Device/mcc");
        },


        // TODO tally this with the Qt implementation of settings to restrict any sensitive keys. or remove this generic setter if not needed!
        set: set,


        // resets all settings to "factory" defaults
        reset: function () {
            clearCache();
            return morpheusSettings.reset(); 
        }
    };
}());

