/**
 * Helper method for TrackData.qml to set the current progress.
 */

function trackPlaybackEnded(progress) {
    return progress == trackItem.cEND_OF_MEDIA;
}

function progressToPercent(progressInMillis, totalTrackLengthInMillis) {
    return progressInMillis / totalTrackLengthInMillis * 100;
}

function isInt(assumedNum) {
    return +assumedNum;
}

function getTotalTrackLengthInMillis(optionalTrackLengthInMillis) {
    var maxTrackLengthInMillis = 30000;
    if (isInt(optionalTrackLengthInMillis) &&
        optionalTrackLengthInMillis < maxTrackLengthInMillis &&
        optionalTrackLengthInMillis > 0) {
        return optionalTrackLengthInMillis;
    }
    return maxTrackLengthInMillis;
}

/**
 * Convert milliseconds to a percentage of how much of the currently playing
 * track has already been listened to. Update progress bar value to the percentage.
 *
 * @param progressInMillis int The current progress of the playing track, in milliseconds
 * @param trackLengthInSec int (optional) The total length of the track. If not given, the default will be assumed.
 */
function setProgressBarValue(progressInMillis, trackLengthInSec) {
    if (trackItem.state != "playerVisible") {
        return; //this item's player is not visible, don't update ui
    }
    if (trackPlaybackEnded(progressInMillis)) {
        player.progressBarValue = 0;
        return;
    }
    var trackLengthInMillis = trackLengthInSec * 1000;
    var totalTrackLenghtInMillis = getTotalTrackLengthInMillis(trackLengthInMillis);
    player.progressBarValue = progressToPercent(progressInMillis || 0, totalTrackLenghtInMillis);
}
