.pragma library

var getBaseURI = function () {
    var papi = settings.getPAPI(),
        uri = "";

    uri += papi.protocol + "://";
    uri += papi.host + "/";
    uri += papi.version + "/";

    return uri;
};

var getBaseUriWithPossibleTerritory = function () {
    var territory = settings.getTerritory(),
        uri = getBaseURI();
    if (territory !== settings.FAIL) {
        uri += territory + "/";
    }
    return uri;
};

var getStandardQueryParams = function () {
    var papi = settings.getPAPI(),
        queryStr = "?";

    queryStr += "format=json";
    queryStr += "&token=" + papi.clientDeviceToken;

    return queryStr;
};

// pass in master as true to get the master global service document
var getGSDURI = function (master) {

    var territory,
        uri = getBaseURI() + getStandardQueryParams();

    if (!master) {
        territory = settings.getTerritory();
        if (territory !== settings.FAIL) {
            uri += "&territory=" + territory;
        }
    }
    return uri;
};

var getTopTracksURI = function () {
    return getBaseUriWithPossibleTerritory() +
            getStandardQueryParams() +
            "&category=track" +
            "&orderby=recentdownloads" +
            "&sortorder=descend" +
            "&itemsperpage=20";
};

var getTopAlbumsURI = function () {
    return getBaseUriWithPossibleTerritory() +
            getStandardQueryParams() +
            "&category=album" +
            "&orderby=recentdownloads" +
            "&sortorder=descend" +
            "&itemsperpage=20";
};

var getGenreTopTracksURI = function (genreId) {
    return getBaseUriWithPossibleTerritory() +
            getStandardQueryParams() +
            "&category=track" +
            "&genre=" + genreId +
            "&orderby=recentdownloads" +
            "&sortorder=descend" +
            "&itemsperpage=20";
};

var getGenreTopAlbumsURI = function (genreId) {
    return getBaseUriWithPossibleTerritory() +
            getStandardQueryParams() +
            "&category=album" +
            "&genre=" + genreId +
            "&orderby=recentdownloads" +
            "&sortorder=descend" +
            "&itemsperpage=20";
};

var getGenreListURI = function () {
    return getBaseUriWithPossibleTerritory() +
            "genres/" +
            getStandardQueryParams();
};

var getProductURI = function (productId) {
    return getBaseUriWithPossibleTerritory() +
            "releases/" +
            productId + "/" +
            getStandardQueryParams();
};

var getProductTrackRecommendationsURI = function (productId) {
    return getBaseUriWithPossibleTerritory() +
            "releases/" +
            productId + "/similar/tracks/" +
            getStandardQueryParams() +
            "&itemsperpage=20";
};

var getProductAlbumRecommendationsURI = function (productId) {
    return getBaseUriWithPossibleTerritory() +
            "releases/" +
            productId + "/similar/albums/" +
            getStandardQueryParams() +
            "&itemsperpage=20";
};

var getArtistTopTracksURI = function (artistId) {
    return getBaseUriWithPossibleTerritory() +
            "artists/" +
            artistId + "/" +
            getStandardQueryParams() +
            "&category=track" +
            "&orderby=alltimedownloads" +
            "&sortorder=descend" +
            "&itemsperpage=20";
};

var getArtistSinglesByDateURI = function (artistId) {
    return getBaseUriWithPossibleTerritory() +
            "artists/" +
            artistId + "/" +
            getStandardQueryParams() +
            "&category=single" +
            "&orderby=streetreleasedate" +
            "&sortorder=descend";
};

var getArtistAlbumsByDateURI = function (artistId) {
    return getBaseUriWithPossibleTerritory() +
            "artists/" +
            artistId + "/" +
            getStandardQueryParams() +
            "&category=album" +
            "&orderby=streetreleasedate" +
            "&sortorder=descend";
};

var getSimilarArtistsURI = function (artistId) {
    return getBaseUriWithPossibleTerritory() +
            "artists/" +
            artistId + "/similar/" +
            getStandardQueryParams();
};
