.pragma library // this should be left as .pragma library so it is cached across views.

// core methods for xhr usage. could be moved to a core js file when using more than one API
var xhr = (function () {

    // specify private properties and methods up front
    var defaultOptions, newXHR, parseXHR, sendXHR, jsonGET, xhrCount = 0, xhrObjects = {}, abortAll;

    console.log("Core.xhr initialisation");

    defaultOptions = {
        uri: "",
        method: "GET",
        username: null,
        password: null,
        headers: {"X": "Y"},
        timeoutMillis: 30000, // TODO implement timout handling
        successCallback: function (xhrObj) {
           console.log("newXHR: default xhr success callback received xhrObj: " + xhrObj);
           console.log("WARNING: unable to use response as no successCallback specified!");
        },

        errorCallback: function (message, xhrObj) {
           console.log("newXHR: default xhr error handler received xhrObj: " + xhrObj + " with error message: " + message);
        },
        // "lovely" little hack for the master GSD
        ignore404: false
    };

    // strict constructor for an XHR object.
    // uri not necessary as wil be defaulted to "".
    // successCallback and errorCallback should possibly be mandatory
    // NB. only allows creation of async XHR objects!
    newXHR = function (options) {

       var result = false, i, responseStatus, header, key, val;

       if (typeof options === "object" && typeof options.uri === "string") {

           // add the default headers
           options.headers = options.headers || {};
           for (header in defaultOptions.headers) {
               if (!options.headers.hasOwnProperty(header)) {
                   options.headers[header] = defaultOptions.headers[header];
               }
           }

           // ensure options has expected default values (but still allow overrides)
           for (i in defaultOptions) {
               if (!options.hasOwnProperty(i)) {
                   options[i] = defaultOptions[i];
               } else if (typeof options[i] === "undefined") {
                   options[i] = defaultOptions[i];
               }
           }

           try {

               result = new XMLHttpRequest();

               result.onreadystatechange = function () {
                   var header;

                   if (result.readyState === XMLHttpRequest.DONE) {

                           responseStatus = result.status;

                           // API hack to allow 404 as a success status code!
                           if (responseStatus == 200 || (options.ignore404 === true && responseStatus === 404) ) {
                                   options.successCallback(result);

                           } else {
                                   options.errorCallback("newXHR: result.status was not deemed successful, instead got: " + result.status, result);
                           }
                   }

               };


               result.open(options.method, options.uri, true, options.username, options.password);

               /*
               if (typeof options.headers === "object" && typeof options.headers.length !== "undefined" && options.headers.length > 0) {

                       for (header = 0; header < options.headers.length; header += 1) {
                               key = options.headers[header].key;
                               val = options.headers[header].value;
                               result.setRequestHeader(key, val);
                       }
               }
               */
               // set any http request headers based on incoming options
               for (header in options.headers) {
                       if (typeof options.headers[header] !== "undefined") {
                               result.setRequestHeader(header, options.headers[header]);
                       }
               }

           } catch (e) {
               console.log("ERROR: newXHR: unable to create new XMLHttpRequest and XMLHttpRequest.open, error: " + e);
           }

       } else {
           console.log("newXHR: invalid options received, unable to create XMLHttpRequest");
       }



       return result;
    };

    parseXHR = function (xhrObj) {
        var result = false;

        if (typeof xhrObj === "object" && typeof xhrObj.responseText === "string") {
            try {
                result = JSON.parse(xhrObj.responseText);
            } catch (e) {
                console.log("parseXHR: failed to parse xhrObj, error: " + e);
                if (result.status === 404 && result.responseText.length < 1) {
                    console.log("WARNING: 404 error and empty responseText, possibly caused by XMLHttpRequest implementation");
                }
            }
        } else {
            console.log("parseXHR: invalid xhrObj provided");
        }
        return result;
    };

    sendXHR = function (xhrObj) {
        var result = false;
        if (typeof xhrObj === "object" && typeof xhrObj.send === "function") {

            // TODO put POST code into here
            xhrObj.send(null);

            result = true;
        } else {
            console.log("sendXHR: invalid xhrObj provided");
        }

        return result;
    };

    // primary public method, wraps up all the above
    jsonGET = function (options, successCallback, errorCallback) {

        var xhrOptions, result = false, x;

        // if options is not an object then use it as the uri
        options = (typeof options === "object") ? options : {
            uri: options
        };

        if (typeof options.uri === "string" && typeof successCallback === "function") {
            xhrOptions = {
                uri: options.uri,
                method: "GET",
                headers: options.headers,
                successCallback: function(xhrObj) {

                    var responseObj = parseXHR(xhrObj), key;

                    if (responseObj === false && typeof errorCallback === "function") {
                        errorCallback("error parsing response", xhrObj);
                    } else if (responseObj === false) {
                        defaultOptions.errorCallback("error parsing response", xhrObj);
                    }
                    else {
                        key = xhrObj.key;
                        if (typeof key === "string" && xhrObjects.hasOwnProperty(key) && typeof xhrObj.abort === "function") {
                            xhrObj.abort();
                            xhrObj = null;
                            delete xhrObjects[key];
                        } else {
                            console.log("jsonGET: successCallback unable to abort xhrObj with key " + key);
                        }

                        successCallback(responseObj);
                    }
                },
                errorCallback: errorCallback,
                ignore404: options.ignore404
            };

            x = newXHR(xhrOptions);

            if (x !== false) {

                x.key = "XHR_" + (xhrCount += 1);

                // add the new xhr object to our collection so we can abort/delete all if necessary
                xhrObjects[x.key] = x;

                result = sendXHR(x);
            } else {
                console.log("jsonGET: unable to proceed with no xhr");
            }
        } else {
            console.log("jsonGET: invalid arguments provided. uri must be a string, successCallback must be a function");
        }
        console.log("jsonGET: returning " + result + " with uri: " + options.uri);

        // this just proves that the xhr namespace is created once and once only
        console.log("jsonGET: xhrCount = " + xhrCount);

        return result;
    };

    abortAll = function () {
        var key, obj;
        console.log("abortAll: attempting to abort and delete all current xhr objects");
        for (key in xhrObjects) {
            if (typeof xhrObjects[key] === "object") {
                obj = xhrObjects[key];

                // this property can be used to determine the reason for the error callback when it is fired on abort()
                obj.aborted = true;

                if (typeof obj.abort === "function") {
                    obj.abort();
                    console.log("abortAll: aborted and deleted " + key);
                } else {
                    console.log("abortAll: expected xhr object " + key + " doesn't have abort property!");
                }
                obj = null;
                delete xhrObjects[key];
            }
        }
    };

    return {
        jsonGET: jsonGET,
        abortAll: abortAll
    };
})();





