import Qt 4.7

import "components"
import "components/asgard"

Page {
    id: accountView
    property string title: "AccountView"

    property bool signedIn: false; //Needs to be bound to accountModel

    property string accountName: "VelvetSkies"; //Temporarily hardcoded for dev purposes
    property string credit: "£25.00"; //Temporarily hardcoded for dev purposes

    objectName: "account"

    Flickable {
        id: scrollPaign
        anchors.fill: parent
        contentWidth: contentItem.childrenRect.width;
        contentHeight: contentItem.childrenRect.height
        flickableDirection: Flickable.VerticalFlick
        clip: true

        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            color: 'transparent'

            GroupHeader {
                id: viewHeader
                text: qsTranslate("AccountView","t[MyStuff");
                headerType: 'headerTwo'
                anchors.top: viewRoot.top
                anchors.topMargin: 16
            }

            Item {
                id: headerItem
                height: 0 //Hidden for pilot
                visible: false //Hidden for pilot
                anchors.top: viewHeader.bottom
                width: parent.width

                M_Button {
                    id: signInBtn

                    visible: !signedIn
                    width: 300
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: qsTranslate("AccountView","t[SignIn");

                    y: 19
                    onClicked: signedIn = !signedIn;
                }


                Item {
                    id: accountInfoDisplay

                    visible: signedIn
                    height: (visible) ? 88 : 0
                    width: parent.width

                    BodyText {
                        id: accountNameDisplay
                        text: qsTranslate("AccountView","t[SignedInAs").arg(accountName);
                        //text: "Signed in as " + accountName
                        width: parent.width
                        anchors.top: accountInfoDisplay.top
                        anchors.topMargin: 10
                        anchors.left: parent.left
                        anchors.leftMargin: 16
                        font.pixelSize: 26
                        font.family: theme.primaryFont
                        font.bold: true
                        color: theme.primaryColor
                        elide: Text.ElideRight
                    }

                    BodyText {
                        id: accountCreditDisplay
                        //text: "Available credit: " + credit
                        text: qsTranslate("AccountView","t[AvailableCredit").arg(credit);
                        width: parent.width
                        anchors.top: accountNameDisplay.bottom
                        anchors.topMargin: 5
                        anchors.left: parent.left
                        anchors.leftMargin: 16
                        font.pixelSize: 22
                        font.family: theme.primaryFont
                        color: theme.secondaryColor
                        elide: Text.ElideRight
                    }

                    Divider {
                        width: parent.width
                        dividerType: 'itemDivider'
                        anchors.bottom: accountInfoDisplay.bottom
                        padding: 0

                    }
                }
            }

            Column {
                id: linksCol
                anchors.top: headerItem.bottom
                width: parent.width

                ListItem {
                    id: activeDownloads

                    visible: (signedIn && downloadEngine.totalDownloads > 0)
                    linkText1: qsTranslate("AccountView","t[ActiveDownloads") + ": " + downloadEngine.totalDownloads;
                    onClicked: { downloadEngine.showTransferUi() }
                    width: parent.width
                }

                ListItem {
                    id: redeemPinLink

                    linkText1: qsTranslate("AccountView","t[RedeemVoucher");
                    onClicked: window.nextPage(pinEntryViewComponent, "");
                    width: parent.width
                }

                ListItem {
                    id: accountSettings

                    visible: signedIn
                    linkText1: qsTranslate("AccountView","t[NokiaAccountSettings");
                    onClicked: window.nextPage(notImplementedViewComponent, "");
                    width: parent.width
                }

                ListItem {
                    id: giveFeedbackLink

                    linkText1: qsTranslate("AccountView","t[GiveUsYourFeedback");
                    onClicked: window.nextPage(notImplementedViewComponent, "");
                    width: parent.width
                }

                ListItem {
                    id: supportLink

                    linkText1: qsTranslate("AccountView","t[Support");
                    onClicked: window.nextPage(notImplementedViewComponent, "");
                    width: parent.width
                }

                ListItem { //Needs to be removed for pilot
                    id: debugLink
                    linkText1: "Debug View"
                    onClicked: window.nextPage(debugComponent, "");
                    width: parent.width
                }

            }



        }// end viewRoot
    }// end scrollPaign
}// end page
