import Qt 4.7

import "components"
import "components/asgard"
import "../javascript/APIWrapper.js" as API
import "../javascript/durationConverter.js" as DurationConverter

Page {
    id: artistView
    property string title: "ArtistView"
    objectName: "artist home"
    state: window.state

    property string currentDisplayMode: "Albums";

    //View load states
    property bool primaryReady: false; //Artist tracks request for promo
    property bool secondaryReady: false; //Initially Album list, switches to Singles on interaction
    property bool tertiaryReady: false; //Similar artist results for artists with no results

    function primaryCb () {
        primaryReady = true;
    }

    //404 response should be treated as a successful request with 0 results
    function primaryEb (errorMessage, xhrObj) {
        if (typeof xhrObj == "object" && xhrObj.status == 404) {
            console.log("This artist has no products in this territory");
            primaryReady = true;
            //stop the secondary spinner as there aren't any products
            secondaryReady = true;
            //trigger similar artist fetch
            API.loadSimilarArtists(API.getSimilarArtistsURI(context.artistId), similarArtistsModel, tertiaryCb, tertiaryEb);
        } else {
            window.showError(context.artistName);
        }
    }

    function secondaryCb () {
        secondaryReady = true;
    }

    //404 response should be treated as a successful request with 0 results
    //TODO: ignore error thrown by aborted requests
    function secondaryEb (errorMessage, xhrObj) {
        if (typeof xhrObj == "object" && xhrObj.status == 404) {
            console.log("There were no results in this artist section");
            secondaryReady = true;
        } else if (typeof xhrObj == "object" && xhrObj.status == 0 && xhrObj.aborted) {
            //Request was aborted, so don't throw an error
        } else {
            window.showError(context.artistName);
        }
    }

    function tertiaryCb () {
        tertiaryReady = true;
    }

    function tertiaryEb (errorMessage) {
        console.log("There were no similar artists found");
        console.log(errorMessage);
        tertiaryReady = true;
    }

    //UI variables
    property int tracksHiddenListItems: (window.state == "Portrait" || window.state == "PortraitInverted") ? 3 : 6;
    property int hiddenListItems: (artistListModel.count == 0) ? tracksHiddenListItems : 0;

    //break the binding to the pageStack variable
    Component.onCompleted: context = context;

    ListModel {
        id: artistPromoModel
        Component.onCompleted: {
            API.loadProductList(API.getArtistTopTracksURI(context.artistId), artistPromoModel, primaryCb, primaryEb);
	}
    }

    ListModel {
        id: artistListModel
        Component.onCompleted: {
            API.loadProductList(API.getArtistAlbumsByDateURI(context.artistId), artistListModel, secondaryCb, secondaryEb);
        }
    }

    ListModel {
        id: similarArtistsModel
    }

    Flickable {
        id: scroller
        anchors.fill: parent
        contentWidth: contentItem.childrenRect.width;
        contentHeight: contentItem.childrenRect.height + theme.bottomPadding
        flickableDirection: Flickable.VerticalFlick
        clip: true

        //View header
        GroupHeader {
            id: viewHeader
            headerType: 'headerTwo'
            topMargin: 10
            text: context.artistName
        }

        //Primary load indication
        Item {
            height: (visible) ? window.height : 0
            width: window.width
            visible: !primaryReady

            Spinner {
                id: primarySpinner
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                dimension: 170
                visible: !primaryReady
            }
        }

        //View contents
        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            anchors.top: viewHeader.bottom
            anchors.topMargin: (artistPromoModel.count >= 8) ? 10 : 0
            color: 'transparent'
            visible: primaryReady

            PromoPanel {
                id: viewPromoPanel
                visible: (artistPromoModel.count >= 8) ? true : false
                objectName: "promo master panel"
                model: artistPromoModel
            }

            ListItem {
                id: similarArtistsLink
                anchors.top: (viewPromoPanel.visible == true) ? viewPromoPanel.bottom : viewHeader.bottom
                linkId: context.artistId
                linkText1: qsTranslate("ArtistView","t[SimilarArtists");
                width: parent.width
                onClicked: window.nextPage(similarArtistViewComponent, {artistName: context.artistName, artistId: linkId});
                visible: (artistPromoModel.count > 0 && primaryReady == true) ? true : false
            }

            Grid {
                id: buttonRow
                columns: 3
                spacing: 0
                z: 2
                anchors.top: similarArtistsLink.bottom
                anchors.topMargin: 18
                anchors.horizontalCenter: parent.horizontalCenter
                visible: (artistPromoModel.count < 1 && primaryReady == true) ? false : true
                height: (visible == false) ? 0 : childrenRect.height

                property int buttonWidth: (window.state == "Portrait" || window.state == "PortraitInverted") ? 150 : 200;


                function switchToSongs() {
                    API.xhr.abortAll();
                    secondaryReady = true;
                    currentDisplayMode = "Songs";
                    artistListModel.clear();
                    productsList.model = artistPromoModel;
                }

                function switchToAlbums() {
                    API.xhr.abortAll();
                    secondaryReady = false;
                    currentDisplayMode = "Albums";
                    artistListModel.clear();
                    API.loadProductList(API.getArtistAlbumsByDateURI(context.artistId), artistListModel, secondaryCb, secondaryEb);
                    productsList.model = artistListModel;
                }

                function switchToSingles() {
                    API.xhr.abortAll();
                    secondaryReady = false;
                    currentDisplayMode = "Singles";
                    artistListModel.clear();
                    API.loadProductList(API.getArtistSinglesByDateURI(context.artistId), artistListModel, secondaryCb, secondaryEb);
                    productsList.model = artistListModel;
                }

                M_Button {
                    id: songsBtn
                    text: qsTranslate("ArtistView","t[SongsTab");
                    width: parent.buttonWidth
                    checked: false
                    buttonPos: 'left'
                    onClicked: {
                        if (!checked) {
                            buttonRow.switchToSongs();
                            albumsBtn.checked = false;
                            singlesBtn.checked = false;
                            songsBtn.checked = true;
                        }
                    }
                }

                M_Button {
                    id: albumsBtn
                    text: qsTranslate("ArtistView","t[AlbumsTab");
                    width: parent.buttonWidth
                    checked: true
                    buttonPos: 'middle'
                    onClicked: {
                        if (!checked) {
                            buttonRow.switchToAlbums();
                            albumsBtn.checked = true;
                            singlesBtn.checked = false;
                            songsBtn.checked = false;
                        }
                    }
                }
                M_Button {
                    id: singlesBtn
                    text: qsTranslate("ArtistView","t[SinglesTab");
                    width: parent.buttonWidth
                    checked: false
                    buttonPos: 'right'
                    onClicked: {
                        if (!checked) {
                            buttonRow.switchToSingles();
                            albumsBtn.checked = false;
                            songsBtn.checked = false;
                            singlesBtn.checked = true;
                        }
                    }
                }
            }


            Spinner {
                id: secondarySpinner
                anchors.top: buttonRow.bottom
                anchors.topMargin: (artistView.state === ('Portrait' || 'PortraitInverted')) ? 60 : -20
                z: 0
                anchors.horizontalCenter: parent.horizontalCenter
                dimension: 170
                visible: !secondaryReady
            }

            Column {
                id: productColumn
                anchors.top: buttonRow.bottom
                anchors.topMargin: 12
                height: childrenRect.height
                width: window.width
                visible: (primaryReady == true && artistPromoModel.count > 0) ? true : false //[DF] Note: model count is being used to hide the 'Myleene Klass' bug (Artist with albums but no tracks).

                Repeater {
                    id: productsList
                    model: artistListModel
                    width: productColumn.width

                    ProductLink {
                        id: productLink

                        //cast release date to date format
                        property date releaseDate: streetReleaseDate;

                        visible: (index < hiddenListItems && viewPromoPanel.visible == true) ? false : true
                        height: (visible == false) ? 0 : 116
                        linkText1: name
                        linkText2: Qt.formatDate(releaseDate,"MMMM yyyy");
                        linkText3: (typeof durationLength != "number") ? qsTr("t[TrackCount","",trackCount) : DurationConverter.convert(durationLength)
                        packshotUrl: albumArt100
                        onClicked: window.nextPage(
                                productViewComponent,
                        {
                            name: name,
                            type: type,
                            artistName: artistName,
                            artistID: artistID,
                            variousArtists: variousArtists,
                            albumArt100: albumArt100,
                            albumArt200: albumArt200,
                            takenFrom: takenFrom,
                            takenFromID: takenFromID,
                            genre: genre,
                            genreID: genreID,
                            label: label,
                            dataProductID: dataProductID,
                            trackCount: trackCount,
                            durationLength: durationLength,
                            currencyCode: currencyCode,
                            price: price,
                            trackUrl: trackUrl,
                            streetReleaseDate: streetReleaseDate,
                            cwmAvailable: cwmAvailable,
                            cwmBitRate: cwmBitRate,
                            cwmFormat: cwmFormat,
                            alcAvailable: alcAvailable,
                            alcBitRate: alcBitRate,
                            alcFormat: alcFormat
                        });
                    }
                }
            }

            BodyText {
                id: noCollectionResultsText
                anchors.top: buttonRow.bottom
                anchors.topMargin: 16
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width - 32
                wrapMode: Text.WordWrap
                text: (currentDisplayMode == "Albums") ? qsTranslate("ArtistView","t[NoAlbums") : qsTranslate("ArtistView","t[NoSingles");
                visible: (productsList.model.count < 1 && secondaryReady == true && currentDisplayMode != "Songs" && artistPromoModel.count > 0) ? true : false
            }

            BodyText {
                id: noProductsText
                anchors.top: viewHeader.bottom
                anchors.topMargin: 16
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width - 32
                wrapMode: Text.WordWrap
                text: qsTranslate("ArtistView","t[NoProducts").arg(context.artistName);
                visible: (artistPromoModel.count < 1 && primaryReady == true) ? true : false
            }

            //Similar artist panel (shown only when artist has no products)

            GroupHeader {
                id: similarArtistsHeader
                height: (visible == false) ? 0 : childrenRect.height
                anchors.top: noProductsText.bottom
                anchors.topMargin: 10
                text: qsTranslate("ArtistView","t[SimilarArtists")
                headerType: 'headerThree'
                background: true
                divider: true
                visible: (tertiaryReady == true && similarArtistsModel.count > 0) ? true : false
            }

            ListView {
                id: similarArtistsList
                objectName: "similar artist list"
                visible: (tertiaryReady == true && similarArtistsModel.count > 0) ? true : false
                anchors.top: similarArtistsHeader.bottom
                anchors.topMargin: 3
                width: parent.width
                height: childrenRect.height

                model: similarArtistsModel
                delegate: similarArtistsItem
                interactive: false

                Component {
                    id: similarArtistsItem

                    ListItem {
                        id: similarArtistComponent
                        linkId: artistId
                        linkText1: artistName
                        width: similarArtistsList.width
                        onClicked: window.nextPage(artistViewComponent, {artistName: linkText1, artistId: linkId});
                    }
                }

            }
        }// end viewRoot
    }// end scroller
}// end page
