import Qt 4.7
import "components"
import "components/asgard"
import "../javascript/APIWrapper.js" as API

Page {
    objectName: "debug"

    Flickable {
        id: scroller
        contentWidth: contentItem.childrenRect.width;
        contentHeight: contentItem.childrenRect.height
        flickableDirection: Flickable.VerticalFlick
        clip: true
        anchors.fill: parent

        Rectangle {
            id: viewRoot
            height: childrenRect.height

            GroupHeader {
                id: title
                headerType: 'headerTwo'
                text: "Orientation"
                width: parent.width
                anchors.top: parent.top
            }

            Grid {
                id: orientationbuttons
                columns: 3
                spacing: 10
                anchors.top: title.bottom

                Button {
                    id: forcePortraitOrientation
                    text: "Portrait"
                    onClicked: { screen.orientationString = "Portrait" }
                }
                Button {
                    id: forceLandscapeOrientation
                    text: "Landscape"
                    onClicked: { screen.orientationString = "Landscape" }
                }
                Button {
                    id: gotoWelcomeView
                    text: "Welcome"
                    onClicked: { window.nextPage(firstTimeUseViewComponent, '') }
                }

            }

            GroupHeader {
                id: settingstitle
                headerType: 'headerTwo'
                text: "Settings"
                width: parent.width
                anchors.top: orientationbuttons.bottom
            }

            Text {
                id: settingsDisclaimer
                text: "You need restart Morpheus in order to environment change to take effect."
                anchors.top: settingstitle.bottom
            }


            function setEnvironment(envNum) {

                var oldTerr = API.settings.getTerritory(), 
                    oldRedTerr = API.settings.getRedirectedTerritory(),
                    newHost;

                API.settings.reset();

                switch (envNum) {

                    case 1:
                        newHost = "api.music.cq1.brislabs.com"; // CQ1
                        morpheusSettings.setEnvironment("cq1");
                        break;
                    case 2:
                        newHost = "api.music.cq2.brislabs.com"; // CQ2
                        morpheusSettings.setEnvironment("cq2");
                        break;
                    case 3:
                        newHost = "api.stg.music.ovi.com"; // Staging
                        morpheusSettings.setEnvironment("stg");
                        break;
                    default:
                        newHost = "api.music.ovi.com"; // live
                        morpheusSettings.setEnvironment("live");
                        break;
                }

                API.settings.set("ServiceProviders/NokiaMusic/PAPI/host", newHost);

                API.settings.setTerritory(oldTerr);
                API.settings.setRedirectedTerritory(oldRedTerr);
            }

            Grid {
                id: settingsbuttons
                columns: 3
                spacing: 10
                anchors.top: settingsDisclaimer.bottom

                Button {
                    id: resetSettings
                    text: "Reset All"
                    onClicked: {API.settings.reset()}
                }
                Button {
                    id: setCQ1Env
                    text: "CQ1"
                    onClicked: {
                        viewRoot.setEnvironment(1);
                    }
                }
                Button {
                    id: setCQ2Env
                    text: "CQ2"
                    onClicked: {
                        viewRoot.setEnvironment(2);
                    }
                }
                Button {
                    id: setLIVEEnv
                    text: "LIVE"
                    onClicked: {
                        viewRoot.setEnvironment(0);
                    }
                }
                Button {
                    id: setSTGEnv
                    text: "STG"
                    onClicked: {
                        viewRoot.setEnvironment(3);
                    }
                }

            }

            GroupHeader {
                id: territorytitle
                headerType: 'headerTwo'
                text: "Territory"
                width: parent.width
                anchors.top: settingsbuttons.bottom
            }

            Grid {
                id: territorybuttons
                columns: 3
                spacing: 10
                anchors.top: territorytitle.bottom

                Button {
                    id: clearTerritory
                    text: "Clear"
                    onClicked: {API.settings.setTerritory("")}
                }

            }

            GroupHeader {
                id: debugtitle
                headerType: 'headerTwo'
                text: "Debug view"
                width: parent.width
                anchors.top: territorybuttons.bottom
            }

            Grid {
                id: debugbuttons
                columns: 4
                spacing: 10
                anchors.top: debugtitle.bottom

                Button {
                    id: genreHub
                    text: "GenreHub"
                    onClicked: { window.nextPage(genreHubViewComponent, "")}
                }
                Button {
                    id: redeemPurchaseOptionsButton
                    text: "Redeem voucher"
                    onClicked: { window.nextPage(redeemVoucherInPurchaseOptionsComponent, {productId: 13041836, productName: "Meine Zeit", artistName: "Rainhard Fendrich", price: "123 euro", productUrl: "http://4.musicimg.ovi.com/u/1.0/image/169102245/?w=200&q=90", productType: "musiccollection"})}
                }
                Button {
                    id: genreHome
                    text: "GenreHome"
                    onClicked: { window.nextPage(genreHomeView, {genreId: "SoulRandBFunk", genreName: "Soul / R'n'B / Funk"})}
                }
                Button {
                    id: ssoTester
                    text: "SSO Test View"
                    onClicked: { window.nextPage(ssoTestView, "") }
                }
            }

        // Suds

            GroupHeader {
                id: sudstitle
                headerType: 'headerTwo'
                text: "Product Tests"
                width: parent.width
                anchors.top: debugbuttons.bottom
            }

            Grid {
                id: sudsproductlinks
                columns: 4
                spacing: 10
                anchors.top: sudstitle.bottom

                Button {
                    id: longTrackNameButton
                    text: "LongTrackName"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "1926"}); }
                }
                Button {
                    id: longAlbumNameButton
                    text: "LongAlbumName"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "1778"}); }
                }
                Button {
                    id: longArtistNameButton
                    text: "LongArtistName"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "1774"}); }
                }
                Button {
                    id: htmlalbumNameButton
                    text: "HtmlAlbumName"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "760743"}); }
                }
                Button {
                    id: htmlsongNameButton
                    text: "HtmlSongName"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "760747"}); }
                }
                Button {
                    id: albumHas99TracksButton
                    text: "99Songs"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "1779"}); }
                }
                Button {
                    id: japaneseCharslAlbumNameButton
                    text: "JapAlbum"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "760603"}); }
                }
                Button {
                    id: japaneseCharstrackNameCharsButton
                    text: "JapSong"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "760605"}); }
                }
                Button {
                    id: noReleaseYearButton
                    text: "NoReleaseYearPackshotAlbum"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "1115"}); }
                }
                Button {
                    id: missingPackShotButton
                    text: "NoPackshotAlbum"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "760645"}); }
                }
                Button {
                    id: longTracksNameButton
                    text: "TracksLongName"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "1406"}); }
                }
                Button {
                    id: noTracksInAlbum
                    text: "NoTracksInAlbum"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "1306"}); }
                }
                Button {
                    id: artistNonWestern
                    text: "ArtistNameNonWestrenChars"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "760602"}); }
                }
                Button {
                    id: longDurationTrackName
                    text: "1:59:59LongTrackLength"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "760739"}); }
                }
                Button {
                    id: dodgyCharsInAlbumName
                    text: "DodgyCharsInAlbumName"
                    onClicked: { window.nextPage(productViewComponent, {dataProductID: "43414"}); }
                }
            }

            GroupHeader {
                id: otherTitle
                headerType: 'headerTwo'
                text: "Other"
                width: parent.width
                anchors.top: sudsproductlinks.bottom
            }

            Grid {
                id: other
                columns: 4
                spacing: 10
                anchors.top: otherTitle.bottom

                Button {
                    id: playLocalFileInExternalMusicPlayer
                    text: "Launch MusicPlayer"
                    onClicked: { externalMusicPlayer.playTrack("file:///home/user/MyDocs/.sounds/Dire%20Straits%20-%20Sultans%20Of%20Swing%20-%20Best%20Of/Dire%20Straits%20-%202008%20-%20Sultans%20Of%20Swing%20The%20Very%20Best%20Of%20-%2009%20-%20Money%20For%20Nothing.mp3") }
                }

                Button {
                    id: launchTransferUI
                    text: "Launch TUI"
                    visible:  (downloadEngine.totalDownloads > 0) ? true : false
                    onClicked: { downloadEngine.showTransferUi() }
                }

                Button {
                    id: pinEntry
                    text: "PinEntryView"
                    onClicked: { window.nextPage(pinEntryViewComponent, "")}
                }
            }

        }

    }

}
