import Qt 4.7
//import com.meego 1.0
import "components"
import "components/asgard"
import NetworkMonitor 1.0

import "../javascript/APIWrapper.js" as API

Page {
    id: firstTimeUseView
    anchors.fill: parent
    property string title: "FirstTimeUseView"
    objectName: "welcome"
    state: window.state

    states: [
        State {
            name: "Landscape"
            PropertyChanges {
                target: buttonRow
                columns: 2
                spacing: 6
            }
        },
        State {
            name: "Portrait"
            PropertyChanges {
                target: buttonRow
                columns: 1
                spacing: 16
            }
        },
        State {
            name: "LandscapeInverted"
            extend: "Landscape"
        },
        State {
            name: "PortraitInverted"
            extend: "Portrait"
        }
    ]


    function init() {
        loadingSpinner.visible = true;
        buttonRow.visible = false;
        tryAgainBlock.visible = false;
       
        var masterGSDURI = API.getGSDURI(true);

        API.loadGSD(masterGSDURI, countryModel, function (responseObj) {

            // hide the error block if we have a successful response
            tryAgainBlock.visible = false;

            console.log('countryModel loaded');

            var index = API.getPreSelectedTerritoryIndex(countryModel);

            if (index !== -1) {
                firstTimeDropDown.selectedIndex = index;
                dropDownButton.text = countryModel.get(index).translatedCountry;
                translateTextButton.disabled = false;
            }

            loadingSpinner.visible = false;
            buttonRow.visible = true;
        },
        function(error) {
            loadingSpinner.visible = false;
            buttonRow.visible = false;
            tryAgainBlock.errorText = qsTranslate("FirstTimeUseView","t[GeneralError");
            tryAgainBlock.buttonText = qsTranslate("FirstTimeUseView", "t[TryAgain");
            tryAgainBlock.visible = true;
        }
        );
    }

    function noConnection() {

        loadingSpinner.visible = false;

        buttonRow.visible = false;
        tryAgainBlock.errorText = "";
        tryAgainBlock.buttonText = qsTranslate("FirstTimeUseView", "t[ConnectToInternet");
        tryAgainBlock.visible = true;
    }

    NetworkMonitor {
	id: networkMonitor
        onOnlineStateChanged: {
            if (!morpheusSettings.disableNetMonitoring) {
                if(!online){
                    noConnection();
                }
                else
                {
                    init();
                }
            }
        }

        Component.onCompleted: {
            if(!morpheusSettings.disableNetMonitoring)  {               
                if(online) {
                    init();

                }
                else {
                    noConnection();
                }
            }
            else {
                init();
            }
        }
    }

    Flickable {
        id: scroller
        anchors.fill: parent
        contentWidth: contentItem.childrenRect.width;
        contentHeight: viewRoot.height + theme.bottomPadding
        flickableDirection: Flickable.VerticalFlick
        clip: true

        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            color: 'transparent'

            ContextDialog {
                id: firstTimeDropDown

                headerText: qsTranslate("FirstTimeUseView","t[DropDownPreFill");
                dropDownModel: countryModel
                backgroundWidth: window.width
                backgroundHeight: window.height
                yOffset: scroller.contentY
                dropDownVisible: false
                selectedIndex: -1

                onClickedOn: {scroller.interactive = false;}
                onClickedOff: {scroller.interactive = true;}

                ListModel {
                    id: countryModel
                }

                dropDownDelegate:

                    DropDownItem {
                    id: delegateItem
                    name: 'countryDropDownItem' + index
                    itemText: translatedCountry;

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            firstTimeDropDown.dropDownVisible = false;
                            scroller.interactive = true;
                            console.log(delegateItem.name);
                        }
                        onPressed: {
                            dropDownButton.text = delegateItem.itemText;
                            firstTimeDropDown.selectedIndex = index;
                            translateTextButton.disabled = false;
                        }
                    }
                }
            }

            BannerOne {
                id: welcomeBanner
                bannerText: qsTranslate("FirstTimeUseView","t[BannerTitle");
            }

            Column {
                id: bulletList
                width: parent.width
                anchors.top: welcomeBanner.bottom
                anchors.topMargin: 20

                Repeater {
                    model: [
                        qsTranslate("FirstTimeUseView","t[DiscoverAndDownload"),
                        qsTranslate("FirstTimeUseView","t[ExploreGenres"),
                        qsTranslate("FirstTimeUseView","t[DownloadAndPlay")
                    ]
                    BulletItem {
                        bulletText: modelData
                    }
                }
            }

            Grid {
                id: buttonRow
                columns: 2
                spacing: 6
                anchors.top: bulletList.bottom
                anchors.topMargin: 16
                anchors.horizontalCenter: parent.horizontalCenter

                M_Button {
                    id: dropDownButton
                    width: 322
                    align: Text.AlignLeft
                    rightPadding: 40
                    iconPos: 'right'
                    iconSource: '../../images/buttons/btnDropDown.png'
                    text: qsTranslate("FirstTimeUseView","t[DropDownPreFill");

                    onClicked: {
                        firstTimeDropDown.dropDownVisible = true;
                        scroller.interactive = false;
                        //console.log(delegateItem.name);
                    }
                }

                M_Button {
                    id: translateTextButton
                    width: 322
                    disabled: true
                    text: qsTranslate("FirstTimeUseView","t[TakeMeTo");

                    onClicked: {

						var storeObj = countryModel.get(firstTimeDropDown.selectedIndex),
							code = storeObj.countryCode,
                            redirectedTerritory = null;

                        console.log("got selected territory code: " + code);

						if (typeof storeObj.redirectCode === "string") {
							redirectedTerritory = storeObj.redirectCode;
                            console.log("got redirectedTerritory: " + redirectedTerritory);
                            API.settings.setRedirectedTerritory(code); // original territory
							code = redirectedTerritory;
                        }

                        API.settings.setTerritory(code);

                        API.settings.setStoreConfig(storeObj.settings);

                        window.clearHistory();
                        window.nextPage(homeViewComponent,'');
                    }
                }
            }

            Spinner {
                id: loadingSpinner
                dimension: 170
                anchors.top: bulletList.bottom
                anchors.topMargin: -8
                anchors.horizontalCenter: parent.horizontalCenter
            }

            Item {
                id: tryAgainBlock

                property alias errorText:  tryAgainText.text
                property alias buttonText: tryAgainButton.text

                anchors.top: bulletList.bottom
                anchors.topMargin: 4
                width: parent.width

                Divider {
                    id: tryAgainDivider
                    dividerType: 'itemDivider'
                    visible: (tryAgainText.text === "") ? false : true
                }

                BodyText {
                    id: tryAgainText
                    height: (text === "") ? 0 : paintedHeight
                    anchors {
                        top: tryAgainDivider.bottom
                        left: parent.left
                        right: parent.right
                        topMargin: (text === "") ? 0 : 16
                        leftMargin: 16
                        rightMargin: 16
                    }
                    wrapMode:  "Wrap"

                    //text: "It is taking longer than the usual to open the page you wanted."
                }
                M_Button {
                    id: tryAgainButton
                    anchors.top: tryAgainText.bottom
                    anchors.topMargin: 16
                    anchors.horizontalCenter: parent.horizontalCenter
                    width: 322
                    //text: 'Try Again';

                    onClicked: {init();}
                }
            }

            Rectangle {
                id: bottomPadding
                anchors.top: buttonRow.bottom
                height: 30
                width: parent.width
                color: 'transparent'
            }

        }// end viewRoot
    }// end scroller
}// end page


