import Qt 4.7
//import com.meego 1.0

import "components"
import "components/asgard"
import "../javascript/APIWrapper.js" as API
import "../javascript/durationConverter.js" as DurationConverter

Page {
    id: genreHomeView
    property string title: "GenreHomeView"
    objectName: "genre home"
    state: window.state

    property int hiddenListItems: (window.state == "Portrait" || window.state == "PortraitInverted") ? 3 : 6

    property bool primaryReady: false
    //Initially true as secondary request is only made on filter switching
    property bool secondaryReady: true

    function primaryCb () {
        primaryReady = true;
    }

    function primaryEb () {
        window.showError(context.genreName);
    }

    function secondaryCb () {
        secondaryReady = true;
    }

    function secondaryEb () {
        window.showError(context.genreName);
    }

    //break the binding to the pageStack variable
    Component.onCompleted: context = context;

    ListModel {
        id: homeModel
        Component.onCompleted: {
            var tracksURI = API.getGenreTopTracksURI(context.genreId);
            API.loadProductList(tracksURI, homeModel, primaryCb, primaryEb);
	}
    }

    Flickable {
        id: scroller
        anchors.fill: parent
        contentWidth: contentItem.childrenRect.width
        contentHeight: contentItem.childrenRect.height + theme.bottomPadding
        flickableDirection: Flickable.VerticalFlick
        clip: true

        //View header
        GroupHeader {
            id: homeHeader
            objectName: "genreHeader"
            headerType: 'headerTwo'
            topMargin: 10
            text: context.genreName
        }

        //Primary load indication
        Item {
            height: (visible) ? window.height : 0
            width: window.width
            visible: !primaryReady

            Spinner {
                id: primarySpinner
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                dimension: 170
                visible: !primaryReady
            }
        }

        //View contents
        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            color: 'transparent'
            anchors.top: homeHeader.bottom
            anchors.topMargin: 8
            visible: primaryReady

            PromoPanel {
                id: genreHomeViewPromoPanel
		objectName: "promo master panel"
                model: homeModel
            }

            Grid {
                id: buttonRow
                columns: 2
                spacing: 0
                z: 2
                anchors.top: genreHomeViewPromoPanel.bottom
                anchors.topMargin: 18
                anchors.horizontalCenter: parent.horizontalCenter


                function switchToSongs() {
                    secondaryReady = false;
                    var tracksURI = API.getGenreTopTracksURI(context.genreId);
                    API.loadProductList(tracksURI, homeModel, secondaryCb, secondaryEb);
                }

                function switchToAlbums() {
                    secondaryReady = false;
                    var albumsURI = API.getGenreTopAlbumsURI(context.genreId);
                    API.loadProductList(albumsURI, homeModel, secondaryCb, secondaryEb);
                }

                M_Button {
                    id: songsBtn
                    text: qsTranslate("GenreHomeView","t[SongsTab");
                    width: 224
                    checked: true
                    buttonPos: 'left'
                    onClicked: {
                        buttonRow.switchToSongs();
                        albumsBtn.checked = false;
                        songsBtn.checked = true;
                    }
                }

                M_Button {
                    id: albumsBtn
                    text: qsTranslate("GenreHomeView","t[AlbumsTab");
                    width: 224
                    checked: false
                    buttonPos: 'right'
                    onClicked: {
                        buttonRow.switchToAlbums();
                        albumsBtn.checked = true;
                        songsBtn.checked = false;
                    }
                }
            }

            Spinner {
                id: secondarySpinner
                anchors.top: buttonRow.bottom
                anchors.topMargin: (genreHomeView.state === ('Portrait' || 'PortraitInverted')) ? 70 : -20
                z: 0
                anchors.horizontalCenter: parent.horizontalCenter
                dimension: 170
                visible: !secondaryReady
            }

            Column {
                id: productColumn
                anchors.top: buttonRow.bottom
                anchors.topMargin: 16
                height: childrenRect.height
                width: window.width
                visible: secondaryReady

                Repeater {
                    id: productsList
                    model: homeModel
                    width: productColumn.width

                    ProductLink {
                        id: productLink
                        visible: (index < hiddenListItems) ? false : true
                        height: (index < hiddenListItems) ? 0 : 116
                        linkText1: name
                        linkText2: artistName
                        linkText3: (typeof durationLength != "number") ? qsTr("t[TrackCount","",trackCount) : DurationConverter.convert(durationLength)
                        packshotUrl: albumArt100
                        onClicked: window.nextPage(
                                productViewComponent,
                        {
                            name: name,
                            type: type,
                            artistName: artistName,
                            artistID: artistID,
                            variousArtists: variousArtists,
                            albumArt100: albumArt100,
                            albumArt200: albumArt200,
                            takenFrom: takenFrom,
                            takenFromID: takenFromID,
                            genre: genre,
                            genreID: genreID,
                            label: label,
                            dataProductID: dataProductID,
                            trackCount: trackCount,
                            durationLength: durationLength,
                            currencyCode: currencyCode,
                            price: price,
                            trackUrl: trackUrl,
                            streetReleaseDate: streetReleaseDate,
                            cwmAvailable: cwmAvailable,
                            cwmBitRate: cwmBitRate,
                            cwmFormat: cwmFormat,
                            alcAvailable: alcAvailable,
                            alcBitRate: alcBitRate,
                            alcFormat: alcFormat
                        });
                    }
                }
            }

        }// end viewRoot
    }// end scroller
}// end page
