import Qt 4.7
import "components"
import "components/asgard"
import com.nokia.qmlcomponents 1.0

Page {
    id: pinEntry
    property variant _pinRedeemCommand;
    // Should be in same order than in RedeemCreditPinCommand::CommerceError
    property variant _errorTexts: {
        1 : "Pin code is invalid!",
        2 : "Promotion associated with pin is not active",
        3 : "Promotion associated with pin has expired.",
        4 : "Pin is associated with different territory.",
        5 : "Pin has already been redeemed.",
        6 : "Pin has already been redeemed by this user.",
        7 : "Pin has already been redeemed maximum amount of times.",
        8 : "Promotion associated with pin is of wrong type.",
        9 : "Pin promotion does not match LPG license.",
        10 : "IMEI not found in LPG.",
        11 : "Device is blacklisted.",
        12 : "Device's public id doesn't match requested public id.",
        13 : "Device has no unredeedem licenses of the specified offering types.",
        14 : "Associated promition are not active at the time.",
        15 : "Device license is associated with a different territory."
    }
    property Connections _currentConnection;
    property Connections _ssoConnectionBinding;

    function createSsoConnectionBinding() {
        if (_ssoConnectionBinding != undefined) {
            _ssoConnectionBinding.destroy();
        }
        _ssoConnectionBinding = ssoConnectionContainer.createObject(pinEntry);
    }


    function redeemPin() {
        pinEntry.state = "wait"

        if (_currentConnection != undefined) {
            _currentConnection.destroy();
        }
        _pinRedeemCommand = store.account.redeemCreditPin(voucherInputField.pinEntered);
        _currentConnection = pinRedeemCommandContainer.createObject(pinEntry);
    }

    Component {
        id: pinRedeemCommandContainer;
        Connections {
            target: _pinRedeemCommand.status;
            onStatusChanged: {
                var _status = _pinRedeemCommand.status.status;
                var _commerceError = _pinRedeemCommand.commerceError;
                console.log("***********_pinRedeemCommand.status.status: " + _status);
                console.log("***********_pinRedeemCommand.commerceError: " + _commerceError);
                if (_status == RequestStatus.Success) {
                    if (_ssoConnectionBinding != undefined) {
                        _ssoConnectionBinding.destroy();
                    }
                    if (_commerceError == RedeemCreditPinCommand.NoCommerceError) {
                        console.log("******************_pinRedeemCommand.creditBalance: " + _pinRedeemCommand.creditBalance);
                        morpheusSettings.setCreditBalance(_pinRedeemCommand.creditBalance);
                        //pinEntry.state = "pinRedeemed";
                        window.nextPage(accountViewComponent,"");
                    }
                } else if (_status == RequestStatus.NetworkError) {
                    pinEntry.state = "error";
                    error.errorText = "Network error!"
                } else if (_status == RequestStatus.RequestError) {
                    pinEntry.state = "error";
                    error.errorText = _errorTexts[_commerceError];
                } else if (_status == RequestStatus.PermissionError) {
                    // Need to sign in
                    createSsoConnectionBinding();
                    sso.signIn();
                }
            }
        }
    }

    Component {
        id: ssoConnectionContainer;
        Connections {
            target: sso
            onSignInSuccessful: {
                redeemPin();
            }
            onSilentSignInFailed: {
                sso.launchSignInUi();
            }
        }
    }

    Flickable {
        id: scrollPaign
        anchors.fill: parent
        contentWidth: childrenRect.width
        contentHeight: contentItem.activeFocuschildrenRect.height + theme.bottomPadding
        flickableDirection: Flickable.VerticalFlick
        clip: true

        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            color: 'transparent'

            GroupHeader {
                id: pinEntryTitleText
                headerType: 'headerTwo'
                text: qsTranslate("PinEntryView","t[Title");
                width: parent.width
                anchors.top: parent.top
                topMargin: 16
            }

            Column {
                id: redeemVoucherContent
                anchors.top:  pinEntryTitleText.bottom
                anchors.topMargin: 10
                height: childrenRect.height
                width: window.width


                Text {
                    id: pinEntryGreeting
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    width: window.width
                    text: qsTranslate("PinEntryView","t[Greeting");
                    wrapMode: "WordWrap"
                }

                ErrorText{
                    id: error
                    opacity: 0
                    anchors.top: pinEntryGreeting.bottom
                    anchors.topMargin: 16
                    errorText: "<error message to be placed here>"
                }

                Text {
                    id: pinSuccessfullyRedeemed
                    opacity: 0
                    anchors.top: pinEntryGreeting.bottom
                    anchors.topMargin: 16
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    text: "Your new balance is " + morpheusSettings.creditBalance;//"You're account has been topped with xx€"
                }

                CommonSingleInputField{
                    id: voucherInputField
                    anchors.top: error.bottom
                    anchors.topMargin: 16
                }

                Grid {
                    id: pinEntryButtonGrid
                    anchors.top: voucherInputField.bottom
                    anchors.topMargin: 16
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    spacing: 10

                    Button {
                        id: redeemButton
                        text: qsTranslate("PinEntryView","t[RedeemButtonText")
                        onClicked: {
                            redeemPin();
                        }
                    }

                    Button {
                        id: cancelPurchaseOptions
                        text: "Cancel"
                        onClicked: {
                            window.back()
                        }

                    }

                }

                Spinner {
                    id: spinner
                    visible : false
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.top: voucherInputField.bottom
                    anchors.topMargin: 16
                    dimension: 170
                }

            }

        }

    }

    states : [

        State {
                name : "wait"
                PropertyChanges { target: error; opacity: 0}
                PropertyChanges { target: voucherInputField; opacity: 0}
                PropertyChanges { target: pinEntryButtonGrid; opacity: 0}
                PropertyChanges { target: spinner; visible: true}
        },

        State {
                name : "error"
                PropertyChanges { target: error; opacity: 1}
                PropertyChanges { target: voucherInputField; opacity: 1}
                PropertyChanges { target: pinEntryButtonGrid; opacity: 1}
                PropertyChanges { target: spinner; opacity: 0}
        },

        State {
                name : "pinRedeemed"
                PropertyChanges { target: pinSuccessfullyRedeemed; opacity: 1}
                PropertyChanges { target: voucherInputField; opacity: 1}
                PropertyChanges { target: pinEntryButtonGrid; opacity: 1}
                PropertyChanges { target: spinner; opacity: 0}

        }
    ]

}
