import Qt 4.7
import com.nokia.qmlcomponents 1.0
import "components"
import "components/asgard"
import "../javascript/APIWrapper.js" as API
import "../javascript/durationConverter.js" as DurationConverter
import "../javascript/parameterInsertion.js" as ParameterInsertion

Page {
    id: productView
    property string title: "ProductView"
    objectName: "product"
    state: window.state

    property variant productData;
    //cast release date to date format for formatting
    property date releaseDate: productData.streetReleaseDate;

    property bool prefilled: false;

    property bool primaryReady: false;
    property bool secondaryReady: false;

    property bool albumTrackListReady: false;

    property variant _downloadCommand;
    property Connections _connectionBinding;
    property Connections _ssoConnectionBinding;


    function init () {
        //break the binding to the pageStack variable
        context = context;

        //check for prefilled content
        if (context.hasOwnProperty("name")) {
            prefilled = true;
            applyPrefilledContent();
            primaryReady = true;
        }

    }

    function applyPrefilledContent () {
        var i, dataObj = {};
        console.log("Product prefill: Got necessary data, prefilling product view content");
        productData = context;
    }

    function applyNonPrefilledContent () {
        var productResponse = productModel.get(0);
        console.log("Product prefill: Required properties not found, filling product view with product response");
        productData = productModel.get(0);
    }

    function primaryCb () {
        if (!prefilled) {
            applyNonPrefilledContent();
        }
        primaryReady = true;
        secondaryReady = true;

        generateTrackListForAlbumDownload();

        // Returning from OPE
        if (context.execute == "startDownload") {
            downloadEngine.updateAlbumStatusData(productData.dataProductID, "queuingDownload", "queuingDownload");
            createDownloadCommand(context.dataProductID);
        }
        // TODO: Define returning from OPE with flag
        /*else {
            // Commented out as this cause the background and state behavious to disappear for that button; there is no state as default for this component...
            //albumDownloadButton.state = "default";
        }*/
    }

    function primaryEb () {
        window.showError(productData.name);
    }

    function recommendationsCB() {
        console.log("Recommendations retrieved successfully");
    }

    function generateTrackListForAlbumDownload() {
        var modelLength, i, currentItem;
        modelLength = productModel.count;

        for (i = 0; i < modelLength; i += 1) {
            currentItem = productModel.get(i);
            if (currentItem.type === 'musictrack') {
                albumTrackListModel.append({
                    productId: currentItem.dataProductID,
                    name: currentItem.name,
                    fileType: productData.alcFormat,
                    alcAvailable: currentItem.alcAvailable
                });
            }
        }
        albumTrackListReady = true;
    }

    function getPriceString (productObj) {
        //console.log('getPriceString' + productObj.price)
        var priceStr = '',
            voucherStore = (API.settings.getStoreConfig().alcVoucherOnly === 'true'),
            currencyCode,
            productPrice = (typeof(productObj.price) !=='undefined') ? productObj.price : -1;

        if (voucherStore && (productPrice !== -1)) {
            priceStr = qsTr("t[VoucherCredit","",productPrice);
        } else if (productPrice === 0) {
            priceStr = qsTranslate("ProductView","t[Free");
        } else {
            priceStr = (productPrice !== -1) ? morpheusCurrency.formatPrice(productPrice, productObj.currencyCode) : '';
        }
        return priceStr;
    }

    function createDownloadCommand(paramAlbumId) {
        console.log("Album download, productId: " + paramAlbumId + " -> DownloadCommand.ALCUsage: " + DownloadCommand.ALCUsage);
        _downloadCommand = store.account.download(paramAlbumId, DownloadCommand.ALCUsage);
        if (_connectionBinding != undefined) {
            _connectionBinding.destroy();
        }
        _connectionBinding = connectionContainer.createObject(productView);
    }

    function createSsoConnectionBinding() {
        if (_ssoConnectionBinding != undefined) {
            _ssoConnectionBinding.destroy();
        }
        _ssoConnectionBinding = ssoConnectionContainer.createObject(productView);
    }

    //Set the model sources on view init so that request is not refired when the navstack item is removed on backward navigation
    Component.onCompleted: init();

    onDeactivated: musicPlayer.stop();

    ListModel {
        id: productModel

        Component.onCompleted: if (context.type !== "musictrack") {
            API.loadProductList(API.getProductURI(context.dataProductID), productModel, primaryCb, primaryEb);
        } else {
            productModel.append(productData);
            secondaryReady = true;
        }
    }

    ListModel {
        id: recommendationsModel
        Component.onCompleted: {
            if (context.type == "musictrack") {
                API.loadProductList(API.getProductTrackRecommendationsURI(context.dataProductID), recommendationsModel, recommendationsCB, recommendationsCB);
            } else {
                API.loadProductList(API.getProductAlbumRecommendationsURI(context.dataProductID), recommendationsModel, recommendationsCB, recommendationsCB);
            }
        }
    }

    ListModel {
        id: albumTrackListModel
    }

    Component {
        id: connectionContainer
        Connections {
            ignoreUnknownSignals: true;
            target: _downloadCommand.status;
            onStatusChanged: {
                var _status = _downloadCommand.status.status;
                console.log("Album download -> Download command status: " + _status + ", response: " + _downloadCommand.response);
                if (_ssoConnectionBinding != undefined) {
                    _ssoConnectionBinding.destroy();
                }

                if (_downloadCommand.response == DownloadCommand.SuccessResponse) {
                    var responseLength =  _downloadCommand.count(), i, result, r, downloadUrls = {};
                    if( responseLength > 0 ) {
                        console.log("DownloadCommand results length: " + responseLength);
                        for (i = 0; i < responseLength; i++) {
                            result = _downloadCommand.resultAt(i)
                            r = "DownloadCommand result -> releaseId: " + result.releaseId + " , downloadUri: " + result.downloadUri + " , licenseUri: " + result.licenseUri;
                            console.log(r);
                            downloadUrls[result.releaseId] = result.downloadUri;
                        }
                        downloadEngine.downloadAlbum(productData.dataProductID, {
                            "trackListModel": albumTrackListModel,
                            "downloadUrls" : downloadUrls,
                            "artistName" : productData.artistName,
                            "albumName" : productData.name,
                            "albumArtUrl" : productData.albumArt100
                        });
                    }
                }

                else if (_downloadCommand.response == DownloadCommand.PaymentRequiredResponse) {
                    if (API.settings.getStoreConfig().alcVoucherOnly === 'true') {
                        window.nextPage(redeemVoucherInPurchaseOptionsComponent, {productId: productData.dataProductID, productName: productData.name, artistName: productData.artistName, price: albumDownloadButton.text, price2:productData.price, productUrl: productData.albumArt200, productType: productData.type})
                    }
                    else {
                        opePage.doCheckout("MusicDD-1388", viewRoot, opePage.ShowSpinner, opePage.ShowSpinner);
                    }
                }

                else if (_downloadCommand.response == DownloadCommand.ErrorResponse ||
                         _downloadCommand.response == DownloadCommand.NoResponse) {

                    if (_status == RequestStatus.PermissionError) {
                        // Need to sign in
                        createSsoConnectionBinding();
                        sso.signIn();
                    }

                    else if (_status == RequestStatus.NetworkError ||
                             _status == RequestStatus.RequestError ||
                             _status == RequestStatus.UnknownError) {
                        /* In backend errors, show error message and disable album download button temporarily.
                           Change track list download buttons back to normal */
                        downloadEngine.updateAlbumStatusData(productData.dataProductID, "temporarilyDisabled", "normal");
                    }

                    else if (_status == RequestStatus.DataError) {
                        /* In fatal backend errors, show error message and disable album download button.
                           Change track list download buttons back to normal */
                        downloadEngine.updateAlbumStatusData(productData.dataProductID, "disabled", "normal");
                    }
                }
            }
        }
    }

    Component {
        id: ssoConnectionContainer;
        Connections {
            target: sso
            onSignInSuccessful: {
                // Retry the SAPI call
                createDownloadCommand(productData.dataProductID);
            }
            onSilentSignInFailed: {
                sso.launchSignInUi();
            }
            onSignInFailed: {
                downloadEngine.updateAlbumStatusData(productData.dataProductID, "normal", "normal");
            }
        }
    }

    Flickable {
        id: scroller
        contentWidth: contentItem.childrenRect.width
        contentHeight: contentItem.childrenRect.height + theme.bottomPadding
        flickableDirection: Flickable.VerticalFlick
        clip: true
        anchors.fill: parent

        //View header
        GroupHeader {
            id: viewHeader
            text: productData.name
            objectName: "product name"
            headerType: 'headerTwo'
            topMargin: 10;
        }

        //Primary load indication
        Item {
            height: (visible) ? window.height : 0
            width: window.width
            visible: !primaryReady

            Spinner {
                id: primarySpinner
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                dimension: 170
                visible: !primaryReady
            }
        }


        //View contents
        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            anchors.top: viewHeader.bottom
            anchors.topMargin: 8
            color: 'transparent'
            visible: primaryReady

            TextLink {
                id: artistLink
                anchors {
                    left: parent.left
                    right: parent.right
                    leftMargin: 16
                    rightMargin: 16
                }
                textSize: 24
                linkText: productData.artistName
                onClicked: window.nextPage(artistViewComponent, {artistId: productData.artistID, artistName: productData.artistName});
            }

            Rectangle {
                id: productInfo
                color: "transparent"
                width: parent.width
                height: childrenRect.height
                anchors.top: artistLink.bottom
                anchors.topMargin: 10

                Item {
                    width: parent.width
                    height: childrenRect.height

                    WebImage {
                        id: productImage
                        height: 290
                        width: 290
                        imageSource: productData.albumArt200
                        anchors.left: parent.left
                        anchors.leftMargin: 16

                        Image {
                            id: rightsAndInfoImage
                            objectName: "rights and info"
                            source: '../images/buttons/btnRightsAndInfo.png'
                            height: 43
                            width: 42
                            visible: true
                            fillMode: Image.PreserveAspectFit
                            anchors {
                                right: parent.right
                                rightMargin: 10
                                bottom: parent.bottom
                                bottomMargin: 10
                            }

                            MouseArea {
                                anchors.fill: parent
                                onClicked: {
                                    window.nextPage(rightsViewComponent, productData);
                                }
                            }
                        }
                    }

                    Column {
                        id: productInfoColumn
                        spacing: 5
                        width: parent.width - productImage.width //- 16 is for the right padding

                        anchors {
                            top: productImage.top
                            topMargin: 8
                            left: productImage.right
                            leftMargin: 13
                            right: parent.right
                            rightMargin: 16
                        }

                        BodyText {
                            id: tracksOrLength
                            width: parent.width
                            objectName: "tracks or length"
                            font.pixelSize: 18
                            elide: "ElideRight"
                            color: theme.tertiaryColor
                            text: (productData.type == "musictrack") ? DurationConverter.convert(productData.durationLength) : qsTr("t[TrackCount","",productData.trackCount)
                        }

                        BodyText {
                            width: parent.width
                            objectName: "release date"
                            font.pixelSize: 18
                            elide: "ElideRight"
                            color: theme.tertiaryColor
                            text: Qt.formatDate(releaseDate,"MMMM yyyy");
                        }

                        TextLink {
                            width: parent.width
                            objectName: "genreLink"
                            font.pixelSize: 18
                            elide: "ElideRight"
                            text: productData.genre
                            onClicked: window.nextPage(genreHomeViewComponent, {genreName: productData.genre, genreId: productData.genreID});
                        }

                        BodyText {
                            id: labelName
                            width: parent.width

                            font.pixelSize: 18
                            elide: "ElideRight"
                            color: theme.tertiaryColor
                            text: productData.label
                        }
                    }

                    ButtonSmall {
                        id: albumDownloadButton
                        objectName: "price"
                        visible: (productData.type == "musictrack" || !albumTrackListReady || ((productData.type === 'musiccollection') && !productData.alcAvailable)) ? false : true
                        anchors.top: productInfoColumn.bottom
                        anchors.topMargin: 14
                        anchors.left: productInfoColumn.left
                        text: getPriceString(productData)
                        productId: productData.dataProductID
                        isTrackDownload: false
                        onClicked: {
                            downloadEngine.addAlbumDownloadData(productData.dataProductID, albumTrackListModel);
                            createDownloadCommand(productData.dataProductID);
                            //window.nextPage(opeHeaderViewComponent, {albumArt100: productData.albumArt200, collectionOrSongName: viewHeader.text, artistName: productData.artistName, collectionNameOrNumberOfSongs: tracksOrLength.text, productId: productData.dataProductID});
                        }
                    }

                    BodyText {
                        id: albumDownloadRequestError

                        visible: (albumDownloadButton.state === 'temporarilyDisabled' || albumDownloadButton.state === 'disabled') ? true : false
                        width: productInfoColumn.width
                        anchors.top: albumDownloadButton.bottom
                        anchors.topMargin: 14
                        anchors.left: productInfoColumn.left
                        wrapMode: Text.Wrap
                        text: qsTranslate("Download","t[AlbumDownloadRequestErrorNote");
                    }

                }
            }

            Divider {
                id: productDivider
                dividerType: 'itemDivider'
                anchors {
                    top: productInfo.bottom
                    topMargin: 18
                }
            }

            Spinner {
                id: secondarySpinner
                anchors.top: productDivider.bottom
                anchors.topMargin: (productView.state === ('Portrait' || 'PortraitInverted')) ? 70 : 20
                anchors.horizontalCenter: parent.horizontalCenter
                dimension: 170
                visible: !secondaryReady
            }

            ListView {
                id: tracksList
                objectName: "track list"

                height: childrenRect.height
                anchors.top: productDivider.bottom
                anchors.topMargin: 3
                width: parent.width

                model: productModel
                delegate: trackItem
                interactive: false

                Component {
                    id: trackItem

                    TrackListItem {
                        id: productLink
                        visible: (productData.type === 'musiccollection' && index === 0 ) ? false : true;

                        trackPrefix: (productData.type === 'musiccollection') ?
                                ParameterInsertion.insertParams("{0}. ", [index])
                        :
                                ParameterInsertion.insertParams("{0}. ", [index+1])
                        trackName: name
                        trackLengthInSec: (durationLength !== 'undefined') ? durationLength : 0
                        priceText: getPriceString(productModel.get(index));
                        url: trackUrl
                        trackId: dataProductID
                        variousArtists: productData.variousArtists
                        trackArtistName: artistName
                        albumName: productData.name
                        fileType: alcFormat
                        albumArtUrl: productData.albumArt100
                        alcAvailable: (productData.type === 'musiccollection' && index === 0 ) ? productData.alcAvailable : productModel.get(index).alcAvailable;
                        cwmAvailable: (productData.type === 'musiccollection' && index === 0 ) ? productData.cwmAvailable : productModel.get(index).cwmAvailable;

                        onClicked: {
                            if (musicPlayer.isPlaying && musicPlayer.currentTrack == clickedTrack.url) {
                                musicPlayer.stop();
                            } else {
                                musicPlayer.play(clickedTrack.url);
                            }
                        }
                    }
                }

            }

            BodyText {
                id: takenFromText
                visible: (productData.type == "musictrack") ? true : false
                anchors {
                    top: tracksList.bottom
                    topMargin: 10
                    left: parent.left
                    leftMargin: 16
                }
                text: qsTranslate("ProductView","t[TakenFrom")
                color: theme.tertiaryColor
            }
            TextLink {
                id: takenFromLink
                visible: (productData.type == "musictrack") ? true : false
                anchors {
                    top: takenFromText.top
                    left: takenFromText.right
                    right: parent.right
                    rightMargin: 16
                }
                font.pixelSize: 24
                text: " " + ParameterInsertion.insertParams("{0}", [productData.takenFrom]);
                onClicked: window.nextPage(productViewComponent, {dataProductID: productData.takenFromID})
            }

            GroupHeader {
                id: inspireMeHeader
                visible: (secondaryReady == true && recommendationsModel.count > 0) ? true : false
                height: (visible == false) ? 0 : childrenRect.height
                anchors.top: (productData.type == "musictrack") ? takenFromText.bottom : tracksList.bottom
                anchors.topMargin: 10
                text: qsTranslate("ProductView","t[OviRecommends")
                headerType: 'headerThree'
                background: true
                divider: true
            }

            Column {
                id: recommendationsCol
                anchors.top: inspireMeHeader.bottom
                anchors.topMargin: 8
                height: (visible == false) ? 0 : childrenRect.height
                visible: (secondaryReady == true && recommendationsModel.count > 0) ? true : false

                Repeater {
                    id: recommendationsList
                    width: parent.width
                    model: recommendationsModel
                    delegate: recommendationsItem

                }

                Component {
                    id: recommendationsItem

                    ProductLink {
                        id: productLink
                        linkText1: name
                        linkText2: artistName
                        linkText3: (type === "musictrack") ? DurationConverter.convert(durationLength) : qsTr("t[TrackCount","",trackCount)
                        packshotUrl: albumArt100
                        onClicked: window.nextPage(
                                productViewComponent,
                        {
                            name: name,
                            type: type,
                            artistName: artistName,
                            artistID: artistID,
                            variousArtists: variousArtists,
                            albumArt100: albumArt100,
                            albumArt200: albumArt200,
                            takenFrom: takenFrom,
                            takenFromID: takenFromID,
                            genre: genre,
                            genreID: genreID,
                            label: label,
                            dataProductID: dataProductID,
                            trackCount: trackCount,
                            durationLength: durationLength,
                            currencyCode: currencyCode,
                            price: price,
                            trackUrl: trackUrl,
                            streetReleaseDate: streetReleaseDate,
                            cwmAvailable: cwmAvailable,
                            cwmBitRate: cwmBitRate,
                            cwmFormat: cwmFormat,
                            alcAvailable: alcAvailable,
                            alcBitRate: alcBitRate,
                            alcFormat: alcFormat
                        });
                    }
                }
            }
        }
    }//end Flickable
}//end page
