import Qt 4.7
import "components"
import "components/asgard"
import com.nokia.qmlcomponents 1.0

Page {
    id:redeemVoucherInPurchaseOptionsView
    property variant _pinRedeemCommand;
    // Should be in same order than in RedeemCreditPinCommand::CommerceError
    property variant _errorTexts: {
        1 : "Pin code is invalid!",
        2 : "Promotion associated with pin is not active",
        3 : "Promotion associated with pin has expired.",
        4 : "Pin is associated with different territory.",
        5 : "Pin has already been redeemed.",
        6 : "Pin has already been redeemed by this user.",
        7 : "Pin has already been redeemed maximum amount of times.",
        8 : "Promotion associated with pin is of wrong type.",
        9 : "Pin promotion does not match LPG license.",
        10 : "IMEI not found in LPG.",
        11 : "Device is blacklisted.",
        12 : "Device's public id doesn't match requested public id.",
        13 : "Device has no unredeedem licenses of the specified offering types.",
        14 : "Associated promition are not active at the time.",
        15 : "Device license is associated with a different territory."
    }
    property Connections _currentConnection;

    Component {
        id: pinRedeemCommandContainer;
        Connections {
            target: _pinRedeemCommand.status;
            onStatusChanged: {
                var _status = _pinRedeemCommand.status.status;
                var _commerceError = _pinRedeemCommand.commerceError;
                console.log("***********_pinRedeemCommand.status.status: " + _status);
                console.log("***********_pinRedeemCommand.commerceError: " + _commerceError);
                if (_status == RequestStatus.Success) {
                    if (_commerceError == RedeemCreditPinCommand.NoCommerceError) {
                        morpheusSettings.setCreditBalance(_pinRedeemCommand.creditBalance);
                        var creditBalanceAfterPurchase = _pinRedeemCommand.creditBalance - context.price2;
                        if (creditBalanceAfterPurchase < 0) {
                            error.errorText = "You’ve successfully redeemed your Music voucher. You’ve now got "+ _pinRedeemCommand.creditBalance +" credit in your account for Music.You still need more credit to complete this purchase";
                            redeemVoucherInPurchaseOptionsView.state = "error";
                        }
                        else {
                            redeemVoucherInPurchaseOptionsDescription.text = "You’ve successfully redeemed your Music voucher. That means you’ve got a total of "+ _pinRedeemCommand.creditBalance +" song(s) worth of credit in your account."
                            redeemVoucherInPurchaseOptionsView.state = "readyForDownload";
                        }
                    }
                } else if (_status == RequestStatus.NetworkError) {
                    redeemVoucherInPurchaseOptionsView.state = "error";
                    error.errorText = "Network error!"
                } else if (_status == RequestStatus.RequestError) {
                    redeemVoucherInPurchaseOptionsView.state = "error";
                    error.errorText = _errorTexts[_commerceError];
                } else if (_status == RequestStatus.PermissionError) {
                    // TODO: launch SSO
                }
            }
        }
    }

    function init () {
        //break the binding to the pageStack variable
        context = context;

        console.log("Context passed through (productID): ", context.productId);
    }

    Component.onCompleted: init();

    Flickable {
        id: scrollPaign
        anchors.fill: parent
        contentWidth: childrenRect.width
        contentHeight: contentItem.activeFocuschildrenRect.height + theme.bottomPadding
        flickableDirection: Flickable.VerticalFlick
        clip: true

        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            color: 'transparent'

            GroupHeader {
                id: redeemVoucherInPurchaseOptionsViewTitleText
                headerType: 'headerOne'
                text: qsTranslate("PurchaseOptionsView","t[Title");
                width: parent.width
                anchors.top: parent.top
            }

            ProductLink {
                id: musicInfo
                anchors.top: redeemVoucherInPurchaseOptionsViewTitleText.bottom
                packshotUrl: context.productUrl
                linkText1: context.artistName
                linkText2: context.productName
                linkText3: context.price
                isLink: false
            }

            Column {
                id: redeemVoucherContent
                anchors.top:  musicInfo.bottom
                anchors.topMargin: 10
                height: childrenRect.height
                width: window.width


                Text {
                    id: redeemVoucherInPurchaseOptionsDescription
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    width: window.width
                    text: qsTranslate("PurchaseOptionsView","t[AccountMessageVoucherOnly");
                    wrapMode: "WordWrap"
                }

                ErrorText{
                    id: error
                    opacity: 0
                    anchors.top: redeemVoucherInPurchaseOptionsDescription.bottom
                    anchors.topMargin: 16
                    errorText: "<error message to be placed here>"
                }

                CommonSingleInputField{
                    id: voucherInputField
                    anchors.top: redeemVoucherInPurchaseOptionsDescription.bottom
                    anchors.topMargin: 16

                }

                Grid {
                    id: pinEntryButtonGrid
                    anchors.top: voucherInputField.bottom
                    anchors.topMargin: 16
                    anchors.left: parent.left
                    anchors.leftMargin: 16
                    spacing: 10

                    Button {
                        id: redeemButton
                        text: qsTranslate("PinEntryView","t[RedeemButtonText")
                        onClicked: {

                            console.log("PIN: " + voucherInputField.pinEntered);
                            redeemVoucherInPurchaseOptionsView.state = "wait"

                            if (_currentConnection != undefined) {
                                _currentConnection.destroy();
                            }
                            _pinRedeemCommand = store.account.redeemCreditPin(voucherInputField.pinEntered);
                            _currentConnection = pinRedeemCommandContainer.createObject(redeemVoucherInPurchaseOptionsView);
                        }
                    }

                    Button {
                        id: cancelPurchaseOptions
                        text: "Cancel"
                        onClicked: {
                            window.back()
                        }

                    }

                }

                Spinner {
                    id: spinner
                    visible : false
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.top: voucherInputField.bottom
                    anchors.topMargin: 16
                    dimension: 170
                }

                Button {
                    id: startDownloadButton
                    text: "Start Download"
                    anchors.top : pinEntryButtonGrid.bottom
                    anchors.horizontalCenter: redeemVoucherContent.horizontalCenter
                    opacity: 0
                    onClicked: {
                            console.log("StartDownloadButton clicked !");
                            console.log("dataProductID: " +context.productId);
                            window.loadPage(productViewComponent, {dataProductID: context.productId, execute: "startDownload", productType: context.productType});
                    }
               }

            }

        }

    }

    states : [
        State {
                name : "wait"
                PropertyChanges { target: redeemVoucherInPurchaseOptionsDescription; opacity: 0}
                PropertyChanges { target: error; opacity: 0}
                PropertyChanges { target: voucherInputField; opacity: 0}
                PropertyChanges { target: pinEntryButtonGrid; opacity: 0}
                PropertyChanges { target: startDownloadButton; opacity: 0}
                PropertyChanges { target: spinner; visible: true}
        },

        State {
                name : "error"
                PropertyChanges { target: redeemVoucherInPurchaseOptionsDescription; opacity: 0}
                PropertyChanges { target: error; anchors.top: redeemVoucherInPurchaseOptionsDescription.top}
                PropertyChanges { target: error; opacity: 1}
                PropertyChanges { target: voucherInputField; anchors.top: error.bottom}
                PropertyChanges { target: voucherInputField; opacity: 1}
                PropertyChanges { target: pinEntryButtonGrid; opacity: 1}
                PropertyChanges { target: startDownloadButton; opacity: 0}
        },

        State {
                name : "readyForDownload"
                PropertyChanges { target: redeemVoucherInPurchaseOptionsDescription; opacity: 1}
                PropertyChanges { target: error; opacity: 0}
                PropertyChanges { target: voucherInputField; opacity: 0}
                PropertyChanges { target: pinEntryButtonGrid; opacity: 0}
                PropertyChanges { target: startDownloadButton; opacity: 0}
                PropertyChanges { target: spinner; opacity: 0}
                PropertyChanges { target: startDownloadButton; opacity: 1}
        }
    ]

}
