import Qt 4.7

import "components"
import "components/asgard"
import "../javascript/APIWrapper.js" as API
import "../javascript/durationConverter.js" as DurationConverter

Page {
    id: rightsView
    property string title: 'rightsView'

    property date releaseDate: context.streetReleaseDate;
    
    //break the binding to the pageStack variable
    Component.onCompleted: context = context;

    Flickable {
        id: flick
        anchors.fill: parent
        contentWidth: contentItem.childrenRect.width
        contentHeight: contentItem.childrenRect.height
        flickableDirection: Flickable.VerticalFlick
        clip: true

        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            color: 'transparent'

            GroupHeader {
                id: rightsHeader
                headerType: 'headerTwo'
                topMargin: 16;
                text: context.name
            }
            GroupHeader {
                id: infoHeader
                headerType: 'headerThree'
                divider: true
                background: true
                anchors.top: rightsHeader.bottom
                anchors.topMargin: 16
                text: qsTranslate("RightsView","t[Information");
            }


            Column {
                id: infoTable
                property int labelColumnWidth: 220
                property int labelColumnFontSize: 26
                property bool labelColumnBold: true
                property int valueColumnFontSize: 24
                spacing: 30
                anchors {
                    top: infoHeader.bottom
                    left: parent.left
                    right: parent.right
                    margins: 16
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Title") + ":";
                    }
                    BodyText {
                        text: context.name
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Artist") + ":";
                    }
                    // Repeater
                    TextLink {
                        text: context.artistName
                        font.pixelSize: infoTable.valueColumnFontSize
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                        onClicked: window.nextPage(artistViewComponent, {artistId: context.artistID, artistName: context.artistName});
                    }
                }

                Row {
                    height: (visible === false) ? 0 : undefined
                    visible: (context.type === "musictrack") ? false : true

                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Songs") + ":";
                    }
                    BodyText {
                        id: songCount
                        text: context.trackCount
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    height: (visible === false) ? 0 : undefined
                    visible: (context.type === "musiccollection") ? false : true

                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Length") + ":";
                    }
                    BodyText {
                        id: songLength
                        text: DurationConverter.convert(context.durationLength)
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    height: (visible === false) ? 0 : undefined
                    visible: (context.type === "musiccollection") ? false : true

                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[TakenFrom") + ":";
                    }
                    TextLink {
                        id: takenFrom
                        text: context.takenFrom
                        font.pixelSize: infoTable.valueColumnFontSize
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                        onClicked: window.nextPage(productViewComponent, {dataProductID: context.takenFromID})
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Released") + ":";
                    }
                    BodyText {
                        text: Qt.formatDate(releaseDate,"MMMM yyyy");
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Genre") + ":";
                    }
                    TextLink {
                        text: context.genre
                        wrapMode: "Wrap"
                        font.pixelSize: infoTable.valueColumnFontSize
                        width: parent.width - infoTable.labelColumnWidth - 16
                        onClicked: window.nextPage(genreHomeViewComponent, {genreName: context.genre, genreId: context.genreID});
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Label") + ":";
                    }
                    BodyText {
                        text: context.label
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[FileType") + ":";
                    }
                    BodyText {
                        wrapMode: "Wrap"
                        font.capitalization: Font.AllUppercase
                        text: context.alcFormat
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[BitRate") + ":";
                    }
                    BodyText {
                        wrapMode: "Wrap"
                        //font.capitalization: Font.AllUppercase
                        text: context.alcBitRate + qsTranslate("RightsView","t[Kbps");
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

            } // end infoTable

            GroupHeader {
                id: purchaseRightsHeader
                headerType: 'headerThree'
                divider: true
                background: true
                anchors.top: infoTable.bottom
                anchors.topMargin: 16
                text: qsTranslate("RightsView","t[PurchaseRights");
            }

            Column {
                id: purchaseRightsTable
                property int labelColumnWidth: 190
                property int labelColumnFontSize: 26
                property bool labelColumnBold: true
                spacing: 30
                anchors {
                    top: purchaseRightsHeader.bottom
                    left: parent.left
                    right: parent.right
                    margins: 16
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[TransferRights") + ":";
                    }
                    BodyText {
                        text: qsTranslate("RightsView","t[Unlimited");
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[BurnToCD") + ":";
                    }
                    BodyText {
                        text: qsTranslate("RightsView","t[Unlimited");
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

                Row {
                    width: parent.width
                    BodyText {
                        width: infoTable.labelColumnWidth
                        font.pixelSize: infoTable.labelColumnFontSize
                        font.bold: infoTable.labelColumnBold
                        elide: "ElideRight"
                        text: qsTranslate("RightsView","t[Plays") + ":";
                    }
                    BodyText {
                        text: qsTranslate("RightsView","t[Unlimited");
                        wrapMode: "Wrap"
                        width: parent.width - infoTable.labelColumnWidth - 16
                    }
                }

            }// end rightsTable

        }
    }
}
