import Qt 4.7
import "components"
import "components/asgard"
import "../javascript/durationConverter.js" as DurationConverter
import com.nokia.qmlcomponents 1.0

Page {
    id: searchView
    objectName: "search"

    property int itemsPerPage: 50;
    property string noResultsSearchTxt;
    property string didYouMeanTxt: '';

    property bool primaryRequestCompleted: false;

    function search(searchTxt) {
        console.log("Search page searching: " + searchTxt);
        searchRequest.searchText = searchTxt;
        searchView.noResultsSearchTxt = searchTxt;
        searchRequest.itemsPerPage = itemsPerPage;
        searchResults.model = store.search(searchRequest);
        modelStatusListener.target = searchResults.model.status;
        primarySpinner.visible = true;
        primaryRequestCompleted = false;
    }

    SearchRequest {
        id: searchRequest
    }

    TextField {
        id:searchInput
        objectName: "searchInput"

        placeholderText: qsTranslate("SearchView","t[SearchMusic")
        anchors {
            top: searchView.top
            left:  parent.left
            right: parent.right
            margins: 15
            topMargin: 18
        }
        maximumLength: 200
        actionButtonEnabled: (text != "") ? true : false
        iconSource: (text != "") ? "../images/inputMethodClear.png" : ""
        onActionButtonClicked: {
            searchInput.text = "";
            searchResults.model = undefined;
            searchView.didYouMeanTxt = '';
            textEditElement.focus = true;
        }

        Keys.onPressed: {
            if (event.key == Qt.Key_Enter || event.key == Qt.Key_Return) {
                textEditElement.closeSoftwareInputPanel();
                textEditElement.focus = false;
            }
        }
        onAccepted: {
            var trimmed = searchInput.text.replace(/^\s+|\s+$/g, '') ;
            if (trimmed != "") {
                search(trimmed);
            }
        }
    }

    Component.onCompleted: {
        if (searchInput.text === '') {
            searchInput.textEditElement.focus = true;
        }
    }

    onDeactivating: {
        searchInput.textEditElement.closeSoftwareInputPanel();
        searchInput.textEditElement.focus = false;
    }


    BodyText {
        id: noResultText
        anchors {
            top: searchInput.bottom
            left: parent.left
            right: parent.right
            margins: 16
        }
        text: (searchView.didYouMeanTxt === '') ? qsTranslate("SearchView","t[NoMacthes").arg('<b>' + searchView.noResultsSearchTxt + '</b>') : qsTranslate("SearchView","t[NoExactMacthes").arg('<b>' + searchView.noResultsSearchTxt + '</b>')
        wrapMode: Text.WordWrap
        visible: {
            if (!searchResults.model) {
                false;
            } else if(searchResults.model.count === 0 && primarySpinner.visible === false) {
                true;
            } else {
                false;
            }

        }
    }


    GroupHeader {
        id: resultsHeader
        anchors.top: (noResultText.visible === true) ? noResultText.bottom : searchInput.bottom
        anchors.topMargin: 10
        text: searchView.didYouMeanTxt ? qsTranslate("SearchView","t[DidYouMean") : qsTranslate("SearchView","t[Results")
        headerType: 'headerThree'
        background: true

        divider: true
        visible: {

            if (!searchResults.model) {
                false
            } else if (searchView.didYouMeanTxt !== '' || searchResults.model.count > 0) {
                true
            } else {
                false
            }
        }
    }

    ListItem {
        id: didYouMean
        anchors.top: resultsHeader.bottom
        anchors.topMargin: 3
        width: parent.width
        linkText1: searchView.didYouMeanTxt
        visible: (searchView.didYouMeanTxt !== '')
        z: 999

        onClicked: {
            searchInput.text = searchView.didYouMeanTxt;
            searchView.search(searchView.didYouMeanTxt);
            searchView.didYouMeanTxt = '';
        }
    }

    Connections {
        id: modelStatusListener
        target: null
        onChanged: {
            console.log("Search Model Changed Status: " + searchResults.model.status.status);
            if (searchResults.model.status.status === RequestStatus.Success) {
                primarySpinner.visible = false;
                primaryRequestCompleted = true;
                //getMoreSpinner.visible = false;
                //getMoreSpinnerContainer.height = 0;
                console.log('*'+ searchResults.model.searchSuggestion+'*');
                searchView.didYouMeanTxt = searchResults.model.searchSuggestion;
                console.log(searchView.didYouMeanTxt);
            } else if (searchResults.model.status.status === RequestStatus.DataError || searchResults.model.status.status === RequestStatus.RequestError || searchResults.model.status.status === RequestStatus.UnknownError || searchResults.model.status.status === RequestStatus.NetworkError) {
                //if this is the first request, throw an error, otherwise ignore
                if (primaryRequestCompleted === false) {
                    window.showError();
                }
            }
        }
    }


    ListView {
        id: searchResults
        delegate: searchDelegate
        anchors.top: resultsHeader.bottom
        anchors.topMargin: 3
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        clip: true;
        contentHeight: contentItem.childrenRect.height

        Spinner {
            id: primarySpinner
            anchors.centerIn: parent
            dimension: 170
            displayLatency: 500
            visible: false
        }
    }


    /*
    Rectangle {
        id: getMoreSpinnerContainer
        width: parent.width
        color: 'transparent'
        height: 0
        anchors.bottom: parent.bottom


        Spinner {
            id: getMoreSpinner
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            dimension: 100            
            displayLatency: 500
            visible: (parent.height > 0)
        }
    }
    */

    property int total: 0
    property int i: 0

    Component{
        id: searchDelegate
        Rectangle {
            id: searchItem
            width: parent.width
            height: (item.type !== "musicartist") ? 116 : 64
            color: 'transparent'

            Component.onCompleted: {
                total++;
                console.log(total);
                i++;
                if(i >= itemsPerPage - 10){
                    console.log("Get More Items ...  ");
                    searchResults.model.getMore();
                    //getMoreSpinnerContainer.height = 100;
                    i=0;
                }
            }

            ProductLink {
                id: prod1
                linkText1: item.name
                linkText2: item.artistName
                linkText3: (item.type === "musictrack") ? DurationConverter.convert(item.duration) : qsTr("t[TrackCount","",item.trackCount)
                packshotUrl: item.albumArt100

                height: (visible) ? 116 : 0
                visible: (item.type !== "musicartist")

                onClicked:
                        window.nextPage(
                                productViewComponent,
                {
                    dataProductID: item.id,
                    name: item.name,
                    type: item.type,
                    artistName: item.artistName,
                    artistID: item.artistId,
                    variousArtists: item.variousArtists,
                    albumArt100: item.albumArt100,
                    albumArt200: item.albumArt200,
                    takenFrom: item.takenFrom,
                    takenFromID: item.takenFromId,
                    genre: item.genre.title,
                    genreID: item.genre.id,
                    label: item.label,
                    trackCount: item.trackCount,
                    durationLength: item.duration,
                    price: item.priceValue,
                    currencyCode: item.priceCurrency,
                    trackUrl: item.wmaClip || "",
                    streetReleaseDate: item.streetReleaseDate,
                    cwmAvailable: item.cwmAvailable,
                    cwmBitRate: item.cwmBitRate,
                    cwmFormat: item.cwmFileType,
                    alcAvailable: item.alcAvailable,
                    alcBitRate: item.alcBitRate,
                    alcFormat: item.alcFileType
                    
                });

            }

            ListItem {
                id: prod2
                width: searchItem.width
                linkText1: name
                visible: (item.type === "musicartist")
                height: (visible) ? 64 : 0

                onClicked:
                        window.nextPage(
                                artistViewComponent,
                {artistId: item.artistId,
                    artistName: item.artistName});
            }           
        }

    }
}
