import Qt 4.7

import "components"
import "components/asgard"
import "../javascript/APIWrapper.js" as API

Page {
    id: similarArtistsView
    property string title: qsTranslate("SimilarArtistsView","t[PageTitle")
    objectName: "similar artists"

    property bool primaryReady: false;

    function primaryCb () {
        primaryReady = true;
    }

    function primaryEb (errorMessage, xhrObj) {
        if (typeof xhrObj == "object" && xhrObj.status == 404) {
            console.log("404 status is acceptable for this request, indicates 0 results");
            console.log("There were no similar artists found");
            primaryReady = true;
        } else {
            window.showError(context.artistName);
        }
    }
    
    //break the binding to the pageStack variable
    Component.onCompleted: context = context;

    ListModel {
        id: similarArtistsModel
        Component.onCompleted: {
            var similarArtistsURI = API.getSimilarArtistsURI(context.artistId);
            API.loadSimilarArtists(similarArtistsURI, similarArtistsModel, primaryCb, primaryEb);
        }
    }

    Flickable {
        id: flick
        anchors.fill: parent
        contentWidth: contentItem.childrenRect.width;
        contentHeight: contentItem.childrenRect.height + theme.bottomPadding
        flickableDirection: Flickable.VerticalFlick
        clip: true

        //View header
        GroupHeader {
            id: similarArtistsViewHeaderPanel
            headerType: 'headerTwo'
            topMargin: 10
            text: context.artistName
        }


        //Primary load indication
        Item {
            height: (visible) ? window.height : 0
            width: window.width
            visible: !primaryReady

            Spinner {
                id: primarySpinner
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                dimension: 170
                visible: !primaryReady
            }
        }


        //View contents
        Rectangle {
            id: viewRoot
            height: childrenRect.height
            width: window.width
            anchors.top: similarArtistsViewHeaderPanel.bottom
            anchors.topMargin: 10
            color: 'transparent'
            visible: primaryReady

            GroupHeader {
                id: similarArtistsHeader
                text: qsTranslate("SimilarArtistsView","t[SimilarArtists")
                headerType: 'headerThree'
                background: true
                divider: true
            }

            Column {
                id: similarArtistsColumn
                anchors.top: similarArtistsHeader.bottom
                anchors.topMargin: 3
                height: childrenRect.height
                width: parent.width

                Repeater {
                    id: similarArtistsList
                    model: similarArtistsModel
                    width: parent.width

                    ListItem {
                        id: similarArtistComponent
                        linkId: artistId
                        linkText1: artistName
                        width: similarArtistsList.width
                        onClicked: window.nextPage(artistViewComponent, {artistName: linkText1, artistId: linkId});
                    }
                }
            }

            BodyText {
                id: noArtistsText
                anchors {
                    top: similarArtistsHeader.bottom
                    left: parent.left
                    right: parent.right
                    margins: 16
                }
                width: parent.width - 32
                wrapMode: Text.WordWrap
                text: qsTranslate("SimilarArtistsView","t[NoResults")
                visible: (similarArtistsModel.count < 1 && primaryReady == true) ? true : false
            }
        }
    }
}
