import Qt 4.7

// Dropdown Item
Rectangle {

    property ListModel dropDownModel
    property string headerText: ""

    property int backgroundWidth
    property int backgroundHeight
    property int yOffset
    signal clickedOn
    signal clickedOff
    property alias dropDownDelegate: dropDownList.delegate
    property alias dropDownVisible: dropdownContainer.visible

    property int selectedIndex

    id: dropDownComponent
    z: 100
    color: 'transparent'
    state: window.state

    states: [
        State {
            name: "Landscape"
            PropertyChanges {
                target: dialogContent
                height: 330
            }
        },
        State {
            name: "Portrait"
            PropertyChanges {
                target: dialogContent
                height: 650
            }
        },
        State {
            name: "LandscapeInverted"
            extend: "Landscape"
        },
        State {
            name: "PortraitInverted"
            extend: "Portrait"
        }
    ]

    Rectangle {
        id: dropdownContainer

        visible: dropDownVisible
        height: backgroundHeight
        width: backgroundWidth
        y: yOffset
        x: 0
        color: Qt.rgba(0, 0, 0, 0.95)

        MouseArea {
            anchors.fill: parent
            onClicked: {
                dropdownContainer.visible = false;
                dropDownComponent.clickedOff();
            }
        }


        Rectangle {
            id: contextWrapper
            color: 'transparent'
            height: childrenRect.height
            width: dialogContent.width
            anchors.centerIn: parent


            Text {
                id: contentHeader
                text: headerText
                anchors {
                    top: contextWrapper.top
                    left: dialogContent.left
                    leftMargin: 8
                    right: dialogContent.right
                    rightMargin: dialogClose.width + 16
                }
                verticalAlignment:Text.AlignVCenter
                height: (headerText === "") ? 0 : 48

                elide: Text.ElideRight
                font.pixelSize: 32
                font.family: theme.primaryFont
                color: theme.themeColor


                Image {
                    id: dialogClose
                    source: "../../images/dialogClose.png"
                    anchors.right: parent.right
                    anchors.rightMargin: - width - 8
                    anchors.verticalCenter: parent.verticalCenter
                }

            }

            Rectangle {
                id: dialogContent
                width: 448; height: 330
                anchors.top: contentHeader.bottom
                //anchors.centerIn: parent
                color: 'transparent'

                Rectangle {
                    height: 1
                    width: parent.width
                    color: theme.themeColor
                }

                ListView {
                    id: dropDownList
                    height: parent.height - 8
                    width:  parent.width
                    contentWidth: childrenRect.width
                    contentHeight: childrenRect.height
                    flickableDirection: Flickable.VerticalFlick
                    anchors.centerIn: parent
                    clip: true
                    interactive: true

                    model: dropDownModel
                    delegate: dropDownDelegate
                    highlight: Rectangle {
                        gradient: Gradient {
                            GradientStop { position: 0.0; color: "#e8188b" }
                            GradientStop { position: 1.0; color: "#ee47a0" }
                        }
                    }
                    highlightMoveDuration : 1
                    focus: true
                    currentIndex: selectedIndex
                }

                Rectangle {
                    height: 1
                    width: parent.width
                    color: theme.themeColor
                    anchors.top: parent.bottom
                }
            }
        }
    }
}
