/**
  * Divider prodives the divider styles from the Meego toolkit.
  * Possible values for dividerType are:
  *     - groupDivider (default)
  *     - itemDivider
  *
  * itemDivider can either have padding on the the left and right in the toolkit,
  * padding is set as the defult in this mode, to have a full width itemDivider set:
  *     - padding: 0 (8 is as the toolkit specifies i.e. 4 on each side)
  *
  */

import Qt 4.7

Rectangle {
    id: container
    property alias dividerType: container.state
    state: 'groupDivider'
    property int padding: 8
    width: parent.width
    height: 9
    color: "transparent"

    Rectangle {
        id: divider
        y: 4.5
        height: 1
        anchors.left: parent.left
        anchors.right: parent.right
        color: "#b3b4b5"
    }

    Rectangle {
        id: leftBlob
        anchors.left: container.left
        anchors.leftMargin: -3
        anchors.verticalCenter: parent.verticalCenter
        height: 6
        width: 6
        radius: 3
        color: "#000000"
    }

    Rectangle {
        id: rightBlob
        anchors.right: container.right
        anchors.rightMargin: -3
        anchors.verticalCenter: parent.verticalCenter
        height: 6
        width: 6
        radius: 3
        color: "#000000"
    }

    states: [
        State {
            name: "groupDivider"
            PropertyChanges { target: leftBlob; visible: true;}
            PropertyChanges { target: rightBlob; visible: true;}
            PropertyChanges { target: container; height: 9;}
            PropertyChanges {
                target: divider
                color: '#b3b4b5'
                y: 4.5
            }
        },
        State {
            name: "itemDivider"
            PropertyChanges { target: leftBlob; visible: false;}
            PropertyChanges { target: rightBlob; visible: false;}
            PropertyChanges { target: container; height: 1;}
            PropertyChanges {
                target: divider
                anchors.leftMargin: padding
                anchors.rightMargin: padding
                color: '#dddfe0'
                y: 0
            }
        }
    ]

}
