import Qt 4.7
import "../../javascript/downloadUtils.js" as Utils
import MusicDownload 1.0
import NetworkMonitor 1.0


Item {
    id: downloadEngine

    property string downloadLocation: morpheusSettings.downloadLocation
    property variant downloadData: "initValue"
    /* downloadData contains track specific download data:
       downloadData[productId]: {
            status: "statusString",
            downloadItem: {
                productId: "productIdString",
                itemState: "itemStateString",
                downloadUrl: "downloadUrlString",
                artistName: "artistNameString",
                albumName: "albumNameString",
                trackName: "trackNameString",
                fileType: "fileTypeString",
                trackPlayUrl: "trackPlayUrlString",
                albumArtUrl: "albumArtUrlString",
                addedToDownloadCounter: addedToDownloadCounterBoolean
            }
        }
    */
    property variant albumDownloadData: "initValue"
    /* albumDownloadData contains album specific download data
       albumDownloadData[albumProductId]: {
            status: "statusString",
            tracks: [
                "productIdString",
                ...
            ]
       }
    */
    property int totalDownloads: 0 // total number of downloads, needed for showing count in menu
    property variant downloadStates : {
        0 : "normal",
        1 : "wait",
        2 : "play",
        3 : "disabled",
        4 : "temporarilyDisabled",
        5 : "queuingDownload",
        6 : "albumDownloadOnlyTrack"
    }


    /** Called on track list download button click. Sets TUI metadata and starts track download flow.
      * @param {String} productId - catalogue id
      * @param {Object} productData - details needed for MusicDownload
      */
    function downloadTrack (productId, productData) {
        _createDownloadItem(productId, productData, false);
    }

    /** Called on album download button click.
      * @param {String} albumProductId - album catalogue id
      * @param {Object} albumProductData - details needed for DownloadManager
      */
    function downloadAlbum (albumProductId, albumProductData) {
        _splitAlbumDataForDownload(albumProductData);
    }

    /** UI helper for album and related download button states, stores album id and related tracks id's.
      * Called at the start of the album download flow.
      * @param {String} albumProductId - catalogue id
      * @para, {ListModel} albumTrackListModel - generated in ProductView
      */
    function addAlbumDownloadData (albumProductId, albumTrackListModel) {
        var i, trackCount, albumData = {};
        trackCount = albumTrackListModel.count;
        albumData.tracks = new Array();
        console.log("DownloadEngine -> Adding album track productId's to albumDownloadData");
        for (i = 0; i < trackCount; i++) {
            var trackData = {};
            trackData.productId = albumTrackListModel.get(i).productId;
            trackData.alcAvailable = albumTrackListModel.get(i).alcAvailable;
            albumData.tracks[i] = trackData;

            console.log("albumData.tracks[i].productId: " + albumData.tracks[i].productId);
            console.log("albumData.tracks[i].alcAvailable: " + albumData.tracks[i].alcAvailable);
            updateTrackStatusData(albumData.tracks[i].productId, downloadStates[5]); // "queuingDownload"
        }
        albumData.status = downloadStates[5]; // "queuingDownload"
        Utils.updateTempAlbumDownloadData(albumProductId, albumData);
        albumDownloadData = Utils.tempAlbumDownloadData;
    }

    /** Updates the track status stored in downloadData property
      * @param {String} productId - catalogue Id
      * @param {String} status - status string defined in property variant downloadStates
      */
    function updateTrackStatusData (productId, status) {
        var data = {};
        if (Utils.tempDownloadData.hasOwnProperty(productId)) {
            data = Utils.tempDownloadData[productId];
        }
        data.status = status;
        Utils.updateTempDownloadData(productId, data);
        downloadData = Utils.tempDownloadData;
        console.log("DownloadEngine -> Updating downloadData, productId: " + productId + ", status: " + data.status);
    }

    /** Updates album status and album's track statuses
      * @param {String} albumProductId - catalogue id
      * @param {String} albumStatus - status string defined in property variant downloadStates
      * @param {String} trackStatus - status string defined in property variant downloadStates
      */
    function updateAlbumStatusData(albumProductId, albumStatus, trackStatus) {
        var data = {}, trackCount, trackData, i;
        if (Utils.tempAlbumDownloadData.hasOwnProperty(albumProductId)) {
            data = Utils.tempAlbumDownloadData[albumProductId];
        }
        data.status = albumStatus;
        Utils.updateTempAlbumDownloadData(albumProductId, data);
        albumDownloadData = Utils.tempAlbumDownloadData;
        console.log("DownloadEngine -> Updating albumDownloadData, productId: " + albumProductId + ", status: " + data.status);

        // Update album's track statuses
        trackData = albumDownloadData[albumProductId].tracks;
        trackCount = trackData.length;
        for (i = 0; i < trackCount; i++) {
            if (trackData[i].alcAvailable === "false" && trackStatus === "normal") {
                // Set instead to default state for album dowload only tracks
                trackStatus = downloadStates[6]; // "albumDownloadOnlyTrack"
            }
            updateTrackStatusData(trackData[i].productId, trackStatus);
        }
    }

    /** Calls MusicDownload API to display TransferUI
      */
    function showTransferUi() {
        console.log("Show TransferUI");
        var rtnvalue = downloadManagement.showTransferUi();
        console.log("The transfer is shown = " + rtnvalue);
    }

    /** Calls MusicDownload API to set the download metadata to TransferUI
      * @param {String} productId - catalogue id of a song or album
      * @param {String} productDescription - description to be shown in TUI
      * @param {String} albumArtUrl
      * @param {Boolean} canPause - true if download can be paused through TUI false otherwise
      */
    function _publishDownloadToTUI (productId, productDescription, albumArtUrl, canPause) {
        console.log("DownloadEngine -> Publishing download to TUI");
        console.log("TUI productId: " + productId);
        console.log("TUI productDescription: " + productDescription);
        console.log("TUI albumArtUrl: " + albumArtUrl);
        console.log("TUI canPause: " + canPause);
        downloadManagement.setTransferUiMetadata(
            productId,
            productDescription,
            albumArtUrl,
            canPause
        );
    }

    /** Splits track details from albumProductData
      * @param {Object} albumProductData - details needed for MusicDownload
      */
    function _splitAlbumDataForDownload (albumProductData) {
        var i, currentTrackItem, trackCount, productData = {};
        trackCount = albumProductData.trackListModel.count;
        for (i = 0; i < trackCount; i += 1) {
            currentTrackItem = albumProductData.trackListModel.get(i);
            productData.downloadUrl = albumProductData.downloadUrls[currentTrackItem.productId];
            productData.artistName = albumProductData.artistName;
            productData.albumName = albumProductData.albumName;
            productData.trackName = currentTrackItem.name;
            productData.fileType = currentTrackItem.fileType;
            productData.albumArtUrl = albumProductData.albumArtUrl;

            _createDownloadItem(currentTrackItem.productId, productData, true);
        }
    }

    /** Creates instance of DownloadItem component for each download
      * @param {String} productId - catalogue id
      * @param {Object} productData - details needed for MusicDownload
      * @param {Boolean} isAlbumDownload - true if is an album, false is if a track
      */
    function _createDownloadItem (productId, productData, isAlbumDownload) {
        var component = Qt.createComponent("DownloadItem.qml");
        if (component.status == Component.Ready) {
            var downloadItem = component.createObject(downloadEngine);
            downloadItem.productId = productId;
            downloadItem.downloadUrl = productData.downloadUrl;
            downloadItem.artistName = productData.artistName;
            downloadItem.albumName = productData.albumName;
            downloadItem.trackName = productData.trackName;
            downloadItem.fileType = productData.fileType;
            downloadItem.albumArtUrl = productData.albumArtUrl;
            downloadItem.addedToDownloadCounter = false;
            _addDownloadData(productId, downloadItem, isAlbumDownload);
        }
    }

    /* Add download details to downloadData
     * @param {String} productId - catalogue id
     * @param {DownloadItem} dynamically created DownloadItem instance
     * @param {Boolean} isAlbumDownload - true if is an album, false is if a track
     */
    function _addDownloadData (productId, downloadItem, isAlbumDownload) {
        var productData = {};
        if (isAlbumDownload) {
            productData.status = downloadStates[5]; // "queuingDownload"
        } else {
            productData.status = downloadStates[1]; // "wait"
        }
        productData.downloadItem = downloadItem;
        Utils.updateTempDownloadData(productId, productData);
        downloadData = Utils.tempDownloadData;
        _startDownload(productId);
    }

    /* Call MusicDownload to start download
     * @param productId - catalogue id
     */
    function _startDownload (productId) {
        var downloadPath = _getDownloadPath(productId);
        var fileName = _getFileName(productId);
        console.log("DownloadEngine: Starting download -> productId: " + productId + ", downloadPath: " + downloadPath + ", fileName: " + fileName);
        downloadManagement.add(
            productId,
            downloadData[productId].downloadItem.downloadUrl,
            downloadPath,
            fileName
        );
    }

    /* Generates download location from artist name and album name
     * @param {String} productId
     * @returns {String} path to download folder
     */
    function _getDownloadPath (productId) {
        return downloadLocation + "/" +
            downloadData[productId].downloadItem.artistName + "/" +
            downloadData[productId].downloadItem.albumName + "/";
    }

    /* Generates download filename and file type from track name and user type
     * @param {String} productId
     * @returns {String} filename
     */
    function _getFileName (productId) {
        return downloadData[productId].downloadItem.trackName + "." +
            downloadData[productId].downloadItem.fileType;
    }

    /* Determine is error returned from MusicDownload an error
     * @param {int} errorCode
     * @returns {Boolean} true if is error, false otherwise
     */
    function _isDownloadError (errorCode) {
        if (errorCode > 0) {
            return true;
        } else {
            return false;
        }
    }


    /** On Morpheus start-up:
      * - Check amount of ongoing download from MusicDownload and publish that to toolbar.
      * - Set default album art to be used in TUI.
      */
    Component.onCompleted: {
        totalDownloads = downloadManagement.restore();
        console.log("DownloadEngine -> Restore the downloads when morpheus started.");
        console.log("DownloadEngine -> Active downloads are: " + totalDownloads);
        var defaultAlbumArtSet = downloadManagement.setDefaultIcon('/usr/share/morpheus/images/imagePlaceHolder.png');
        console.log("DownloadEngine -> Set default album art for TUI: " + defaultAlbumArtSet);
    }

    MusicDownload {
        id: downloadManagement

        onAdded: {
            console.log("DownloadManagement -> Download added, " + aProductId + ": " + aFullPath + "/" + aUniqueName);
            stopAndRemoveProfiler("wait-dlmanager-onAdded");

            _publishDownloadToTUI(
                aProductId,
                downloadData[aProductId].downloadItem.artistName + " - " + downloadData[aProductId].downloadItem.trackName,
                downloadData[aProductId].downloadItem.albumArtUrl,
                false
            );

            downloadData[aProductId].downloadItem.itemState = downloadStates[1];
            downloadData[aProductId].downloadItem.trackPlayUrl = "file://" + aFullPath + "/" + aUniqueName;

            /* If download is redirected in backend server, added signal is sent also for redirection.
               We need to increase counter only once for one download */
            if (downloadData[aProductId].downloadItem.addedToDownloadCounter === false) {
                totalDownloads ++;
                downloadData[aProductId].downloadItem.addedToDownloadCounter = true;
                console.log("DownloadManagement -> onAdded: Increase the totalDownloads when download starts: " + totalDownloads);
            }
        }

        onProgress: {
            console.log("DownloadManagement -> Downloading, productId: " + aProductId + ", progress: " + aProgress);
            stopAndRemoveProfiler("wait-first-progress");
        }

        onPaused: {
            console.log("DownloadManagement -> Download paused, productId: " + aProductId + ", Error: " + _isDownloadError(aError) + ", " + aError);

            if (downloadData[aProductId]) {
                if (_isDownloadError(aError)) {
                    console.log("DownloadManagement -> Error occured, download is paused! ProductId: " +
                                aProductId + ", trackName: " + downloadData[aProductId].downloadItem.trackName);
                }
            }
        }

        onCancelled: {
            console.log("DownloadManagement -> Download cancelled, productId: " + aProductId);

            if (downloadData[aProductId]) {
                downloadData[aProductId].downloadItem.itemState = downloadStates[0];
            }

            if(totalDownloads >= 1) {
                totalDownloads --;
            }

            console.log("DownloadManagement -> onCancelled: Decrease the totalDownloads when download is cancelled " + totalDownloads);
        }

        onCompleted: {
            console.log("DownloadManagement -> Download completed, productId: " + aProductId + ", Error: " + _isDownloadError(aError) + ", " + aError);
            stopAndRemoveProfiler("wait-track-download-complete");
            if (downloadData[aProductId]) {
                if (_isDownloadError(aError)) {
                    // TODO: Throw to Error page?
                    console.log("DownloadManagement -> Error occured, download is completed! ProductId: " +
                                aProductId + ", trackName: " + downloadData[aProductId].downloadItem.trackName);
                    console.log("TODO: Handle DownloadManager internal errors");
                } else {
                    downloadData[aProductId].downloadItem.itemState = downloadStates[2];
                }
            }

            if(totalDownloads >= 1) {
                totalDownloads --;
            }

            console.log("DownloadManagement -> onCompleted: Decrease the totalDownloads when download completes " + totalDownloads);
        }
    } // end MusicDownload

    NetworkMonitor {
        id: networkMonitor
        onOnlineStateChanged: {
            if (online) {
                console.log("Resume all downloads");
                downloadManagement.resumeAll();
            }
        }
    } // end NetworkMonitor
}
