/**
* GroupHeader provides the header styles from the Meego toolkit.
  * Possible values for headerType are:
  *     - headerOne
  *     - headerTwo
  *     - headerThree
  *     - headerFour
  *
  * All these header can come with or without a divider, this is provided by setting:
  *     - divider: true/false
  *
  * headerthree and headerFour can also have a background color in the toolkit which is specified by:
  *     - background: true/false
  *
  */

import Qt 4.7

Rectangle {
    id: outerContainer
    width: parent.width
    property alias text: headerText.text
    property bool background: false
    property bool divider: false
    property alias headerType: outerContainer.state
    property int topMargin
    state: "headerOne"
    height: childrenRect.height
    color: "transparent"


    Divider {
        id: headerDivider
        anchors.top: outerContainer.top
        visible: (divider === true) ? true : false
        z: 5
    }

    Rectangle {
        id: container
        anchors.top: (divider === true) ? headerDivider.bottom : outerContainer.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.topMargin: (background === true) ? -4 : 0
        color: (background === true) ? "#dddfe0" : "transparent"

        Text {
            id: headerText
            text: text
            font.family: theme.primaryFont
            color: theme.primaryColor
            elide: Text.ElideRight

            anchors {
                left: parent.left
                right: parent.right
                leftMargin: 16
                rightMargin: 16
                verticalCenter: parent.verticalCenter

            }
        }

    }



    states: [
        State {
            name: "headerOne"
            PropertyChanges {
                target: container
                height: (background === true) ? 72 + 4 : 72
            }
            PropertyChanges { target: headerText; font.pixelSize: 56}
        },
        State {
            name: "headerTwo"
            PropertyChanges {
                target: container
                height: (background === true) ? 56 + 4 + topMargin : 56 + topMargin
            }
            PropertyChanges { target: headerText; font.pixelSize: 40}
            PropertyChanges { target: headerText; anchors.verticalCenterOffset: topMargin}

        },
        State {
            name: "headerThree"
            PropertyChanges {
                target: container
                height: (background === true) ? 36 + 4 : 36
            }
            PropertyChanges {
                target: headerText
                font.pixelSize: 22
                font.bold: true
            }
        },
        State {
            name: "headerFour"
            PropertyChanges {
                target: container
                height: (background === true) ? 36 + 4 : 36
            }
            PropertyChanges {
                target: headerText
                font.pixelSize: 22
                font.bold: true
                horizontalAlignment: Text.AlignRight


            }
        }
    ]

}


