/**
* ListItem provides the two basic textual list items currently used by music.
  * The list item does not have to have an icon and can have up to three lines of text at this time.
  *
  * Properties for a listItem include:
  *     - linkText1 (string)
  *     - linkText2 (string)
  *     - linkText3 (string)
  *     - linkId (string)
  *
  *     - linkIcon: true/false
  *
  */

import Qt 4.7

Rectangle {
    id: container

    property string linkText1: "";
    property string linkText2: "";
    property string linkText3: "";
    property string linkId: "";
    property bool linkIcon: true


    signal clicked;

    height: if (visible == false) {
        return 0
    } else if (linkText2 === "") {
        return 64
    } else if (linkText3 === "") {
        return 80
    } else {
        return 108
    }
    //width: parent.width You must provide a width when declaring this component
    color: (mouseArea.pressed === false) ? 'transparent' : theme.hoverColor

    MouseArea {
        id: mouseArea;
        anchors.fill: parent;
        onClicked: container.clicked()
    }

    Image {
        id: linkArrow
        visible: (linkIcon === true) ? true : false
        source: "../../images/linkArrow.png"
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: 27

    }


    Item {
        width: parent.width
        height: childrenRect.height
        anchors {
            left: parent.left
            right: parent.right
            verticalCenter: parent.verticalCenter
            leftMargin: 16
            rightMargin: (linkIcon === true) ? 50 : 16
        }

        Text {
            id: text1

            text: linkText1
            width: parent.width
            font.pixelSize: 26
            font.family: theme.primaryFont
            font.bold: true
            color: theme.primaryColor
            elide: Text.ElideRight
        }
        Text {
            id: text2

            text: linkText2
            height: (linkText2 == "") ? 0 : 22
            width: parent.width
            anchors.top: text1.bottom
            anchors.topMargin: (linkText2 == "") ? 0 : 5
            font.pixelSize: 22
            font.family: theme.primaryFont
            color: theme.secondaryColor
            elide: Text.ElideRight
        }
        Text {
            id: text3

            text: linkText3
            height: (linkText3 == "") ? 0 : 22
            width: parent.width
            anchors.top: text2.bottom
            anchors.topMargin: (linkText3 == "") ? 0 : 5
            font.pixelSize: 22
            font.family: theme.primaryFont
            color: theme.secondaryColor
            elide: Text.ElideRight
        }
    }

}
