import Qt 4.7
import "../../javascript/APIWrapper.js" as API

Item {

    function launchContent (inputString) {
        /**
        * Launches the content specified in the helper textbox
        *
        * Supported formats:
        * product(4544616) - Product (productId)
        * genre(SoulRandBFunk,Soul/R 'n' B/Funk) - Genre (genreId-genreName)
        * artist(660811,Lily Allen) - Artist (artistId-artistName)
        * home() - Home
        * categories() - Categories Hub
        * genrehub() - Genres Hub
        * debug() - Debug Page
        * territory(gb) - Change Territory
        * redirectTerritory(gb) - Change Redirect Territory
        * host(api.music.ovi.com) - Change Environment
        * settingsReset() - Clear all persisted settings
        * orientation(Portrait) - Change Orientation
        */

        var stringArray = inputString.split("(")
        if (stringArray.length > 1) {
            var parameters = stringArray[1].replace(')','');

            parameters = parameters.split(",");

            switch (stringArray[0])
            {
            case "product":
                    window.nextPage(productViewComponent, {dataProductID: parameters[0]});
                break;
            case "genre":
                    window.nextPage(genreHomeViewComponent, {genreName: parameters[1], genreId: parameters[0]});
                break;
            case "artist":
                    window.nextPage(artistViewComponent, {artistId: parameters[0], artistName: parameters[1]});
                break;
            case "home":
                    window.nextPage(homeViewComponent);
                break;
            case "categories":
                    window.nextPage(categoriesViewComponent);
                break;
            case "genrehub":
                    window.nextPage(genreHubViewComponent);
                break;
            case "debug":
                    window.nextPage(debugComponent);
                break;
            case "territory":
                    API.settings.setTerritory(parameters[0]);
                break;
            case "redirectTerritory":
                    API.settings.setRedirectedTerritory(parameters[0]);
            case "host":
                    API.settings.set("ServiceProviders/NokiaMusic/PAPI/host", parameters[0]);
                break;
            case "orientation":
                    screen.orientationString = parameters[0];
                break;
            case "settingsReset":
                    API.settings.reset()
                break;
            case "error":
                    window.showError(parameters[0]);
                break;
            case "viewError":
                    pageStack.currentPage.primaryEb();
                break;
            default:
                    console.log("Matti Helper: Requested action was not recognised")
                break;
            }
        }
        textInput.text = "";
        mattiBox.visible = false;
        window.forceActiveFocus();
    }

    Rectangle {
        id: mattiLauncher
        objectName: "mattiLauncher"
        color: "transparent"
        height: 10
        width: 10
        anchors.right: parent.right

        MouseArea {
            anchors.fill: parent
            onClicked: {
            	if (mattiBox.visible == true) {
                    window.forceActiveFocus();
                    mattiBox.visible = false;
                } else {
                    mattiBox.visible = true;
                }
            }
        }
    }

    Rectangle {
        id: mattiBox
        objectName: "mattiBox"
        anchors.right: mattiLauncher.right
        anchors.rightMargin: 5
        anchors.top: mattiLauncher.top
        anchors.topMargin: 5
        radius: 10
        color: "#CCC"
        border.color: "#FFF"
        border.width: 5
        visible: false
        width: 200
        height: (visible == true) ? 35 : 0

        TextInput {
            id: textInput
            width: 180
            x: 10
            y: 10

            Keys.onPressed: {
                if (event.key == Qt.Key_Enter || event.key == Qt.Key_Return) {
                    console.log(textInput.text);
                    launchContent(textInput.text);
                }
            }
        }

        onVisibleChanged: {
            if (visible == true) {
                textInput.forceActiveFocus();
            }
        }
    }
}
