import Qt 4.7
import QtMultimediaKit 1.1

Item {
    id: musicPlayerComponent

    property int progress
    property bool buffering: false
    property int cEND_OF_MEDIA: -1
    property string error

    property alias isPlaying: nativePlayer.playing
    property alias currentTrack: nativePlayer.source

    function play(url) {
        if (nativePlayer.playing) {
            stop()
        }
        nativePlayer.source = url
        startProfiler("musicPlayer::play");
        nativePlayer.play()
    }

    function stop() {
        startProfiler("musicPlayer::stop");
        nativePlayer.stop()
    }

    Audio {
        id: nativePlayer

        onPositionChanged: {
            musicPlayerComponent.buffering = false
            musicPlayerComponent.progress = position
        }

        onError: {
            console.log("MusicPlayer: Audio.onError: " + nativePlayer.error + ", " + nativePlayer.errorString)
            musicPlayerComponent.error = errorString
            musicPlayerComponent.progress = cEND_OF_MEDIA
        }

        onStopped: {
            console.log("MusicPlayer: Audio.onStopped")
            nativePlayer.stop()
            stopProfiler("musicPlayer::stop");
            musicPlayerComponent.progress = cEND_OF_MEDIA
        }

        onStatusChanged: {
            if (status == Audio.Loading) {
                console.log("MusicPlayer: Audio.Loading...")
                musicPlayerComponent.buffering = true
            }
            else if (status == Audio.Buffering) {
                console.log("MusicPlayer: Audio.Buffering")
                musicPlayerComponent.buffering = true
            }
            else if (status == Audio.Buffered) {
                console.log("MusicPlayer: Audio.Buffered")
                stopProfiler("musicPlayer::play");
                musicPlayerComponent.buffering = false
            }
            else if (status == Audio.EndOfMedia) {
                console.log("MusicPlayer: Audio.EndOfMedia")
                musicPlayerComponent.progress = cEND_OF_MEDIA
            }
            else if (status == Audio.Loaded) {
                console.log("MusicPlayer: Audio.Loaded")
            }
            else if (status == Audio.NoMedia) {
                console.log("MusicPlayer: Audio.No media")
                musicPlayerComponent.error = "No media"
            }
            else if (status == Audio.Stalled) {
                console.log("MusicPlayer: Audio.Stalled")
                musicPlayerComponent.error = "Stalled"
            }
            else if (status == Audio.InvalidMedia) {
                console.log("MusicPlayer: Audio.InvalidMedia")
                musicPlayerComponent.error = "InvalidMedia"
            }
            else if (status == Audio.UnknownStatus) {
                console.log("MusicPlayer: Audio.UnknownStatus")
                musicPlayerComponent.error = "UnknownStatus"
            }
        }
    }
}
