import Qt 4.7

/**
* PromoPanel will use the provided model to show a primary item and variable
  * number of secondary items.
  *
  * PromoView will assume that model provides following properties to delegate:
  *   - albumArt200    primary promo item image
  *   - albumArt100    secondary promo item image
  *   - name           name of the item
  *   - entityId       Entity id of the promo item
  */
Item {
    id: container
    width: parent.width;
    state: window.state;
    height: if (visible == false) {
        return 0
    } else if (state == "Landscape" || state == "LandscapeInverted") {
        return 144
    } else {
        return 320
    }

    // Number of secondary items to show
    property int secondaryItemCount : 2;
    
    // Number of items in landscape
    property int landscapeItemCount: 6;

    // The model containing the elements in the view
    property ListModel model;
    
    Loader { id: visualisationLoader }
    
    states: [
        State {
            name: "Landscape"
            PropertyChanges {
                target: visualisationLoader
                sourceComponent: landscapeVisualisation
            }
        },        
        State {
            name: "Portrait"
            PropertyChanges {
                target: visualisationLoader
                sourceComponent: portraitVisualisation
            }
        },
        State {
            name: "LandscapeInverted"
            extend: "Landscape"
        },
        State {
            name: "PortraitInverted"
            extend: "Portrait"
        }
    ]

    Component {
        id: portraitVisualisation
        Repeater {
            id: repeater
            height: container.height;
            width: container.width;
            model: container.model;
            clip: true;

            Rectangle {
                id: repeaterContainer;
                property bool primaryItem : (index == 0) ? true : false;
                color: "transparent";
                visible: (index < (secondaryItemCount + 1) ? true : false);
                height: (primaryItem ? container.height : container.height / secondaryItemCount);
                width: height
                x: (primaryItem ? 0 : container.height);
                y: (primaryItem ? 0 : (index - 1) * height);

                Rectangle {
                    height: parent.height;
                    width: parent.width;
                    color: "transparent";

                    WebImage {
                        height: parent.height
                        width: parent.width
                        imageSource: (primaryItem ? albumArt200 : albumArt100);
                    }
                    Rectangle {
                        y: parent.height - 26
                        width: parent.width
                        height: 26
                        color: "#CC000000"
                        Text {
                            x: 10
                            height: parent.height
                            verticalAlignment: Text.AlignVCenter
                            text: name
                            font.pixelSize: 18
                            font.family: theme.primaryFont
                            color: "#FFFFFF"
                            width: parent.width - 20
                            elide: Text.ElideRight
                        }
                    }
                    MouseArea {
                        anchors.fill: parent
                        hoverEnabled: true
                        onClicked: window.nextPage(
                                productViewComponent,
                        {
                            name: name,
                            type: type,
                            artistName: artistName,
                            artistID: artistID,
                            variousArtists: variousArtists,
                            albumArt100: albumArt100,
                            albumArt200: albumArt200,
                            takenFrom: takenFrom,
                            takenFromID: takenFromID,
                            genre: genre,
                            genreID: genreID,
                            label: label,
                            dataProductID: dataProductID,
                            trackCount: trackCount,
                            durationLength: durationLength,
                            currencyCode: currencyCode,
                            price: price,
                            trackUrl: trackUrl,
                            streetReleaseDate: streetReleaseDate,
                            cwmAvailable: cwmAvailable,
                            cwmBitRate: cwmBitRate,
                            cwmFormat: cwmFormat,
                            alcAvailable: alcAvailable,
                            alcBitRate: alcBitRate,
                            alcFormat: alcFormat
                        });
                    }
                }
            } // End Rectangle
        } // End Repeater
    } // End Component
    
    Component {
        id: landscapeVisualisation
        Repeater {
            id: repeater
            height: container.height;
            width: container.width;
            model: container.model;
            clip: true;

            Rectangle {
                id: repeaterContainer;
                property bool primaryItem : (index == 0) ? true : false;
                color: "transparent";
                visible: (index < landscapeItemCount ? true : false);
                height: (container.width/landscapeItemCount)
                width: height
                x: index * height;
                y: 0;

                Rectangle {
                    height: parent.height;
                    width: parent.width;
                    color: "transparent";

                    WebImage {
                        height: parent.height
                        width: parent.width
                        imageSource: (primaryItem ? albumArt200 : albumArt100);
                    }
                    Rectangle {
                        y: parent.height - 26
                        width: parent.width
                        height: 26
                        color: "#99000000"
                        Text {
                            x: 10
                            height: parent.height
                            verticalAlignment: Text.AlignVCenter
                            text: name
                            font.pixelSize: 18
                            font.family: theme.primaryFont
                            color: "#FFFFFF"
                            width: parent.width - 20
                            elide: Text.ElideRight
                        }
                    }
                    MouseArea {
                        anchors.fill: parent
                        hoverEnabled: true
                        onClicked: window.nextPage(
                                productViewComponent,
                        {
                            name: name,
                            type: type,
                            artistName: artistName,
                            artistID: artistID,
                            variousArtists: variousArtists,
                            albumArt100: albumArt100,
                            albumArt200: albumArt200,
                            takenFrom: takenFrom,
                            takenFromID: takenFromID,
                            genre: genre,
                            genreID: genreID,
                            label: label,
                            dataProductID: dataProductID,
                            trackCount: trackCount,
                            durationLength: durationLength,
                            currencyCode: currencyCode,
                            price: price,
                            trackUrl: trackUrl,
                            streetReleaseDate: streetReleaseDate,
                            cwmAvailable: cwmAvailable,
                            cwmBitRate: cwmBitRate,
                            cwmFormat: cwmFormat,
                            alcAvailable: alcAvailable,
                            alcBitRate: alcBitRate,
                            alcFormat: alcFormat
                        });
                    }
                }
            } // End Rectangle
        } // End Repeater
    } // End Component
}
