import Qt 4.7
import com.nokia.qmlcomponents 1.0
import "../../javascript/APIWrapper.js" as API

Rectangle {
    id: container

    property alias trackPrefix: trackData.trackPrefix
    property alias trackName: trackData.trackName
    property alias trackArtistName: trackData.artistName
    property alias variousArtists: trackData.variousArtists
    property alias trackLengthInSec: trackData.trackLengthInSec
    property alias priceText: priceButton.text
    property alias url: trackData.url
    property string backgroundColor: ""
    property bool highlightVisible: trackData.playerVisible || trackData.state == "errorShown"
    property bool alcAvailable: false
    property bool cwmAvailable: false

    property string trackId: trackData.trackId
    property string albumName: trackData.albumName
    property string fileType: trackData.fileType
    property string albumArtUrl: trackData.albumArtUrl

    property variant _downloadCommand;
    property Connections _connectionBinding;
    property Connections _ssoConnectionBinding;

    signal clicked(variant clickedTrack)

    height: (visible == true) ? trackData.nonPlayerHeight : 0;
    width: parent.width
    color: highlightVisible? '#eeeeef': "transparent"

    function createDownloadCommand(paramTrackId) {
        console.log("Track download, productId: " + paramTrackId + " -> DownloadCommand.ALCUsage: " + DownloadCommand.ALCUsage);

        _downloadCommand = store.account.download(paramTrackId, DownloadCommand.ALCUsage);
        if (_connectionBinding != undefined) {
            _connectionBinding.destroy();
        }

        _connectionBinding = connectionContainer.createObject(container);
    }

    function createSsoConnectionBinding() {
        if (_ssoConnectionBinding != undefined) {
            _ssoConnectionBinding.destroy();
        }
        _ssoConnectionBinding = ssoConnectionContainer.createObject(container);
    }

    Behavior on color { PropertyAnimation {duration: 100} }

    MouseArea {
        id: clipHitArea
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: parent.left
            right: priceButton.left
            rightMargin: 10
        }
        onClicked: {
            container.clicked(container);
        }
    }
    MouseArea {
        id: downloadHitArea
        anchors {
            top: parent.top
            bottom: parent.bottom
            left: priceButton.left
            leftMargin: 10
            right: parent.right
        }
        onClicked: {
            priceButton.clicked();
            priceButton.pressed();
        }
    }

    ButtonSmall {
        id: priceButton
        anchors {
            top: parent.top
            topMargin: 20
            right: parent.right
            rightMargin: 21
        }
        productId: trackId
        isTrackDownload: true
        isAlbumDownloadOnlyTrack: (alcAvailable) ? false : true
        onClicked: {

            if (priceButton.playable) {
                externalMusicPlayer.playTrack(downloadEngine.downloadData[trackId].downloadItem.trackPlayUrl)
            } else if (priceButton.isAlbumDownloadOnlyTrack) {
                downloadEngine.updateTrackStatusData(productId, "albumDownloadOnlyTrackPressed");
            } else {
                downloadEngine.updateTrackStatusData(trackId, "wait");
                startProfiler("wait-track-download-complete");
                startProfiler("wait-get-downloadlink");
                startProfiler("wait-first-progress");
                createDownloadCommand(trackId);
            }
        }
    }

    TrackData {
        id: trackData
        anchors {
            top: parent.top
        }
        width: parent.width
        visible: (priceButton.state === 'temporarilyDisabled' ||
                  priceButton.state === 'disabled' ||
                  priceButton.state === 'albumDownloadOnlyTrackPressed') ? false : true
    }

    BodyText {
        id: trackDownloadRequestError
        visible: (priceButton.state === 'temporarilyDisabled' || priceButton.state === 'disabled') ? true : false
        font.italic: true
        color: theme.tertiaryColor
        anchors {
            verticalCenter: parent.verticalCenter
            left: parent.left;
            leftMargin: 16;
            right: priceButton.left;
            rightMargin: 20;
        }
        wrapMode: Text.Wrap
        text: qsTranslate("Download","t[TrackDownloadRequestErrorNote");
    }

    BodyText {
        id: albumDownloadOnlyTrackInfo

        visible: (priceButton.state === 'albumDownloadOnlyTrackPressed') ? true : false
        width: parent.width
        anchors.verticalCenter: parent.verticalCenter
        wrapMode: Text.Wrap
        text: qsTranslate("Download","t[AlbumDownloadOnlyTrackNote");
    }

    Component {
        id: connectionContainer
        Connections {
            ignoreUnknownSignals: true;
            target: _downloadCommand.status;
            onStatusChanged: {
                var _status = _downloadCommand.status.status;
                console.log("Track download -> Download command status: " + _status + ", response: " + _downloadCommand.response);
                if (_ssoConnectionBinding != undefined) {
                    _ssoConnectionBinding.destroy();
                }

                if (_downloadCommand.response == DownloadCommand.SuccessResponse) {
                    if( _downloadCommand.count() > 0 ) {
                        stopAndRemoveProfiler("wait-get-downloadlink");
                        startProfiler("wait-dlmanager-onAdded");
                        var result = _downloadCommand.resultAt(0)
                        var r = "DownloadCommand result -> releaseId: " + result.releaseId + " , downloadUri: " + result.downloadUri + " , licenseUri: " + result.licenseUri;
                        console.log(r);
                        downloadEngine.downloadTrack(result.releaseId, {
                            "downloadUrl" : result.downloadUri,
                            "artistName" : artistName,
                            "albumName" : albumName,
                            "trackName" : trackName,
                            "fileType" : fileType,
                            "albumArtUrl" : albumArtUrl
                        });
                    }
                }

                else if (_downloadCommand.response == DownloadCommand.PaymentRequiredResponse) {
                    if (API.settings.getStoreConfig().alcVoucherOnly === 'true') {
                        window.nextPage(redeemVoucherInPurchaseOptionsComponent, {productId: trackId, productName: trackData.trackName, artistName: trackData.artistName, price: priceButton.text, productUrl: albumArtUrl, productType: context.type })
                    }
                    else {
                        opePage.doCheckout("MusicDD-1388", viewRoot, opePage.ShowSpinner, opePage.ShowSpinner);
                    }
                }

                else if (_downloadCommand.response == DownloadCommand.ErrorResponse ||
                         _downloadCommand.response == DownloadCommand.NoResponse) {

                    if (_status == RequestStatus.PermissionError) {
                        // Need to sign in
                        createSsoConnectionBinding();
                        sso.signIn();
                    }

                    else if (_status == RequestStatus.NetworkError ||
                             _status == RequestStatus.RequestError ||
                             _status == RequestStatus.UnknownError) {
                        // In backend errors, show error message and disable download button temporarily
                        downloadEngine.updateTrackStatusData(trackId, "temporarilyDisabled");
                    }

                    else if (_status == RequestStatus.DataError) {
                        // In fatal backend errors, show error message and disable download button
                        downloadEngine.updateTrackStatusData(trackId, "disabled");
                    }
                }
            }
        }
    }

    Component {
        id: ssoConnectionContainer;
        Connections {
            target: sso
            onSignInSuccessful: {
                // Retry the SAPI call
                createDownloadCommand(trackId);
            }
            onSilentSignInFailed: {
                sso.launchSignInUi();
            }
            onSignInFailed: {
                downloadEngine.updateTrackStatusData(trackId, "normal");
            }
        }
    }
}
