import Qt 4.7

Rectangle {
    id: windowContainer

    Component {
        id: dummyScreen
        QtObject {
            id: screen
            property string orientationString: morpheusSettings.orientationPerspective
            property int width: 864
            property int height: 480
        }
    }

    property string title; //Not implemented
    property bool minimized; //Not implemented
    property int orientation; //Not implemented
    property variant screen;
    
    property variant viewLoadContext
    property variant currentViewComponent
    property variant errorTitle

    function nextPage(view, context) {
        viewLoadContext = context;
        currentViewComponent = view;
        pageStack.push(view);
    }

    function loadPage(view, context) {
        viewLoadContext = context;
        currentViewComponent = view;
        pageStack.replace(view);
    }

    function showError(title) {
        errorTitle = title
        pageStack.replace(errorViewComponent);
    }

    function back() {
        pageStack.pop();
        viewLoadContext = pageStack.currentPage.context;
        currentViewComponent = pageStack.currentPage.parentComponent;
    }

    function clearHistory() {
        pageStack.clear();
    }

    clip: true

    Component {
        id: orientationBinding
        Binding {
            target: windowContainer;
            property: "state";
            value: screen.orientationString;
        }
    }

    Component.onCompleted: {
        loadScreenObject();
    }

    function loadScreenObject() {
        var component;
        if (morpheusSettings.sensorsEnabled) {
            component = Qt.createComponent("Screen.qml");
            screen = component.createObject(windowContainer);
        } else {
            screen = dummyScreen.createObject(windowContainer)
        }
        // Bind orientation to screen.orientationstring
        orientationBinding.createObject(windowContainer);
    }
    
    states:  [
        State {
            name: "Landscape"
            PropertyChanges {
                target: windowContainer
                rotation: 0
                width: screen.width
                height: screen.height
                x: 0
                y: 0
            }
        },
        State {
            name: "LandscapeInverted"
            extend: "Landscape"
            PropertyChanges {
                target: windowContainer
                rotation: 180
            }
        },
        State {
            name: "Portrait"
            PropertyChanges {
                target: windowContainer
                rotation: 270
                width: screen.height
                height: screen.width
                x: (screen.width - screen.height) / 2
                y: -(screen.width - screen.height) / 2
            }
        },
        State {
            name: "PortraitInverted"
            extend: "Portrait"
            PropertyChanges {
                target: windowContainer
                rotation: 90
            }
        }
    ]
    
    transitions: Transition {
        SequentialAnimation {
            PropertyAction { target: windowContainer; properties: "x,y,width,height" }
            ParallelAnimation {
                NumberAnimation { target: windowContainer; property: "opacity"; to: 1; duration: 300 }                
                RotationAnimation { target: windowContainer; property: "rotation"; direction: RotationAnimation.Shortest; easing.type: Easing.InOutQuad; duration: 300 }
            }
        }
    }
}
