.pragma library

/* 
    This function help to generate the correct image id given a template and a dictionary of parameters.
    Also hide the ImageProvider functionality so that the same component can load assets from different sources.
    depending on this function. The family property is used in ascard to point to the right subdirectory.
    This function in qt-component will use the imageprovider and will ignore the family property.
    
    Es1 (boolean value): add "-disabled" to the image path if the button is not enabled
    button.source = getId("button{disabled}", { disabled: !button.enabled, family: "button" });
    
    Output: "assets/button/button-disabled.png" if button.enabled == false
    Output: "assets/button/button.png" if button.enabled == true
    
    Es2 (string value): add the current state as "-state" to the image path. If the state is empty don't add anything
    button.source = getId("button{state}", { state: button.state, family: "button" });
    
    Output: "assets/button/button-pressed.png" if button.state == "pressed"
    Output: "assets/button/button.png" if button.state == ""    
*/
var re = new RegExp("({(.*?)})","g");
function getId(template, params) {
    if (params !== undefined) {
        template = template.replace(re, function(a, b, c) {
            if (!params[c]) return "";
            return "-" + ((params[c] === true) ? c : params[c]);
        });
        return "assets/" + params.family + "/" + template + ".png";
    }
    return template;
}