var self,
    clickHandlers = [], // bindet click handlers (for removing them)
    shadow = [],        // shadow copy of children
    _templates,         // holds the button templates as array: [only, first, middle, last]
    _first,             // holds first index
    _last,              // holds last index
    _direction;

/**
 * prepares the group behavior for that component
 */

var create = function(that, options) {
    self = that;
    _templates = options.templates;
    _direction = options.direction || Qt.Horizontal;
    var groupType = self.groupType || options.groupType;
    selectionFn = selectionFns[groupType.toLowerCase()] || selectionFns.none;
    self.childrenChanged.connect(childrenChanged);
    self.widthChanged.connect(resizeChildren);
    if (self.groupTypeChanged) {
        self.groupTypeChanged.connect(groupTypeChanged);
    }
    build();
}

// fun is taken from qt-components
// "duck-typing" to identify the Buttons, find a better way to do it :-P
function isButton(item) {
    for (var c in item) {
        if (c === "__bgTemplate") {
            return true;
        }
    }
    return false;
}

/**
 * Destroy behavior for that component
 */
var destroy = function() {
    self.childrenChanged.disconnect(childrenChanged);
    if (self.groupTypeChanged) {
        self.groupTypeChanged.disconnect(groupTypeChanged);
    }
    self.widthChanged.disconnect(resizeChildren);
    cleanup();
}

/**
 * prepare the buttongroup
 */
function build() {
    // copy of children because its not an array. also we need a copy
    shadow = [];
    shadow.length = self.children.length;
    var isCheckedPresent = false;
    for (var i = 0, item; (item = self.children[i]); i++) {
        if (item) {
            if (isButton(item)) {
                shadow[i] = item;
                _last = i;
                _first = undefined === _first ? i : _first;
                if (item === self.checkedButton) {
                    isCheckedPresent = true;
                }
            }
        }
    }
    if (!isCheckedPresent) {
        self.checkedButton = undefined;
    }

    var extraPixels = self.width % shadow.length
    var buttonSize = (self.width-extraPixels) / shadow.length;

    shadow.forEach(function(item, i) {
        if (item) {
            clickHandlers[i] = function() { selectionFn(item); }
            item.__bgTemplate = _templates[_first===_last ? 0 : // only
                                         _first === i ? 1 :   // first
                                         _last === i ? 3 :    // last
                                         2];                  // middle
            if (item["checkable"]!==undefined) {
                item.checkable = true;
            }
            if (self.width > 0) { // fixed: ASGARD-18
                if (_direction == Qt.Vertical) {
                    item.anchors.left = self.left
                    item.anchors.right = self.right
                }
            }
            item.clicked.connect(clickHandlers[i]);
        }
    });
    resizeChildren();
}

/**
 * cleanup the buttongroup
 */
function cleanup() {
    for (var i = 0, l = shadow.length; i < l; i++) {
        try {
            if (clickHandlers[i]) { shadow[i].clicked.disconnect(clickHandlers[i]); }
        } catch (e) {}
    }
    clickHandlers = [];
}

/**
 * rebuild if buttongroup has changed
 */
function childrenChanged() {
    cleanup();
    build();
}

function groupTypeChanged() {
    selectionFn = selectionFns[self.groupType.toLowerCase()] || selectionFns.none;
    selectionFn(self.checkedButton);
}

var resizeChildren = function() {
    if (_direction != Qt.Horizontal) {
        return;
    }

    var extraPixels = self.width % shadow.length
    var buttonSize = (self.width-extraPixels) / shadow.length;
    shadow.forEach(function(item, i) {
        item.width = buttonSize + (extraPixels ? 1 : 0);
        if (extraPixels > 0) {
            extraPixels--;
        }
    });
}

/**
 * Selection handlers.
 */

var selectionFn,
    selectionFns = {
        none: function(item) {
            self.checkedButton = undefined;
            for (var i = 0, ref; (ref = shadow[i]); i++) {
                ref.checked = false;
            }
        },
        one: function(item) {
            for (var i = 0, ref; (ref = shadow[i]); i++) {
                ref.checked = item === ref;
            }
            self.checkedButton = item;
        },
        many: function(item) {
            // Maybe we should put to undefined the checkedButton if the current button go to checked:false?
            // self.checkedButton = (item && item.checked) ? item : undefined;
            self.checkedButton = item;
        }
    };

