import Qt 4.7
import "constants.js" as C
import "AssetLoader.js" as AL

/*
   Class: CheckBox
   Component to express a boolean choose.

   A checkbox is a component that accepts user input and send a clicked() signal for
   the application to handle. The checkbox can be checked or unchecked.
   Right now the checkbox don't include any text label.
*/
ImplicitSizeItem {
    /*
     * Property: checked
     * [bool] Specify the checked state.
     */
    property alias checked: button.checked

    /*
     * Property: pressed
     * [bool] (ReadOnly) Is true when the checkbox is pressed
     */
    property alias pressed: button.pressed

    /*
     * Property: enabled
     * [bool=true] Enables/Disables the component. Notice that the disable state is not Toolkit compliant
     * and not present inside the qt-components
     */
    property alias enabled: button.enabled

    /*
     * Event: clicked
     * Is emitted when the checkbox is clicked
     */
    signal clicked

    property alias __family: button.__family
    property alias __type: button.__type
    property alias __bgTemplate: button.__bgTemplate

    implicitWidth: C.CHECKBOX_WIDTH
    implicitHeight: C.CHECKBOX_WIDTH

    Button {
        __family: "meegotouch-checkbox-radiobutton"
        __type: "checkbox"
        __iconSize: 42

        id: button

        anchors.fill: parent

        checkable: true

        function __getIconMargin() {
            return 0;
        }

        function __getTextColor() {
            return "#242424"
        }

        function __getBackground() {
            return ""
        }

        function __getIcon() {
            var bgTemplate = "meegotouch-button{type}-background{state}{disabled}"
            return AL.getId(bgTemplate, {
                type: __type,
                state: state,
                disabled: (!enabled && state !== "disabled"),
                family: __family
            });
        }

        onClicked: parent.clicked()
    }
}
