import Qt 4.7

/*
   Class: PageIndicator
   Component to indicate the page user is currently viewing.

   A page indicator is a component that shows the number of availabe pages as well as the page the user is
   currently on.  The user can also specify the display type to select the normal/inverted visual.

   WARNING:
   This component does not exist in qt-components, and there is no plan to merge back.
*/
Item {
    id: pageIndicator

    /*
     * Property: totalPages
     * [int] The total number of pages.  This value should be larger than 0.
     */
    property int totalPages: 0

    /*
     * Property: currentPage
     * [int] The current page the user is on.  This value should be larger than 0.
     */
    property int currentPage: 0

    /*
     * Property: inverted
     * [string] Specify whether the visual for the rating indicator uses the inverted color.  The value is
     * false for use with a light background and true for use with a dark background.
     */
    property bool inverted: false


    /* private */
    property int __spacing: 8

    property string __totalPagesImageSource: inverted ?
                                             "assets/meegotouch-page-indicator/meegotouch-inverted-pageindicator-page.png" :
                                             "assets/meegotouch-page-indicator/meegotouch-pageindicator-page.png"
    property string __currentPageImageSource: inverted ?
                                              "assets/meegotouch-page-indicator/meegotouch-inverted-pageindicator-page-current.png" :
                                              "assets/meegotouch-page-indicator/meegotouch-pageindicator-page-current.png"

    property bool __init: true

    width: currentImage.width * totalPages + (totalPages - 1) * __spacing
    height: currentImage.height

    function __updateUI() {

        if(totalPages <=0) {
            totalPages = 1;
            currentPage = 1;
        }
        else {
            if(currentPage <=0) {
                currentPage = 1;
            }

            if(currentPage > totalPages) {
                currentPage = totalPages;
            }
        }

        frontRepeater.model = currentPage - 1;
        backRepeater.model = totalPages - currentPage;
    }

    Component.onCompleted: {
        __updateUI();
        __init = false;
    }

    onTotalPagesChanged: {
        if(!__init) {
            __updateUI();
        }
    }

    onCurrentPageChanged: {
        if(!__init) {
            __updateUI();
        }
    }

    Row {
        Repeater {
             id: frontRepeater

             Item {
                 height: currentImage.height
                 width:  currentImage.width + __spacing

                 Image {
                     source: __totalPagesImageSource
                 }
             }
         }

         Image {
             id: currentImage
             source:  __currentPageImageSource
         }

         Repeater {
             id: backRepeater

             Item {
                 height: currentImage.height
                 width:  currentImage.width + __spacing

                 Image {
                     source: __totalPagesImageSource
                     anchors.right: parent.right
                 }
             }
         }
    }
}
