/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Components project on Qt Labs.
**
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions contained
** in the Technology Preview License Agreement accompanying this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
****************************************************************************/

import Qt 4.7

/**
  * Class: ProgressBar
  * A ProgressBar shows the progress status of an operation with a predictable end point.
  */

Item {
    id: root

    /*
     * Property: minimumValue
     * [real=0] Specifies the minimum value of progress
     */
    property real minimumValue: 0.0 // default = 0.0

    /*
     * Property: maximumValue
     * [real=1] Specifies the maximum value of progress (done)
     */
    property real maximumValue: 1.0 // default = 1.0

    /*
     * Property: value
     * [real] Specifies the current value of progress.
     */
    property real value: minimumValue // default = minimumValue

    /*
     * Property: indeterminate
     * [bool=false] Turn on the unknown diration state.
     */
    property bool indeterminate: false // default = false, this doesn't influence the value of progress

    property bool vertical: false

    property string __assetPath: "assets/meegotouch-progress-indicators/"

    rotation: vertical ? 270: 0

    states: [
        State {
            name: "indeterminate"
            when: indeterminate == true
            PropertyChanges {
               target: progressCandybar
               visible: true
            }
            PropertyChanges {
               target: root
               value: root.maximumValue
           }
        }
    ]

    Rectangle {
        id: progressBarContainer
        anchors.fill: parent
        color: "transparent"
        width: parent.width

        Rectangle {
            id: progressBarBackground
            width: parent.width
            height: 10
            anchors.centerIn: parent
            color: "transparent"

            BorderImage {
                id: progressBarBackgroundImage
                anchors.fill: progressBarBackground
                border { left: 4; top: 4; right: 4; bottom: 4 }
                smooth: true
                source: root.__assetPath + "meegotouch-progressindicator-bar-background.png"
            }
        }

        Rectangle {
            id: progressBarFill
            property real length: Math.max(root.minimumValue, Math.min(root.value, root.maximumValue)) - root.minimumValue
            property real maxLength: root.maximumValue - root.minimumValue
            width: (length / maxLength) * progressBarBackground.width
            height: progressBarBackground.height
            anchors.left: progressBarBackground.left
            anchors.top: progressBarBackground.top
            color: "transparent"

            Behavior on width {
                NumberAnimation { duration: 100 }
            }

            BorderImage {
                id: progressBarFillImage
                anchors.fill: progressBarFill
                border { left: Math.min(4, progressBarFill.width/2); top: 4; bottom: 4; right: Math.min(4, progressBarFill.width/2) }
                smooth: true
                source: root.__assetPath + "meegotouch-slider-elapsed-background-horizontal.png"
            }

            /* Hiding the border-radius from the right side of the bar */
            Rectangle {
                id: progressBarFillClipper
                color: "transparent"
                width: Math.min(progressBarFill.width - 2, 4)
                height: progressBarFill.height
                anchors.right: progressBarFill.right
                anchors.top: progressBarFill.top

                BorderImage {
                    visible: !(progressBarBackground.width - progressBarFill.width <= 2)
                    anchors.fill: progressBarFillClipper
                    source: root.__assetPath + "meegotouch-slider-elapsed-background-horizontal.png"
                }
            }
        }

        /* Static 'waiting' animation */

        // FIXME: implementing rounded corners for an image decently seems
        // to be pretty much impossible without native code currently.
        Rectangle {
            id: progressCandybar
            anchors.fill: progressBarBackground
            anchors.rightMargin: 4 // these margins reveal the
            anchors.leftMargin: 4 // rounded corners below them
            visible: false
            radius: 5
            color: "transparent"
            clip: true // needed for the animation

            Image {
                id: progressBarFillImageCandybar
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.topMargin: 1
                width: parent.width + 16
                height: parent.height - 2
                smooth: true
                source: root.__assetPath + "meegotouch-progressindicator-bar-unknown-texture.png"
                fillMode: Image.TileHorizontally
            }

            NumberAnimation {
                id: candybarAnimation
                running: progressCandybar.visible
                target: progressBarFillImageCandybar
                property: "anchors.leftMargin"
                from: -8; to: 0
                duration: 400
                loops: Animation.Infinite
            }
        }
    }
}

