import Qt 4.7

/**
  * Class: ScrollDecorator
  * A ScrollDecorator shows the current position in a scrollable area.
  */
Item {
    id: root

    /**
      * Property: flickable
      * [Item] The Item that should show the ScrollDecorator
      */
    property Item flickable

    // These can also be modified (but probably shouldn't)
    property int __minIndicatorSize: 20
    property int __hideTimeout: 500
    property bool __indicatorsOvershoot: false

    // Private stuff
    anchors.fill: flickable

    property string __assetPath:  "assets/meegotouch-positionindicator/"

    Timer {
        // Hack to have the indicators flash when the view is shown the first time.
        // Ideally we would wait until the Flickable is complete, but it doesn't look
        // possible given the current limitations of QML.
        interval: 100
        running: true
        repeat: false
        onTriggered: {
            if (verticalIndicator.shouldShow) {
                verticalIndicator.state = "visible";
                verticalIndicator.state = "";
            }
            if (horizontalIndicator.shouldShow) {
                horizontalIndicator.state = "visible";
                horizontalIndicator.state = "";
            }
        }
    }

    Item {
        id: verticalIndicator
        property bool shouldShow: flickable.height > 0 && flickable.contentHeight > flickable.height
        opacity: 0
        height: parent.height
        anchors.right: parent.right

        Image {
            source: root.__assetPath + "meegotouch-positionindicator-background.png"
            height: parent.height
            anchors.right: parent.right
        }
        BorderImage {
            source: root.__assetPath + "meegotouch-positionindicator-indicator.png"
            border { left: 2; top: 4; right: 2; bottom: 4 }
            property real yPos: flickable.visibleArea.yPosition * flickable.height // use separate prop to avoid weird binding loop issue
            y: yPos
            height: Math.max(root.__minIndicatorSize, flickable.visibleArea.heightRatio * flickable.height)
            anchors.right: parent.right
            anchors.top: (!root.__indicatorsOvershoot && yPos < 0) ? parent.top : undefined
            anchors.bottom: (!root.__indicatorsOvershoot && yPos + flickable.visibleArea.heightRatio * flickable.height > flickable.height) ? parent.bottom : undefined
        }

        states: State {
            name: "visible"
            when: verticalIndicator.shouldShow && flickable.moving
            PropertyChanges {
                target: verticalIndicator
                opacity: 1
            }
        }

        transitions: Transition {
            from: "visible"; to: ""
            NumberAnimation {
                properties: "opacity"
                duration: root.__hideTimeout
            }
        }
    }

    Item {
        id: horizontalIndicator
        property bool shouldShow: flickable.width > 0 && flickable.contentWidth > flickable.width
        opacity: 0
        width: parent.width
        anchors.bottom: parent.bottom

        Image {
            source: root.__assetPath + "meegotouch-positionindicator-background-horizontal.png"
            width: parent.width
            anchors.left: parent.left
            anchors.bottom: parent.bottom
        }
        BorderImage {
            source: root.__assetPath + "meegotouch-positionindicator-indicator-horizontal.png"
            border { left: 4; top: 2; right: 4; bottom: 2 }
            property real xPos: flickable.visibleArea.xPosition * flickable.width // use separate prop to avoid weird binding loop issue
            x: xPos
            width: Math.max(root.__minIndicatorSize, flickable.visibleArea.widthRatio * flickable.width)
            anchors.bottom: parent.bottom
            anchors.left: (!root.__indicatorsOvershoot && xPos < 0) ? parent.left : undefined
            anchors.right: (!root.__indicatorsOvershoot && xPos + flickable.visibleArea.widthRatio * flickable.width > flickable.width) ? parent.right : undefined
        }

        states: State {
            name: "visible"
            when: horizontalIndicator.shouldShow && flickable.moving
            PropertyChanges {
                target: horizontalIndicator
                opacity: 1
            }
        }

        transitions: Transition {
            from: "visible"; to: ""
            NumberAnimation {
                properties: "opacity"
                duration: root.__hideTimeout
            }
        }
    }
}
