import Qt 4.7

/*
   Class: Switch
   The Switch component is similar to the CheckBox component but instead of
   selecting items it should be used when setting options to On/Off.
*/

ImplicitSizeItem {
    id: root

    width: slider.width
    height: slider.height

    /*
     * Property: checked
     * [bool=false] The checked state of switch
     */
    property bool checked: false

    /*
     * Property: enabled
     * [bool=true] Enables/Disables the component. Notice that the disable state is not Toolkit compliant
     * and not present inside the qt-components
     */

    Image {
        id: slider

        width: 66
        height: 42

        state: root.checked ? 'checked' : 'unchecked'

        states: [
            State {
                name: "unchecked"
                PropertyChanges {
                    target: slider; source: "assets/meegotouch-switch/meegotouch-switch-off.png"
                }
                PropertyChanges { target: knob; x: 4 }
            },
            State {
                name: "checked"
                PropertyChanges {
                    target: slider; source: "assets/meegotouch-switch/meegotouch-switch-on.png"
                }
                PropertyChanges { target: knob; x: 28 }
            }
        ]

        // thumb (shadow)
        Image {
            id: knob

            // thumb (inline)
            Image {
                width: 30
                height: 30
                x: 2
                y: 2
                source: "assets/meegotouch-switch/meegotouch-switch-thumb" + (slider.enabled ? (mouse.pressed ? "-pressed" : "") : "-disabled") + ".png"
            }

            source: "assets/meegotouch-switch/meegotouch-switch-shadow.png"

            /* x: 4 */
            y: 4

            width: 34
            height: 34
        }

        MouseArea {
            id: mouse
            anchors.fill: parent
            onClicked: root.checked = !root.checked
        }

        transitions: Transition {
            SmoothedAnimation { properties: "x"; velocity: 500; maximumEasingTime: 0 }
        }
    }
}
