import Qt 4.7
import "ButtonGroup.js" as Behavior

/*
   Class: TabButtonRow
   A TabButtonRow allows you to group TabButtons in a row. It provides a selection-behavior as well.

   TabButtonRow is able to handle correctly two to four TabButtons. Less or more buttons can produce rendering issues.

   <code>
       TabButtonRow {
           displayMode: "Icon"
           TabButton { text: "Tab1", checked: true }
           TabButton { text: "Tab2" }
           TabButton { text: "Tab3" }
       }
   </code>

   WARNING:
   This component does not yet exist in qt-component, and the APIs are not yet agreed by the community.
   The final APIs may be different.
   You are responsible to ensure that at least one tab is checked at startup. The component doesn't enforce this for you.
*/
Row {
    id: root

    property string __className: "TabButtonRow"

    /*
     * Property: checkedButton
     * [string] Contains the last checked Button.
     */
    property variant checkedButton;

    /*
     * Property: displayMode
     * [string="Text"] Specifies visual appearance of the TabbarButtons. It can be "Text" or "Icon".
     */
    property string displayMode: "Text"

    onDisplayModeChanged: __changeDisplayMode();

    Component.onCompleted: {
        console.log("TabButtonRow is still work in progress, final API may be different");
        Behavior.create(root, {
            templates: ["meegotouch-navigationbar-portrait-bottom-tab-background{state}",
                        "meegotouch-navigationbar-portrait-bottom-tab-background{state}-horizontal-left",
                        "meegotouch-navigationbar-portrait-bottom-tab-background{state}-horizontal-center",
                        "meegotouch-navigationbar-portrait-bottom-tab-background{state}-horizontal-right"],
            groupType: "One"
        });
        __changeDisplayMode();

    }

    Component.onDestruction: {
        Behavior.destroy();
    }

    function __changeDisplayMode() {
        // iterate over all the children and hide/show Text/Image
        var newTextState = displayMode === "Text";
        for (var i = 0; i < children.length; ++i) {
            children[i].__icon.visible = !newTextState;
            children[i].__text.visible = newTextState;
        }
    }
}
