import Qt 4.7

// TODO: figure out to remove binding loop warnings
// TODO: The API does not match that of TextArea component in qt-components, synchronization is needed.

Item {
    id: container
    property string selectionPolicy // enumeration. Select all, only one word, nothing, or ... on tap TODO: no idea what ... means
    property int documentMargin: 14
    property real minHeight: 0
    property real maxHeight: 100

    //property real contentHeight // alias/binding to paintedHeight TODO: what's the purpose?
    //property real contentWidth // alias/binding to paintedWidth TODO: what's the purpose?

    property alias persistentSelection: textEdit.persistentSelection // persistentSelection : bool // what is the case for turning it off?

    property alias font: textEdit.font
    property alias cursorPosition: textEdit.cursorPosition
    property alias horizontalAlignment: textEdit.horizontalAlignment
    property alias verticalAlignment: textEdit.verticalAlignment
    property alias readOnly: textEdit.readOnly
    property alias selectedText: textEdit.selectedText
    property alias selectionEnd: textEdit.selectionEnd
    property alias selectionStart: textEdit.selectionStart
    property alias text: textEdit.text
    property alias textFormat: textEdit.textFormat
    property alias wrapMode: textEdit.wrapMode

    property alias textEditElement: textEdit
    property alias borderImage: borderImage

    height: Math.min(maxHeight, Math.max(minHeight, textEdit.textModel.height + textEdit.anchors.margins * 2))

    // functions
    function copy() {textEdit.copy();}
    function paste() {textEdit.paste();}
    function cut() {textEdit.cut();}
    function moveCursorSelection(position) {textEdit.moveCursorSelection(position)}
    function selectAll() {textEdit.selectAll()}
    function selectWord() {textEdit.selectWord()}

    function forceActiveFocus() {
        textEdit.forceActiveFocus()
    }

    BorderImage {
        id: borderImage
        anchors.fill: parent
        border { left: 21; top: 20; right: 21; bottom: 20 }
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
        source: {
            if(container.readOnly) return disabledImage
            else if(textEdit.focus) return selectedImage
            else return defaultImage
        }
        property string defaultImage: "assets/meegotouch-textedit/meegotouch-textedit-background.png"
        property string selectedImage: "assets/meegotouch-textedit/meegotouch-textedit-background-selected.png"
        property string disabledImage: "assets/meegotouch-textedit/meegotouch-textedit-background-disabled.png"
        property string errorImage: "assets/meegotouch-textedit/meegotouch-textedit-background-error.png"
    }

    Flickable {
        id: scrollContainer
        anchors.top: parent.top; anchors.bottom: parent.bottom; anchors.left: parent.left; anchors.right: parent.right;
        contentHeight: Math.max(parent.height, textEdit.textModel.height + container.documentMargin * 2)
        anchors.topMargin: 3
        anchors.bottomMargin: 3
        clip: true
        property bool moved: false
        contentY:  {
            if(scrollContainer.moving) scrollContainer.moved = true;
            else if(!scrollContainer.moved) {
                if(Math.max(0,textEdit.cursorRectangle.y - (parent.height) + container.documentMargin * 3) >= scrollContainer.contentY)
                    return Math.max(0,textEdit.cursorRectangle.y - (parent.height) + container.documentMargin * 3)
                if(Math.max(0,textEdit.cursorRectangle.y) <= scrollContainer.contentY)
                    return Math.max(0,textEdit.cursorRectangle.y)
            }
        }
        Behavior on contentY {
            NumberAnimation { duration: 50 }
        }
//        Rectangle {
//            anchors.fill: textEdit
//            color: Qt.rgba(1,0,0,0.5);
//        }
        TextEdit {
            id: textEdit
            property variant textModel: Text {
                width: textEdit.width
                wrapMode: textEdit.wrapMode
                font: textEdit.font;
                text: textEdit.text;
                visible: false
            }
            anchors.margins: container.documentMargin
            anchors.top: parent.top
            anchors.topMargin: 10
            anchors.left: parent.left
            anchors.right: parent.right
            height: parent.contentHeight

            activeFocusOnPress: true
            horizontalAlignment: TextEdit.AlignLeft
            wrapMode: TextEdit.WrapAtWordBoundaryOrAnywhere
            persistentSelection: false
            Keys.onPressed: scrollContainer.moved = false
            font.family: "Nokia Standard Light"
            font.pixelSize: 24
            color: (!container.readOnly) ? "#282828" : "#CCC"
        }
        MouseArea {
            id: mouseArea
            anchors.fill: parent
            onClicked: {
                textEdit.forceActiveFocus()
                textEdit.cursorPosition = textEdit.positionAt(Math.max(0, mouse.x - mouseArea.x - container.documentMargin), Math.max(0, mouse.y - mouseArea.y - container.documentMargin));
                if(container.selectionPolicy == "SelectAll") textEdit.selectAll();
                else if(container.selectionPolicy == "SelectWord") textEdit.selectWord();
            }
        }
    }
}
