import Qt 4.7

Item {
    // TODO: cleanup and sync with TextArea
    // TODO: The API does not match that of TextFiled component in qt-components, synchronization is needed.
    id: container

    property int documentMargin: 14

    property bool passwordMode
    property string selectionPolicy // enumeration. Select all, only one word, nothing, or ... on tap
    property string placeholderText
    property bool actionButtonEnabled: false
    property bool typeIconEnabled: false

    property alias inputMethodHints: textInput.inputMethodHints
    property alias font: textInput.font
    property alias cursorPosition: textInput.cursorPosition
    property alias readOnly: textInput.readOnly
    property alias displayText: textInput.displayText
    property alias horizontalAlignment: textInput.horizontalAlignment
    property alias inputMask: textInput.inputMask
    property alias selectedText: textInput.selectedText
    property alias selectionEnd: textInput.selectionEnd
    property alias selectionStart: textInput.selectionStart
    property alias text: textInput.text
    property alias acceptableInput: textInput.acceptableInput
    property alias validator: textInput.validator
    property alias maximumLength: textInput.maximumLength

    property alias textEditElement: textInput
    property alias borderImage: borderImage

    property alias iconSource: icon.source

    //width: Math.max(defaultWidth, textInput.textModel.width) + textInput.anchors.margins * 2

    width: 200
    height: textInput.textModel.height + textInput.anchors.margins * 2

    // functions
    function copy() {
        textInput.copy();
    }
    function paste() {
        textInput.paste();
    }
    function cut() {
        textInput.cut();
    }
    function moveCursorSelection(position) {
        textInput.moveCursorSelection(position)
    }
    function selectAll() {
        textInput.selectAll()
    }
    function selectWord() {
        textInput.selectWord()
    }

    function forceActiveFocus() {
        textInput.forceActiveFocus()
    }

    // signal TODO: this doesn't fire at the moment
    signal accepted
    signal actionButtonClicked

    BorderImage {
        id: borderImage
        anchors.fill: parent
        border { left: 21; top: 20; right: 21; bottom: 20 }
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
        source: {
            if(container.validator && !textInput.acceptableInput) return errorImage
            else if(container.readOnly) return disabledImage
            else if(textInput.focus) return selectedImage
            else return defaultImage
        }
        property string defaultImage: "assets/meegotouch-textedit/meegotouch-textedit-background.png"
        property string selectedImage: "assets/meegotouch-textedit/meegotouch-textedit-background-selected.png"
        property string disabledImage: "assets/meegotouch-textedit/meegotouch-textedit-background-disabled.png"
        property string errorImage: "assets/meegotouch-textedit/meegotouch-textedit-background-error.png"
    }

    TextInput {
        id: textInput
        property variant textModel: Text {
            font: textInput.font;
            text: container.text;
            visible: false
        }
        height: textInput.textModel.height
        anchors.left:parent.left
        anchors.right: {
            if(actionButton.visible) return actionButton.left
            else if(icon.visible) return icon.left
            else return parent.right
        }
        anchors.verticalCenter: container.verticalCenter
        anchors.margins: container.documentMargin
        //anchors.rightMargin: (actionButton.visible || icon.visible) ? 10 : 0
        echoMode: (!container.passwordMode) ? TextInput.Normal : TextInput.Password
        activeFocusOnPress: true
        horizontalAlignment: TextEdit.AlignLeft
        onAccepted: {
            container.accepted();
        }
        font.family: "Nokia Standard Light"
        font.pixelSize: 24
        color: (!container.readOnly) ? "#282828" : "#CCC"

    }

    Text {
        id: placeholder
        elide: Text.ElideRight
        textFormat: Text.PlainText
        anchors.verticalCenter: container.verticalCenter
        anchors.left:parent.left
        anchors.right: actionButton.left
        anchors.margins: container.documentMargin
        text: container.placeholderText
        font: textInput.font
        color: "#CCC"
        opacity:  (!textInput.focus && textInput.text.length < 1) ? 1 : 0
        horizontalAlignment: (container.horizontalAlignment != undefined) ? container.horizontalAlignment : Text.Left
    }
    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            textInput.forceActiveFocus()
            textInput.cursorPosition = textInput.positionAt(mouse.x - mouseArea.x - container.documentMargin);
            if(container.selectionPolicy == "SelectAll") textInput.selectAll();
            else if(container.selectionPolicy == "SelectWord") textInput.selectWord();
        }
    }

    BorderImage {
        property bool pressed: false
        id: actionButton
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        border { left: 21; top: 20; right: 21; bottom: 20 }
        horizontalTileMode: BorderImage.Repeat
        verticalTileMode: BorderImage.Repeat
        source: (actionButtonMouseArea.pressed) ? "assets/meegotouch-textedit/meegotouch-textedit-button-background-pressed-horizontal-right.png": "assets/meegotouch-textedit/meegotouch-textedit-button-background-horizontal-right.png"
        visible: container.actionButtonEnabled
        MouseArea {
            anchors.fill: parent
            id: actionButtonMouseArea
            onClicked: {
                container.actionButtonClicked();
            }
        }
    }

    Image {
        id: icon
        anchors.centerIn: actionButton
        anchors.horizontalCenterOffset: -2
        visible: (width != 0) ? true : false
    }

}
