import Qt 4.7

/*
   Class: TimePickerDialog
   Dialog that shows a time picker.

   WARNING:
   This component does not yet exist in qt-component, and the APIs are not yet agreed by the community.
   The final APIs may be different.
*/
Item {
    id: root

    /*
     * Property: title
     * [string] The title of the dialog.
     */
    property alias title: tumblerDialog.title

    /*
     * Property: mode24Hour
     * [bool=false] Sets if the time picker should show time in military time (24h).
     */
    property bool mode24Hour: false

    /*
     * Property: showSeconds
     * [bool=true] Sets if the time picker should show seconds.
     */
    property bool showSeconds: true

    /*
     * Property: acceptButtonLabel
     * [string] Optional, the button label for the accept button.
     */
    property alias acceptButtonLabel: tumblerDialog.acceptButtonLabel

    /*
     * Property: rejectButtonLabel
     * [string] Optional, the button label for the reject button.
     */
    property alias rejectButtonLabel: tumblerDialog.rejectButtonLabel

    /*
     * Property: deleteOnClose
     * [bool=false] Set to true if the dialog is created by a Loader, and should self destroy.
     *              when it is hided. Leave it at false otherwise.
     */
    property alias deleteOnClose: tumblerDialog.deleteOnClose

    /*
     * Event: selected
     * Is emitted when the user selects one of the buttons.
     */
    signal selected(string optionText, variant param)

    /*
     * Function: show
     * Makes the dialog visible.
     */
    function show(title, mode24Hour, showSeconds, acceptButtonLabel, rejectButtonLabel) {
        if (typeof(title) != "undefined" && title != null) {
            root.title = title;
        }
        if (typeof(mode24Hour) != "undefined" && mode24Hour != null) {
            root.mode24Hour = mode24Hour;
        }
        if (typeof(showSeconds) != "undefined" && showSeconds != null) {
            root.showSeconds = showSeconds;
        }
        if (typeof(acceptButtonLabel) != "undefined" && acceptButtonLabel != null) {
            root.acceptButtonLabel = acceptButtonLabel;
        }
        if (typeof(rejectButtonLabel) != "undefined" && rejectButtonLabel != null) {
            root.rejectButtonLabel = rejectButtonLabel;
        }
        if (!internal.initialised) {
            _initializeDataModels();
        }
        tumblerDialog.component = tumblerComponent;
        tumblerDialog.show();
        if (internal.selected.length != 0) {
            setTime(internal.selected[0], internal.selected[1], internal.selected[2]);
            internal.selected = [];
        }
        if (internal.enabled.length != 0) {
            setEnabled(internal.enabled[0], internal.enabled[1]);
            internal.enabled = [];
        }
    }

    /*
     * Function: hide
     * hides the dialog.
     */
    function hide() {
        tumblerDialog.hide();
    }

    /*
     * Function: getTime
     * Gets the time selected by the user as a Javascript Date object.
     */
    function getTime() {
        if (internal.initialised) {
            var offset = 0;
            if (!mode24Hour) {
                offset = (tumblerDialog.getSelected(showSeconds ? 3: 2) == 0 ? 0 : 12)
            }
            if (showSeconds) {
                return new Date(0, 0, 0,
                    tumblerDialog.getSelected(0) + offset,
                    tumblerDialog.getSelected(1),
                    tumblerDialog.getSelected(2)
                )
            }
            else {
                return new Date(0, 0, 0,
                    tumblerDialog.getSelected(0) + offset,
                    tumblerDialog.getSelected(1)
                )
            }
        }
        else {
            return null;
        }
    }

    /*
     * Function: setDate
     * Sets the date indicated by the "hour", "minute" and "second".
     */
    function setTime(hour, minute, second) {
        if (internal.initialised) {
            if (mode24Hour) {
                tumblerDialog.setSelected([hour, minute, second]);
            }
            else {
                if (showSeconds) {
                    tumblerDialog.setSelected([hour > 12 ? hour - 12 : hour, minute, second, hour > 12 ? 1 : 0])
                }
                else {
                    tumblerDialog.setSelected([hour, minute, hour > 12 ? 1 : 0])
                }
            }
        }
        else {
            internal.selected = [hour, minute, second];
        }
    }

    /*
     * Function: getEnabled
     * Returns the enabled status of the column "index"
     */
    function getEnabled(index) {
        if (internal.initialised) {
            return tumblerDialog.getEnabled(index);
        }
        else {
            return null;
        }
    }

    function setEnabled(index, value) {
        if (internal.initialised) {
            tumblerDialog.setEnabled(index, value);
        }
        else {
            internal.enabled = [index, value];
        }
    }

    /*
     * Function: setEnabled
     * Sets the enabled status of the column "index" with "value"
     */
    function _initializeDataModels() {
        for (var i = 0; i < (mode24Hour ? 24 : 12); i++) {
            hoursList.append({"value" : i + ""});
        }
        for (var i = 0; i < 60; i++) {
            minutesList.append({"value" : i + ""});
            secondsList.append({"value" : i + ""});
        }
        meridiemsList.append({"value" : "a.m."});
        meridiemsList.append({"value" : "p.m."});
        internal.initialised = true;
    }

    function _clearDataModels() {
        hoursList.clear();
        minutesList.clear();
        secondsList.clear();
        meridiemsList.clear();
    }

    anchors.fill: parent
    onShowSecondsChanged: {
        _clearDataModels();
        tumblerDialog.component = null;
        tumblerDialog.component = tumblerComponent;
        internal.initialised = false;
    }
    onMode24HourChanged: {
        _clearDataModels();
        tumblerDialog.component = null;
        tumblerDialog.component = tumblerComponent;
        internal.initialised = false;
    }

    TumblerDialogBase {
        id: tumblerDialog

        onSelected: root.selected(optionText, param)
    }

    Component {
        id: tumblerComponent

        Tumbler {
            id: tumbler

            items: showSeconds ?
                    (mode24Hour ?
                    [ hoursList, minutesList, secondsList ] :
                    [ hoursList, minutesList, secondsList, meridiemsList ]) :
                    (mode24Hour ?
                    [ hoursList, minutesList ] :
                    [ hoursList, minutesList, meridiemsList ])
            labels: showSeconds ? [ "HR", "MIN", "SEC" ] :
                    [ "HR", "MIN" ]
            _delayInit: true
        }
    }

    ListModel {
        id: hoursList
    }

    ListModel {
        id: minutesList
    }

    ListModel {
        id: secondsList
    }

    ListModel {
        id: meridiemsList
    }

    Item {
        id: internal

        property variant selected: []
        property variant enabled: []
        property variant initialised: false
    }
}
