import Qt 4.7

/*
   Class: Tumbler
   A tumbler.

   WARNING:
   This component does not yet exist in qt-component, and the APIs are not yet agreed by the community.
   The final APIs may be different.
*/
Item {
    id: root

    /*
     * Property: items
     * [ListModel] Array of ListModel for each column of the dialog.
     */
    property list<ListModel> items

    /*
     * Property: labels
     * [array] Array of string for the labels of each column.
     */
    property variant labels: []

    /*
     * Property: selectedItems
     * [array] Array of int for the selected item of each column.
     */
    property variant selectedItems: []

    /*
     * Property: enabled
     * [array] Array of bool for the enabled status of each column.
     */
    property variant enabled: []

    /*
     * Event: changed
     * Is emitted when the value of the tumbler changes.
     */
    signal changed(real index)

    /*
     * Function: getSelected
     * Gets the selected item for the column "index".
     */
    function getSelected(index) {
        if (typeof index == "number" && index >= 0 && index < itemListsModel.count) {
            return tumblersArea.children[index].tumblerList.currentIndex;
        }

        if (typeof index == "undefined") {
            var currentIndices = [];
            for (var count = 0; count < itemListsModel.count; count++) {
                currentIndices.push(tumblersArea.children[count].tumblerList.currentIndex);
            }
            return currentIndices;
        }

        return -1;
    }

    /*
     * Function: setSelected
     * Sets the selected item for the column "index".
     */
    function setSelected(index, value) {
        if (typeof value == "number" && typeof index == "number" && index >= 0 && index < itemListsModel.count) {
            tumblersArea.children[index].tumblerList.positionViewAtIndex(value, ListView.Center);
            changed(index);
        }
        else if (typeof index == "object" && !!index.length) {
            for (var count = 0; count < itemListsModel.count && count < index.length; count++) {
                tumblersArea.children[count].tumblerList.positionViewAtIndex(index[count], ListView.Center);
                changed(count);
            }
        }
    }

    /*
     * Function: getEnabled
     * Returns the enabled status of the column "index"
     */
    function getEnabled(index) {
        if (typeof index == "number" && index >= 0 && index < itemListsModel.count) {
            return !itemListsModel.get(index).disabled;
        }
        else if (typeof index == "undefined") {
            var enabledState = [];
            for (var count = 0; count < itemListsModel.count; count++) {
                enabledState.push(!itemListsModel.get(count).disabled);
            }
            return enabledState;
        }
        return false;
    }

    /*
     * Function: setEnabled
     * Sets the enabled status of the column "index" with "value"
     */
    function setEnabled(index, value) {
        if (typeof index == "number" && index >= 0 && index < itemListsModel.count) {
            itemListsModel.setProperty(index, "disabled", !value)
        }
        else if (typeof index == "object" && !!index.length) {
            for (var count = 0; count < itemListsModel.count && count < index.length; count++) {
                itemListsModel.setProperty(count, "disabled", !value)
            }
        }
    }

    function _initializeTumbler()
    {
        for (var index = 0; index < items.length; index++) {
            if (items[index]) {
                var label = labels[index] || "";
                itemListsModel.append({ "items": items[index], "label": label, "selected": selectedItems[index], "disabled": typeof(enabled[index]) == "undefined" ? false : !enabled[index] });
            }
        }
        _initialized = true;
    }

    /* private */
    property bool _delayInit: false
    property bool _initialized: false

    anchors.fill: parent

    clip: true
    Component.onCompleted: {
        if (!_delayInit && !_initialized) {
            _initializeTumbler();
        }
    }

    ListModel { id: itemListsModel }

    Item {
        id: internal

        property int columnWidth: !!itemListsModel.count ? Math.floor(root.width / itemListsModel.count) : 0
        property int calculatedWidth: columnWidth * itemListsModel.count;
        property int labelHeight: 54
    }

    Rectangle {
        width: internal.calculatedWidth
        height: root.height - internal.labelHeight - 2 // decrease by bottom text & border height
        color: "#000000"
        anchors { top: parent.top; topMargin: 1 }
    }

    BorderImage {
        width: internal.calculatedWidth
        height: root.height - internal.labelHeight  // decrease by bottom text height
        source: "assets/meegotouch-objectmenu/meegotouch-button-objectmenu-background.png"
        anchors.top: parent.top
        border { left: 1; top: 1; right: 1; bottom: 1 }
    }

    Row {
        id: tumblersArea
        anchors { top: parent.top; topMargin: 1 }
        Repeater {
            model: itemListsModel
            delegate: tumblerColumn
        }
    }

    Component {
        id: tumblerColumn

        Column {
            property alias tumblerList: tumblerList

            opacity: !!disabled ? 0.4 : 1.0

            ListView {
                id: tumblerList

                property real entryHeight: !!currentItem ? currentItem.height : 0
                preferredHighlightBegin: Math.floor( (height - entryHeight) / 2 )
                preferredHighlightEnd: preferredHighlightBegin + entryHeight
                highlightRangeMode: ListView.StrictlyEnforceRange
                clip: true
                model: items
                delegate: defaultTumblerDelegate
                highlight: defaultTumblerHighlight
                interactive: !disabled
                width: internal.columnWidth
                height: root.height - internal.labelHeight - 2  // decrease by text & border heights
                Component.onCompleted: positionViewAtIndex(selected, ListView.Center)
                onMovementEnded: root.changed(index) // got index from delegate
                maximumFlickVelocity: 700

                Rectangle {
                    visible: !!index
                    width: 1
                    height: parent.height
                    color: "#FFFFFF"
                    opacity: 0.1
                }
            }

            Item {
                width: internal.columnWidth
                height: internal.labelHeight

                Text {
                    text: label
                    elide: Text.ElideRight
                    horizontalAlignment: "AlignHCenter"
                    color: "#8C8C8C"
                    font { family: "Nokia Standard Light"; pixelSize: 22 }
                    anchors { fill: parent; margins: 16}
                }
            }
        }
    }

    Component {
        id: defaultTumblerDelegate

        Item {
            width: parent.width
            height: 64

            Text {
                text: !!value ? value : ""
                elide: Text.ElideRight
                horizontalAlignment: "AlignHCenter"
                color: "#FFFFFF"
                font { family: "Nokia Standard"; pixelSize: 24; bold: true }
                anchors { fill: parent; margins: 16 }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if(tumblerList.interactive) {
                            tumblerList.currentIndex = index;  // got index from delegate
                        }
                    }
                }
            }
        }
    }

    Component {
        id: defaultTumblerHighlight

        Image {
            id: name
            width: parent.width
            source: "assets/meegotouch-objectmenu/meegotouch-button-objectmenu-background-background-selected-horizontal-right.png"
            fillMode: Image.TileHorizontally
        }
    }
}
