import Qt 4.7

/*
   Class: TumblerDialog
   Dialog that shows a tumbler.

   WARNING:
   This component does not yet exist in qt-component, and the APIs are not yet agreed by the community.
   The final APIs may be different.
*/
Item {
    id: root

    /*
     * Property: title
     * [string] The title of the dialog.
     */
    property alias title: tumblerDialog.title

    /*
     * Property: items
     * [ListModel] Array of ListModel for each column of the dialog.
     */
    property variant items: []

    /*
     * Property: labels
     * [array] Array of string for the labels of each column.
     */
    property variant labels: []

    /*
     * Property: selectedItems
     * [array] Array of int for the selected item of each column.
     */
    property variant selectedItems: []

    /*
     * Property: enabled
     * [array] Array of bool for the enabled status of each column.
     */
    property variant enabled: []

    /*
     * Property: acceptButtonLabel
     * [string] Optional, the button label for the accept button.
     */
    property alias acceptButtonLabel: tumblerDialog.acceptButtonLabel

    /*
     * Property: rejectButtonLabel
     * [string] Optional, the button label for the reject button.
     */
    property alias rejectButtonLabel: tumblerDialog.rejectButtonLabel

    /*
     * Property: deleteOnClose
     * [bool=false] Set to true if the dialog is created by a Loader, and should self destroy.
     *              when it is hided. Leave it at false otherwise.
     */
    property alias deleteOnClose: tumblerDialog.deleteOnClose

    /*
     * Event: selected
     * Is emitted when the user selects one of the buttons.
     */
    signal selected(string optionText, variant param)

    /*
     * Function: show
     * Makes the dialog visible.
     */
    function show(items, title, labels, selectedItems, enabled, acceptButtonLabel, rejectButtonLabel) {
        if (typeof(title) != "undefined" && title != null) {
            root.title = title;
        }
        if (typeof(items) != "undefined" && items != null) {
            root.items = items;
        }
        if (typeof(labels) != "undefined" && labels != null) {
            root.labels = labels;
        }
        if (typeof(selectedItems) != "undefined" && selectedItems != null) {
            root.selectedItems = selectedItems;
        }
        if (typeof(enabled) != "undefined" && enabled != null) {
            root.enabled = enabled;
        }
        if (typeof(acceptButtonLabel) != "undefined" && acceptButtonLabel != null) {
            root.acceptButtonLabel = acceptButtonLabel;
        }
        if (typeof(rejectButtonLabel) != "undefined" && rejectButtonLabel != null) {
            root.rejectButtonLabel = rejectButtonLabel;
        }

        tumblerDialog.component = tumblerComponent;
        tumblerDialog.componentProperties.items = root.items;
        tumblerDialog.componentProperties.labels = root.labels;
        tumblerDialog.componentProperties.selectedItems = root.selectedItems;
        tumblerDialog.componentProperties.enabled = root.enabled;
        tumblerDialog.show();
    }

    /*
     * Function: hide
     * hides the dialog.
     */
    function hide() {
        tumblerDialog.hide();
    }

    /*
     * Function: getSelected
     * Gets the selected item for the column "index".
     */
    function getSelected(index) {
        return tumblerDialog.getSelected(index);
    }

    /*
     * Function: setSelected
     * Sets the selected item for the column "index".
     */
    function setSelected(index, value) {
        return tumblerDialog.setSelected(index, value);
    }

    /*
     * Function: getEnabled
     * Returns the enabled status of the column "index"
     */
    function getEnabled(index) {
        return tumblerDialog.getEnabled(index);
    }

    /*
     * Function: setEnabled
     * Sets the enabled status of the column "index" with "value"
     */
    function setEnabled(index, value) {
        return tumblerDialog.setEnabled(index, value);
    }

    anchors.fill: parent

    TumblerDialogBase {
        id: tumblerDialog

        onSelected: root.selected(optionText, param)
    }

    Component {
        id: tumblerComponent

        Tumbler {
            id: tumbler

            _delayInit: true
        }
    }
}
