import Qt 4.7
import "constants.js" as C

Item {
    id: root

    property string title
    property string acceptButtonLabel: "CONFIRM"
    property string rejectButtonLabel: "CANCEL"
    property alias component: loader.sourceComponent
    property alias componentProperties: loader.item // bridge to the actual tumbler
    property bool deleteOnClose: false

    signal selected(string optionText, variant param)

    function show() {
        if (loader.item && !loader.item._initialized) {
            loader.item._initializeTumbler();
        }
        diaBg.state = "visible";
    }

    function hide() {
        diaBg.state = "hidden";
    }

    function getSelected(index) {
        return loader.item ? loader.item.getSelected(index) : -1;
    }

    function setSelected(index, value) {
        return loader.item ? loader.item.setSelected(index, value) : -1;
    }

    function getEnabled(index) {
        return loader.item ? loader.item.getEnabled(index) : false;
    }

    function setEnabled(index, value) {
        return loader.item ? loader.item.setEnabled(index, value) : false
    }

    anchors.fill: parent

    DialogBackground {
        id: diaBg

        onTransitionCompleted: {
            if (diaBg.state == "hidden" && root.deleteOnClose) {
                root.destroy();
            }
        }

        modal: false
        content:
            Item {
                id: dialog

                function buttonClicked(text, param) {
                    root.selected(text, param)
                    root.hide()
                }

                opacity: 0
                anchors { horizontalCenter: parent.horizontalCenter; verticalCenter: parent.verticalCenter }

                NumberAnimation on opacity {
                    id: animDialog

                    to: 1
                    duration: 400
                }

                Item {
                    id: tRect

                    height: 48
                    width: loader.width
                    anchors.top: parent.top

                    Text {
                        id: tTitle

                        color: "#1080DD"
                        font { pixelSize: 32; family: "Nokia Standard Light" }
                        anchors { top: parent.top; left: parent.left; right: parent.right; leftMargin: 8; rightMargin: 8 }
                        text: root.title
                        elide: Text.ElideRight
                    }
                }

                Loader {
                    id: loader  // this is the tumbler region

                    width: parent.width
                    height: dialog.height - 48 - 16 - C.SIZE_BUTTON // reduce by top title, margin, & bottom button
                    anchors.top: tRect.bottom
                }

                Button {
                    id: acceptButton

                    __type: "inverted"
                    text: root.acceptButtonLabel
                    anchors { top: loader.bottom; left: parent.left; right: buttonDivider.left; topMargin: 16 }
                    onClicked: dialog.buttonClicked(text, C.DIALOG_ACCEPT_BUTTON)


                }

                Item {
                    id: buttonDivider
                    width: 6
                    anchors { top: loader.bottom; topMargin: 16; horizontalCenter: parent.horizontalCenter }
                }

                Button {
                    id: rejectButton

                    __type: "inverted"
                    text: root.rejectButtonLabel
                    anchors { top: loader.bottom; left: buttonDivider.right; right: parent.right; topMargin: 16 }
                    onClicked: dialog.buttonClicked(text, C.DIALOG_REJECT_BUTTON)
                }
            }
    }

    states: [
        State {
            name: "landscape"
            when: root.width > root.height
            PropertyChanges {
                target: dialog
                height: root.height * 0.9
                width: root.width * 0.52
            }

            PropertyChanges {
                target: acceptButton
                anchors.leftMargin: root.width * 0.0185
            }

            PropertyChanges {
                target: rejectButton
                anchors.rightMargin: root.width * 0.0185
            }
        },
        State {
            name: "portrait"
            when: root.width <= root.height
            PropertyChanges {
                target: dialog
                height: root.height * 0.5
                width: root.width * 0.933
            }

            PropertyChanges {
                target: acceptButton
                anchors.leftMargin: root.width * 0.033
            }

            PropertyChanges {
                target: rejectButton
                anchors.rightMargin: root.width * 0.033
            }

        }
    ]
}
