import Qt 4.7
import "components"
import "components/asgard"

Window {
    id: window
    property bool appVisibility: visibilityMonitor.visible

    signal startProfiler(string profileName);
    signal stopProfiler(string profileName);
    signal stopAndRemoveProfiler(string profileName);

    color: theme.backgroundColor;

    onAppVisibilityChanged: {
        if (!appVisibility) {
            musicPlayer.stop();
        }
    }

    Theme {
        id: theme
    }

    PageStack {
        id: pageStack

        toolBar: tb

        anchors.top: parent.top
        anchors.bottom: tb.top
    }

    ToolBar {
        id: tb
        anchors.bottom: parent.bottom
    }

/*
    MattiHelper {
    	id: mattiHelper
        objectName: "mattiHelper"
        anchors.right: parent.right
    }
*/

    MusicPlayer {
        id: musicPlayer
    }

    DownloadEngine {
        id: downloadEngine
    }

    ToolBarTabLayout {
        id: fullToolbar
        objectName: "toolbar"
        visible: pageStack.currentPage.tools != null

        ToolItem {
            id: backBtn
            objectName: "back"

            iconId: "icon-m-toolbar-back"
            enabled: (pageStack.depth > 1) ? true : false
            opacity: (enabled == true) ? 1 : 0
            onClicked: if (enabled == true) {
                window.back();
            }
        }

        TabButtonRow {
            id: tabs
            displayMode: "Icon"
            width: parent.width
            height: parent.height

            function getIconSource(source, pressed, checked, enabled) {
                return "../images/navbar/" + source  + (pressed ? "" : (checked ? "-selected" : (enabled ? "" : "-disabled"))) + ".png"
            }

            TabButton {
                id: homeBtn
                objectName: "home"
                checked: true
                enabled: (checked == true && pageStack.currentPage.parentComponent == homeViewComponent) ? false : true
                iconSource: tabs.getIconSource("home", pressed, checked, enabled)
                onClicked: {
                    window.clearHistory();
                    window.loadPage(homeViewComponent, "");
                }
            }
            TabButton {
                id: categoriesBtn
                objectName: "categories"
                iconSource: tabs.getIconSource("categories", pressed, checked, enabled)
                enabled: (checked == true && pageStack.currentPage.parentComponent == genreHubViewComponent) ? false : true
                onClicked: {
                    window.clearHistory();
                    window.loadPage(genreHubViewComponent, "");
                }
            }

            TabButton {
                id: searchBtn
                objectName: "search"
                iconSource: tabs.getIconSource("search", pressed, checked, enabled)
                enabled: (checked == true && pageStack.currentPage.parentComponent == searchViewComponent) ? false : true
                onClicked: {
                    window.clearHistory();
                    window.loadPage(searchViewComponent, "");
                }
            }

            TabButton {
                id: accountBtn
                objectName: "account"
                iconSource: tabs.getIconSource("account", pressed, checked, enabled)
                enabled: (checked == true && pageStack.currentPage.parentComponent == accountViewComponent) ? false : true
                onClicked: {
                    window.clearHistory();
                    window.loadPage(accountViewComponent, "");
                }

                //Download indicator
                CountBubble {
                    id: downloadCount
                    anchors.right: parent.right
                    y: 3
                    visible: (value > 0) ? true : false
                    value: downloadEngine.totalDownloads
                }
            }
        }
    }
 
    Component {
        id: firstTimeUseViewComponent
        FirstTimeUseView {
            id: firstTimeUseView
            //Parent component reference is used for handling errors on backward navigation
            //This must be provided by any view that needs to handle network errors
            property variant parentComponent: firstTimeUseViewComponent

        }
    }

    Component {
        id: productViewComponent
        ProductView {
            id: productView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: productViewComponent
        }
    }

    Component {
        id: rightsViewComponent
        RightsView {
            id: rightsView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: rightsViewComponent
        }
    }

    Component {
        id: artistViewComponent
        ArtistView {
            id: artistView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: artistViewComponent
        }
    }

    Component {
        id: similarArtistViewComponent
        SimilarArtistsView {
            id: similarArtistView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: similarArtistViewComponent
        }
    }

    Component {
        id: homeViewComponent
        HomeView {
            id: homeView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: homeViewComponent
        }
    }

    Component {
        id: redeemVoucherInPurchaseOptionsComponent
        RedeemVoucherInPurchaseOptionsView {
            id: redeemVoucherInPurchaseOptionsView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: redeemVoucherInPurchaseOptionsComponent
        }
    }

    Component {
        id: searchViewComponent
        SearchView {
            id: searchView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: searchViewComponent
        }
    }

    Component {
        id: accountViewComponent
        AccountView {
            id: accountView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: accountViewComponent
        }
    }

    Component {
        id: debugComponent
        DebugView {
            id: debugView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: debugComponent
        }
    }
    
    Component {
        id: ssoTestView
        SSOTestView {
            tools: fullToolbar
            property variant parentComponent: ssoTestView
	}
    }

    Component {
        id: categoriesViewComponent
        CategoriesView {
            id: categoriesView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: categoriesViewComponent
        }
    }

    Component {
        id: genreHomeViewComponent
        GenreHomeView {
            id: genreHomeView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: genreHomeViewComponent
        }
    }

    Component {
        id: genreHubViewComponent
        GenreHubView {
            id: genreHubView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: genreHubViewComponent
        }
    }

    Component {
        id: pinEntryViewComponent
        PinEntryView {
            id: pinEntryView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: pinEntryViewComponent
        }
    }

    Component {
        id: noConnectionViewComponent
        NoConnectionView {
            id: conConnectionView
            property variant context: viewLoadContext
            property variant parentComponent: noConnectionViewComponent
        }
    }

    Component {
        id: errorViewComponent
        ErrorView {
            id: errorView
            tools: fullToolbar
            property variant context: errorTitle
            property variant parentComponent: errorViewComponent
        }
    }

    Component {
        id: notImplementedViewComponent
        NotImplementedView {
            id: notImplementedView
            tools: fullToolbar
            property variant context: viewLoadContext
            property variant parentComponent: notImplementedViewComponent
        }
    }
    
    function initialiseView () {
        if (typeof morpheusSettings.territory  === "string" && morpheusSettings.territory !== "") {
            window.loadPage(homeViewComponent, '');
        } else {
            window.loadPage(firstTimeUseViewComponent, '');
        }
    }

    Component.onCompleted: {
        window.initialiseView();
    }

    function idToComponent(id) {
        if( id == "productViewComponent" ) {
            return productViewComponent;
        }
        else if( id == "artistViewComponent" ) {
            return artistViewComponent;
        }
        else if( id == "homeViewComponent" ) {
            return homeViewComponent;
        }
        else {
            return null
        }
    }

    function loadPageById(id, context) {
        var component = idToComponent(id);
        loadPage(component, context)
    }

    function nextPageById(id, context) {
        var component = idToComponent(id);
        nextPage(component, context)
    }
}
