.pragma library

Qt.include("settings.js");
Qt.include("xhr.js");
Qt.include("dataUtils.js");
Qt.include("uri.js");



// can take a top tracks or top albums url and populate the model
function loadCharts(URI, targetModel, callBack, errorBack) {

    var i, cb, successCB;

    successCB = function (responseObject) {
        var numItems = responseObject.items.length, currItem;

        targetModel.clear();

        for (i = 0; i < numItems; i++) {
            currItem = responseObject.items[i];
            targetModel.append({index: i,
                                albumArt100: currItem.albumArt100,
                                albumArt200: currItem.albumArt200,
                                artistName: getValueFromStringOrArray(currItem.artistName),
                                name: currItem.name,
                                duration: currItem.duration,
                                trackCount: "",
                                dataProductID: currItem.id});
        }
        console.log("loadCharts: loaded");
        callBack(responseObject);
    };

    return xhr.jsonGET(URI, successCB, errorBack);
}



/* example usage:
var gsdurl = "http://api.music.ovi.com/1.0/?format=json&token=04975228-bff5-4db0-83e7-e370250c6787&testStores=false&useip=false";

StoreAPI.loadGSD(gsdurl, GSDModel, function (obj){console.log("wahoo got master gsd:" + JSON.stringify(obj));console.log("wahoo got updated model:" + JSON.stringify(gsdmodel));});
*/
function loadGSD(URI, targetModel, callBack, errorBack) {

    var i, cb, successCB, gsdOptions;

    successCB = function (responseObject) {

        var numItems = responseObject.workspace.length, currItem;

        targetModel.clear();

        for (i = 0; i < numItems; i++) {
            currItem = responseObject.workspace[i];
            targetModel.append(currItem);
        }
        console.log("loadGSD: loaded");
        callBack(responseObject);
    };

    // use an object argument as we need to ignore the 404
    gsdOptions = {
        headers: {"X": "Overridden"},
        uri: URI,
        ignore404: true // currently pointless due to XMLHttpRequest implementation :(
    };

    return xhr.jsonGET(gsdOptions, successCB, errorBack);
}

function loadProduct(URI, targetModel, callBack, errorBack) {
    var successCB = function (responseObject) {
        var i, p;
        for (i = 0; i < responseObject.length; i += 1) {
            var p = responseObject[i];
            targetModel.append({
                index: i,
                name: p.name,
                type: p.type,
                artistName: getValueFromStringOrArray(p.artistName),
                artistID: getValueFromStringOrArray(p.artistId),
                albumArt200: p.albumArt200,
                takenFrom: p.takenFrom,
                takenFromURI: p.takenFromUri,
                genre: p.genreName,
                genreID: p.genreId,
                label: p.label,
                dataProductID: p.id,
                trackCount: p.trackCount,
                duration: p.duration,
                price: p.priceValue
            });
        }
        callBack();
    };
    return xhr.jsonGET(URI, successCB, errorBack);
}


























function getProductData(URI, targetModel, callBack, errorBack) {
    var doc = new XMLHttpRequest();
    doc.onreadystatechange = function() {
        targetModel.clear();
        if (doc.readyState == XMLHttpRequest.HEADERS_RECEIVED) {
        } else if (doc.readyState == XMLHttpRequest.DONE) {
            if (doc.status == 200) {
                //get the items
                var a = JSON.parse (doc.responseText).items;
                for (var i = 0; i < a.length; i++) {
                    var p = a[i];
                    targetModel.append({index: i,
                                        name: p.name,
                                        type: p.type,
                                        artistName: getValueFromStringOrArray(p.artistName),
                                        artistID: getValueFromStringOrArray(p.artistId),
                                        albumArt200: p.albumArt200,
                                        takenFrom: p.takenFrom,
                                        takenFromURI: p.takenFromUri,
                                        genre: p.genreName,
                                        genreID: p.genreId,
                                        label: p.label,
                                        dataProductID: p.id,
                                        trackCount: p.trackCount,
                                        duration: p.duration,
                                        price: p.priceValue,
                                        });
                }
                callBack();
            } else {
                errorBack("Error getting product data");
            }
        }
    }
    doc.open("GET", URI);
    doc.send();
}

function getProductRecommendations(URI, targetModel, callBack, errorBack) {
    var doc = new XMLHttpRequest();
    doc.onreadystatechange = function() {
        targetModel.clear();
        if (doc.readyState == XMLHttpRequest.HEADERS_RECEIVED) {
        } else if (doc.readyState == XMLHttpRequest.DONE) {
            if (doc.status == 200) {
                //get the items
                var a = JSON.parse (doc.responseText).items;
                for (var i = 0; i < a.length; i++) {
                    var p = a[i];
                    targetModel.append({index: i,
                                        name: p.name,
                                        artistName: getValueFromStringOrArray(p.artistName),
                                        trackCount: p.trackCount,
                                        duration: p.duration,
                                        albumArt100: p.albumArt100,
                                        dataProductID: p.id,
                                        });
                }
                callBack();
            } else {
                errorBack("Error getting product recommendations");
            }
        }
    }
    doc.open("GET", URI);
    doc.send();
}

function getGenresList(URI, targetModel, callBack, errorBack) {
    var doc = new XMLHttpRequest(), i, p, a;

    doc.onreadystatechange = function() {
        targetModel.clear();
        if (doc.readyState == XMLHttpRequest.HEADERS_RECEIVED) {
        } else if (doc.readyState == XMLHttpRequest.DONE) {
            if (doc.status == 200) {
                //get the items
                a = JSON.parse(doc.responseText).workspace[0].collection;
                a.sort(sortAlphaByTitle);

                for (i = 0; i < a.length; i++) {
                    p = a[i];
                    targetModel.append({index: i,
                                        name: p.title,
                                        genreID: p.genreId,
                                        genreTitle: p.uri
                                        });
                }
                callBack();
            } else {
                errorBack("Error getting genres list");
            }
        }
    }
    doc.open("GET", URI);
    doc.send();
}

function getGenreData(URI, targetModel, callBack, errorBack) {
    var doc = new XMLHttpRequest();
    doc.onreadystatechange = function() {
        targetModel.clear();
        if (doc.readyState == XMLHttpRequest.HEADERS_RECEIVED) {
        } else if (doc.readyState == XMLHttpRequest.DONE) {
            if (doc.status == 200) {
                //get the items
                var a = JSON.parse (doc.responseText).items;
                for (var i = 0; i < a.length; i++) {
                    var p = a[i];
                    targetModel.append({index: i,
                                        name: p.name,
                                        type: p.type,
                                        artistName: getValueFromStringOrArray(p.artistName),
                                        artistID: getValueFromStringOrArray(p.artistId),
                                        albumArt100: p.albumArt100,
                                        albumArt200: p.albumArt200,
                                        genre: p.genreName,
                                        dataProductID: p.id,
                                        trackCount: p.trackCount,
                                        duration: p.duration,
                                        price: p.priceValue,
                                        })
                }
                callBack();
            } else {
                errorBack("Error getting genre data");
            }
        }
    }
    doc.open("GET", URI);
    doc.send();
}



