import Qt 4.7
import "UIComponents"

Rectangle {
    id: wrapper
    height: (showDevice == true) ? 1200 : deviceResHeight - meegoHeaderHeight
    width: (showDevice == true) ? 1200 : deviceResWidth
    color: "#000"

    //Application Configuration
    property string baseStoreURL: "http://api.music.ovi.com/1.0/" + territory + "/";
    //property string baseStoreURL: "http://api.music.cq1.brislabs.com/1.0/" + territory + "/";
    property string territory: "gb";
    property string papiToken: "04975228-bff5-4db0-83e7-e370250c6787";

    //Session Variables
    property int ongoingDownloads: 0;
    property string currentContainer: "view1";
    property string viewsLocation: "Views/";

    //Base Layout Settings
    property string orientation: (runtime.orientation == 1 || runtime.orientation == 3) ? "portrait" : "landscape";
    property bool showDevice: false;
    property int meegoHeaderHeight: 25;
    property int deviceResHeight: (orientation == "portrait") ? 864 : 480;
    property int deviceResWidth: (orientation == "portrait") ? 480 : 864;

    Image {
        id: appFraming
        z: 1
        visible: (showDevice == true) ? true : false
        anchors.centerIn: parent
        source: (orientation == "portrait") ? "Resources/framingPortrait.png" : "Resources/framingLandscape.png";
        anchors.verticalCenterOffset: (orientation == "portrait") ? -12 : -5;
        anchors.horizontalCenterOffset: (orientation == "portrait") ? -10 : 0;
    }

    Rectangle {
        id: appRoot

        anchors.centerIn: parent
        width: deviceResWidth
        height: deviceResHeight - meegoHeaderHeight
        clip: true
        color: "#F1F1F1"

        /**
        * Global App Functions
        */

        //Initialise the first view
        function init() {
            navHistory.append({viewName: "Home.qml", context: ""});
            view1.source = viewsLocation + navHistory.get(0).viewName;
        }

        //Switch views and amend the navigation history
        function switchView(viewName, direction, context) {
            if (currentContainer === "view1") {
                if (direction === "forward") {
                    navHistory.append({viewName: viewName, context: context});
                    view2.source = "";
                    view2.source = viewsLocation + viewName;
                    view2.item.contentY = 0;
                    view2.x = viewsContainer.width;
                    view2.state = "inRight";
                    view1.state = "outLeft";
                } else if (direction === "back") {
                    navHistory.remove(navHistory.count - 1);
                    view2.source = viewsLocation + navHistory.get(navHistory.count - 1).viewName;
                    view2.item.contentY = 0;
                    view2.x = viewsContainer.width * -1;
                    view2.state = "inLeft";
                    view1.state = "outRight";
                }
                currentContainer = "view2";
            } else {
                if (direction === "forward") {
                    navHistory.append({viewName: viewName, context: context});
                    view1.source = "";
                    view1.source = viewsLocation + viewName;
                    view1.item.contentY = 0;
                    view1.x = viewsContainer.width;
                    view1.state = "inRight";
                    view2.state = "outLeft";
                } else if (direction === "back") {
                    navHistory.remove(navHistory.count - 1);
                    view1.source = viewsLocation + navHistory.get(navHistory.count - 1).viewName;
                    view1.item.contentY = 0;
                    view1.x = viewsContainer.width  * -1;
                    view1.state = "inLeft";
                    view2.state = "outRight";
                }
                currentContainer = "view1";
                return true;
            }
        }

        //Add a number of download items
        function addDownloads (numberOfDownloads) {
            if (typeof numberOfDownloads == "string" && numberOfDownloads != "") {
                numberOfDownloads = parseInt(numberOfDownloads);
            } else {
                numberOfDownloads = 1;
            }
            console.log(numberOfDownloads + " downloads added to queue");
            ongoingDownloads += numberOfDownloads;
            console.log("There are now " + ongoingDownloads + " ongoing downloads");
        }

        //Show the mini player
        function showPlayer (product, artist, price) {
            miniPlayer.productName = product
            miniPlayer.artistName = artist
            miniPlayer.productPrice = price
            miniPlayer.playing = false
            miniPlayer.state = "playing"
            miniPlayer.playing = true
        }

        //Hide the mini player
        function hidePlayer () {
            miniPlayer.state = "stopped"
            miniPlayer.playing = false
        }

        //Change Territory
        function changeTerritory (territoryName) {
            territory = territoryName;
            navHistory.clear();
            switchView("Home.qml", "forward", "");
        }

        function apiError (errorMessage) {
            console.log("appRoot.apiError: " + errorMessage);
        }

        //Render the first view
        Component.onCompleted: init();

        //This ListModel is used to store the navigation history
        ListModel {
            id: navHistory
        }

        //The two loaders here hold the views, and the states handle transition back and forth between the two in each direction
        Item {
            id: viewsContainer

            width: parent.width
            height: (parent.height - navBar.height - miniPlayer.height) - miniPlayer.anchors.bottomMargin

            //View container 1 (default)
            Loader {
                id: view1

                width: parent.width
                height: parent.height
                source: ""

                states: [
                    State {
                        name: "outLeft"
                        PropertyChanges { target: view1; x: viewsContainer.width * -1 }
                    },
                    State {
                        name: "outRight"
                        PropertyChanges { target: view1; x: viewsContainer.width * 1 }
                    },
                    State {
                        name: "inLeft"
                        PropertyChanges { target: view1; x: 0 }
                    },
                    State {
                        name: "inRight"
                        PropertyChanges { target: view1; x: 0 }
                    }
                ]

                transitions: [
                    Transition {
                        NumberAnimation { properties: "x"; easing.type: Easing.OutQuad; duration: 400 }
                    }
                ]

            }

            //View container 2
            Loader {
                id: view2

                width: parent.width
                height: parent.height
                source: ""

                states: [
                    State {
                        name: "outLeft"
                        PropertyChanges { target: view2; x: viewsContainer.width * -1 }
                    },
                    State {
                        name: "outRight"
                        PropertyChanges { target: view2; x: viewsContainer.width * 1 }
                    },
                    State {
                        name: "inLeft"
                        PropertyChanges { target: view2; x: 0 }
                    },
                    State {
                        name: "inRight"
                        PropertyChanges { target: view2; x: 0 }
                    }
                ]

                transitions: [
                    Transition {
                        NumberAnimation { properties: "x"; easing.type: Easing.OutQuad; duration: 400 }
                    }
                ]
            }
        }

        //Mini player control
        MiniPlayer {
            id: miniPlayer
            playing: false
            state: "stopped"
            anchors.bottom: navBar.top

            states: [
                State {
                    name: "playing"
                    PropertyChanges { target: miniPlayer; anchors.bottomMargin: 0 }
                },
                State {
                    name: "stopped"
                    PropertyChanges { target: miniPlayer; anchors.bottomMargin: - 76 }
                }
            ]

            transitions: [
                Transition {
                    NumberAnimation { properties: "anchors.bottomMargin"; easing.type: Easing.OutQuad; duration: 200 }
                }
            ]

            onStopped: appRoot.hidePlayer()
            onPurchased: appRoot.addDownloads(1)
        }

        //Global navigation toolbar
        NavBar {
            id: navBar
            anchors.bottom: parent.bottom
            height: 73
            width: parent.width
        }
    }
}
