import Qt 4.7
import "../UIComponents"
import "../Converters/durationConverter.js" as DurationConverter
import "../Converters/releaseDateConverter.js" as ReleaseDateConverter

Flickable {
    id: scroller

    property string artistName: "";
    property string context: navHistory.get(navHistory.count -1).context;
    property string mostDownloadedSource: "";
    property string topSongsSource: "";
    property string topSinglesSource: "";
    property string topAlbumsSource: "";

    function init () {
        mostDownloadedSource = baseStoreURL + "artists/" + context + "/top-tracks/?format=xml&itemsperpage=6&token=" + papiToken;
        topSongsSource = baseStoreURL + "artists/" + context + "/?category=track&format=xml&orderby=streetreleasedate&sortorder=descend&token=" + papiToken;
        topSinglesSource = baseStoreURL + "artists/" + context + "/?category=single&format=xml&orderby=streetreleasedate&sortorder=descend&token=" + papiToken;
        topAlbumsSource = baseStoreURL + "artists/" + context + "/?category=album&format=xml&orderby=streetreleasedate&sortorder=descend&token=" + papiToken;
    }

    //Set the model sources on view init so that request is not refired when the navstack item is removed on backward navigation
    Component.onCompleted: init();

    XmlListModel {
        id: artistPromoModel
        query: "/feed/entry"
        source: mostDownloadedSource
        namespaceDeclarations: "declare default element namespace 'http://www.w3.org/2005/Atom'; declare namespace oms=\"http://api.music.ovi.com/1.0/schema\";"

        XmlRole { name: "artistName"; query: "oms:metadata/primaryartist[1]/string()" }
        XmlRole { name: "productName"; query: "title/string()" }
        XmlRole { name: "albumArt200"; query: "link[@title=\"albumart200\"]/@href/string()" }
        XmlRole { name: "dataProductID"; query: "oms:metadata/id/string()" }

        onStatusChanged: {
            if (status == XmlListModel.Ready && artistPromoModel.count < 6) {
                //hide promo area when less than two results
                threeTrackPromo.visible = false
                threeTrackPromo.height = 0
            }
            if (status == XmlListModel.Ready && artistPromoModel.count > 0) {
                artistName = artistPromoModel.get(0).artistName;
            }
            if (status == XmlListModel.Ready && artistPromoModel.count >= 6) {
                //Populate the promo area
                threeTrackPromo.label1 = artistPromoModel.get(0).artistName
                threeTrackPromo.image1URL = artistPromoModel.get(0).albumArt200
                threeTrackPromo.link1ID = artistPromoModel.get(0).dataProductID
                threeTrackPromo.label2 = artistPromoModel.get(1).artistName
                threeTrackPromo.image2URL = artistPromoModel.get(1).albumArt200
                threeTrackPromo.link2ID = artistPromoModel.get(1).dataProductID
                threeTrackPromo.label3 = artistPromoModel.get(2).artistName
                threeTrackPromo.image3URL = artistPromoModel.get(2).albumArt200
                threeTrackPromo.link3ID = artistPromoModel.get(2).dataProductID
                threeTrackPromo.label4 = artistPromoModel.get(3).artistName
                threeTrackPromo.image4URL = artistPromoModel.get(3).albumArt200
                threeTrackPromo.link4ID = artistPromoModel.get(3).dataProductID
                threeTrackPromo.label5 = artistPromoModel.get(4).artistName
                threeTrackPromo.image5URL = artistPromoModel.get(4).albumArt200
                threeTrackPromo.link5ID = artistPromoModel.get(4).dataProductID
                threeTrackPromo.label6 = artistPromoModel.get(5).artistName
                threeTrackPromo.image6URL = artistPromoModel.get(5).albumArt200
                threeTrackPromo.link6ID = artistPromoModel.get(5).dataProductID
            }
        }
    }

    XmlListModel {
        id: artistListModel
        query: "/feed/entry"
        source: topSongsSource
        namespaceDeclarations: "declare default element namespace 'http://www.w3.org/2005/Atom'; declare namespace oms=\"http://api.music.ovi.com/1.0/schema\";"

        XmlRole { name: "trackCount"; query: "oms:metadata/trackcount/string()" }
        XmlRole { name: "name"; query: "title/string()" }
        XmlRole { name: "releaseDate"; query: "oms:metadata/streetreleasedate/string()" }
        XmlRole { name: "duration"; query: "oms:metadata/duration/string()" }
        XmlRole { name: "albumArt100"; query: "link[@title=\"albumart100\"]/@href/string()" }
        XmlRole { name: "dataProductID"; query: "oms:metadata/id/string()" }
    }

    contentWidth: childrenRect.width
    contentHeight: viewRoot.height
    flickableDirection: Flickable.VerticalFlick
    boundsBehavior: Flickable.StopAtBounds
    clip: true

    Rectangle {
        id: viewRoot
        height: childrenRect.height
        width: scroller.width
        color: "#00FFFFFF"


        Header1 {
            id: viewHeader
            headerText: artistName
        }

        ThreeTrackPromo {
            id: threeTrackPromo
            visible: true
            anchors.top: viewHeader.bottom
            height: childrenRect.height
            width: parent.width
        }

        Row {
            id: buttonRow
            anchors.top: threeTrackPromo.bottom
            anchors.topMargin: 15
            anchors.horizontalCenter: parent.horizontalCenter

            function switchToSingles() {
                singlesBtn.selected = true;
                songsBtn.selected = false;
                albumsBtn.selected = false;
                artistListModel.source = topSinglesSource;
            }

            function switchToSongs() {
                songsBtn.selected = true;
                singlesBtn.selected = false;
                albumsBtn.selected = false;
                artistListModel.source = topSongsSource;
            }

            function switchToAlbums() {
                albumsBtn.selected = true;
                singlesBtn.selected = false;
                songsBtn.selected = false;
                artistListModel.source = topAlbumsSource;
            }

            Button {
                id: songsBtn

                btnPosition: "left"
                groupSize: 3
                selected: true
                labelText: "Songs"
                onClicked: if (selected != true) {
                    buttonRow.switchToSongs()
                }
            }

            Image {
                width: 1
                source: "../Resources/btnGrp-3-Divider.png"
                height: 52
            }

            Button {
                id: albumsBtn

                btnPosition: "center"
                groupSize: 3
                selected: false
                labelText: "Albums"
                onClicked: if (selected != true) {
                    buttonRow.switchToAlbums()
                }
            }

            Image {
                width: 1
                source: "../Resources/btnGrp-3-Divider.png"
                height: 52
            }

            Button {
                id: singlesBtn

                btnPosition: "right"
                groupSize: 3
                selected: false
                labelText: "Singles"
                onClicked: if (selected != true) {
                    buttonRow.switchToSingles()
                }
            }
        }

        NoResultsText {
            id: noResultsText

            visible: (productsList.count == 0 && artistListModel.progress == 1) ? true : false
            displayText: if (artistListModel.source == topSongsSource) {
                "Sorry, we don't currently have any songs for this artist."
            } else if (artistListModel.source == topAlbumsSource) {
                "Sorry, we don't currently have any albums for this artist."
            } else if (artistListModel.source == topSinglesSource) {
                "Sorry, we don't currently have any singles for this artist."
            }

            anchors.top: buttonRow.bottom
            anchors.topMargin: 15
            anchors.left: parent.left
            anchors.leftMargin: 15
            anchors.right: parent.right
            anchors.rightMargin: 15
        }

        ListView {
            id: productsList

            anchors.top: buttonRow.bottom
            anchors.topMargin: 15
            height: childrenRect.height
            width: parent.width
            model: artistListModel
            delegate: homeItem
            interactive: false

            Component {
                id: homeItem

                ProductLink {
                    id: productLink
                    linkText1: name
                    linkText2: ReleaseDateConverter.convert(releaseDate)
                    linkText3: (duration == "") ? trackCount + " tracks" : DurationConverter.convert(duration)
                    packshotUrl: albumArt100
                    onClicked: appRoot.switchView("Product.qml", "forward", dataProductID)
                }
            }
        }
    }
}
