import Qt 4.7
import "../UIComponents"
import "../Converters/durationConverter.js" as DurationConverter

Flickable {
    id: scroller

    property string playlistHeaderText: "";
    property string playlistSource: "";

    function init () {
        playlistHeaderText = navHistory.get(navHistory.count -1).context.playlistName;
        playlistSource = navHistory.get(navHistory.count -1).context.playlistLocation + "?format=xml&token=" + papiToken;
    }

    Component.onCompleted: init();

    XmlListModel {
        id: playlistListModel
        query: "/feed/entry"
        source: playlistSource
        namespaceDeclarations: "declare default element namespace 'http://www.w3.org/2005/Atom'; declare namespace oms=\"http://api.music.ovi.com/1.0/schema\";"

        XmlRole { name: "artistName"; query: "oms:metadata/primaryartist[1]/string()" }
        XmlRole { name: "trackCount"; query: "oms:metadata/trackcount/string()" }
        XmlRole { name: "name"; query: "title/string()" }
        XmlRole { name: "duration"; query: "oms:metadata/duration/string()" }
        XmlRole { name: "albumArt200"; query: "link[@title=\"albumart200\"]/@href/string()" }
        XmlRole { name: "dataProductID"; query: "oms:metadata/id/string()" }
        XmlRole { name: "chartNumber"; query: "oms:metadata/sequence/string()" }
    }

    contentWidth: childrenRect.width
    contentHeight: viewRoot.height
    flickableDirection: Flickable.VerticalFlick
    boundsBehavior: Flickable.StopAtBounds
    clip: true

    Rectangle {
        id: viewRoot
        height: childrenRect.height
        width: scroller.width
        color: "#00FFFFFF"


        Header1 {
            id: viewHeader
            headerText: playlistHeaderText
        }

        GridView {
            id: productsList

            anchors.top: viewHeader.bottom
            height: childrenRect.height
            width: parent.width
            cellWidth: (orientation == "portrait") ? width / 2 : width / 4
            cellHeight: (orientation == "portrait") ? width / 2 : width / 4
            model: playlistListModel
            delegate: chartItem
            interactive: false

            Component {
                id: chartItem

                Rectangle {
                    height: (orientation == "portrait") ? parent.width / 2 : parent.width / 4
                    width: (orientation == "portrait") ? parent.width / 2 : parent.width / 4
                    color: "#00FFFFFF"

                    WebImage {
                        id: productLink
                        height: parent.height
                        width: parent.width
                        imageSource: albumArt200
                    }

                    Rectangle {
                        height: 50
                        width: parent.width
                        anchors.bottom: parent.bottom
                        color: "#99000000"

                        Text {
                            id: chartNo
                            width: 0
                            clip: true
                            text: (index + 1) + "."
                            font.pixelSize: 38
                            font.family: "Nokia Standard"
                            font.bold: true
                            anchors.top: parent.top
                            anchors.left: parent.left
                            anchors.leftMargin: 21
                            color: "#FFFFFF"
                        }
                        Text {
                            id: productLabel

                            text: name
                            font.pixelSize: 21
                            font.family: "Nokia Standard"
                            font.bold: true
                            width: (parent.width - chartNo.width) - 40
                            elide: Text.ElideRight
                            anchors.top: parent.top
                            anchors.left: chartNo.right
                            anchors.leftMargin: 12
                            anchors.topMargin: 2
                            color: "#FFFFFF"
                        }
                        Text {
                            id: artistLabel

                            text: artistName
                            font.pixelSize: 17
                            font.family: "Nokia Standard Light"
                            width: (parent.width - chartNo.width) - 40
                            elide: Text.ElideRight
                            anchors.top: productLabel.bottom
                            anchors.left: chartNo.right
                            anchors.leftMargin: 12
                            anchors.topMargin: -2
                            color: "#CACACA"
                        }

                    }

                    MouseArea {
                        anchors.fill: parent
                        onClicked: appRoot.switchView("Product.qml", "forward", dataProductID)
                    }
                }
            }
        }
    }
}
