import Qt 4.7
import "../UIComponents"
import "../Converters/parameterInsertion.js" as ParameterInsertion
import "../Converters/durationConverter.js" as DurationConverter

import "../API/StoreAPI.js" as StoreAPI

Flickable {
    id: scroller

    property string context: navHistory.get(navHistory.count -1).context;
    property string productSource: "";
    property string trackListSource: "";
    property string recommendationsSource: "";
    property string productName: "";
    property string productType: "";
    property string artistName: "";
    property string artistID: "";
    property string packshotURL: "";
    property string takenFrom: "";
    property string takenFromID: "";
    property string genre: "";
    property string genreID: "";
    property string label: "";
    property string trackCount: "";
    property int playingTrack: 0;

    function init () {
        productSource = baseStoreURL + "releases/" + context + "/?format=json&token=" + papiToken;
        recommendationsSource = baseStoreURL + "releases/" + context + "/similar/tracks/?format=json&itemsperpage=10&token=" + papiToken;
    }

    function onPrimaryContentLoad() {
        var processTakenFromID = function (takenFromId) {
            takenFromId = takenFromId.substring(0, takenFromId.lastIndexOf('/'));
            takenFromId = takenFromId.substring(takenFromId.lastIndexOf('/') + 1, takenFromId.length);
            return takenFromId;
        }

        console.log("onPrimaryContentLoad");

        var productObj = productModel.get(0);

        productType = productObj.type;
        if (productType == "musictrack") {
            takenFrom = productObj.takenFrom;
            takenFromID = processTakenFromID(productObj.takenFromURI);

        } else if (productType == "musiccollection") {
            trackCount = productObj.trackCount;
        }
        artistName = productObj.artistName;
        artistID = productObj.artistID;
        productName = productObj.name;
        packshotURL = productObj.albumArt200;
        genre = productObj.genre;
        genreID = productObj.genreID;
        label = productObj.label;
    }

    function onSecondaryContentLoad() {
        console.log("onSecondaryContentLoad");
    }

    function showHighlight (trackIndex) {
        playingTrack = trackIndex + 1;
    }

    //Set the model sources on view init so that request is not refired when the navstack item is removed on backward navigation
    Component.onCompleted: init();

    ListModel {
        id: productModel

        Component.onCompleted: StoreAPI.getProductData(productSource, productModel, onPrimaryContentLoad, appRoot.apiError);
    }

    ListModel {
        id: recommendationsModel

        Component.onCompleted: StoreAPI.getProductRecommendations(recommendationsSource, recommendationsModel, onSecondaryContentLoad, appRoot.apiError);
    }

    contentWidth: viewRoot.width
    contentHeight: viewRoot.height
    flickableDirection: Flickable.VerticalFlick
    boundsBehavior: Flickable.StopAtBounds
    clip: true

    Rectangle {
        id: viewRoot
        height: childrenRect.height
        width: scroller.width
        color: "#00FFFFFF"

        Header1 {
            id: viewHeader
            headerText: productName
        }

        TextLink {
            id: artistLink
            anchors.top: viewHeader.bottom
            anchors.left: parent.left
            anchors.leftMargin: 15
            width: scroller.width - 30
            textSize: 20
            linkText: artistName
            onClicked: appRoot.switchView("Artist.qml", "forward", artistID)
        }

        Rectangle {
            id: productInfo

            anchors.top: artistLink.bottom
            anchors.topMargin: 10
            color: "#00FFFFFF"
            width: parent.width
            height: childrenRect.height

            Item {
                width: parent.width
                height: childrenRect.height

                WebImage {
                    id: productImage
                    height: (productType == "musictrack") ? 400 : 290
                    width: (productType == "musictrack") ? 400 : 290
                    anchors.horizontalCenter: if (productType == "musictrack") {
                        parent.horizontalCenter
                    }
                    anchors.left: if (productType != "musictrack") {
                        parent.left
                    }
                    anchors.leftMargin: (productType == "musictrack") ? 0 : 15
                    imageSource: packshotURL
                }

                TakenFromLink {
                    width: 400
                    visible: (productType == "musictrack") ? true : false
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.bottom: productImage.bottom
                    labelText: ParameterInsertion.insertParams("From: {0}", [takenFrom])
                    onClicked: appRoot.switchView("Product.qml", "forward", takenFromID)
                }

                Column {
                    visible: (productType == "musictrack") ? false : true
                    width: parent.width - productImage.width
                    anchors.top: productImage.top
                    anchors.topMargin: 10
                    anchors.left: productImage.right
                    anchors.leftMargin: 10

                    Text {
                        font.pixelSize: 18
                        font.family: "Nokia Standard Light"
                        color: "#8C8C8C"
                        text: "Information:"
                    }

                    TextLink {
                        text: genre
                        width: parent.width - 30
                        elide: Text.ElideRight
                        textSize: 18
                        onClicked: appRoot.switchView("Genre.qml", "forward", genreID)
                    }

                    Text {
                        font.pixelSize: 18
                        font.family: "Nokia Standard Light"
                        width: parent.width - 30
                        elide: Text.ElideRight
                        color: "#8C8C8C"
                        text: label
                    }
                }
            }
        }

        Item {
            id: productActions
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: productInfo.bottom
            anchors.topMargin: 20
            height: childrenRect.height
            width: childrenRect.width

            Button {
                id: playBtn
                iconImage: "../Resources/playIcon.png"
                onClicked: if (productType == "musictrack") {
                    appRoot.showPlayer(productName, artistName, "£0.99");
                    showHighlight(0);
                } else {
                    appRoot.showPlayer(productModel.get(1).name, productModel.get(1).artistName, "£0.99");
                    showHighlight(0);
                }
            }

            Button {
                id: downloadBtn

                labelText: if (productType == "musictrack") {
                    "£0.79"
                } else if (productType == "musiccollection" && trackCount > 6) {
                    "£7.99"
                } else if (productType == "musiccollection" && trackCount == 1) {
                    "£0.79"
                } else {
                    "£1.99"
                }

                anchors.left: playBtn.right
                anchors.leftMargin: 10
                onClicked: appRoot.addDownloads(trackCount)
            }
        }

        ListHeader {
            id: listHeader

            visible: tracksList.visible
            headerText: if (productType == "musictrack") {
                "Ovi recommends"
            } else {
                if (productModel.count > 2) {
                    ParameterInsertion.insertParams("{0} Songs", [productModel.count - 1]);
                } else if (productModel.count - 1 == 1) {
                    ParameterInsertion.insertParams("{0} Song", [productModel.count - 1]);
                } else {
                    "";
                }
            }
            anchors.top: productActionsRule.verticalCenter
            anchors.topMargin: 1
        }

        HorizontalRule {
            id: productActionsRule

            visible: tracksList.visible
            anchors.top: productActions.bottom
            anchors.topMargin: 12
            width: parent.width
        }

        ListView {
            id: tracksList

            visible: (productType == "musictrack") ? false : true
            height: (productType == "musictrack") ? 0 : childrenRect.height
            anchors.top: listHeader.bottom
            width: parent.width
            model: productModel
            delegate: trackItem
            interactive: false

            Component {
                id: trackItem

                TrackListItem {
                    id: productLink

                    visible: (index == 0) ? false : true
                    height: (index == 0) ? 0 : height

                    highlightVisible: (miniPlayer.state == "playing" && playingTrack != 0 && index == playingTrack - 1) ? true : false
                    //Alternate row style
                    backgroundColor: if ((index) %2 == 0) {
                        "#E5E5E5";
                    } else {
                        "#00FFFFFF";
                    }
                    trackName: ParameterInsertion.insertParams("{0}. {1}", [index, name])
                    durationText: DurationConverter.convert(duration)
                    onClicked: if (true == true) {
                        appRoot.showPlayer(name, artistName, "Ã‚Â£0.99");
                        showHighlight(index);
                    }
                }
            }
        }

        ListHeader {
            id: recommendationsHeader

            visible: recommendationsList.visible
            headerText: "Ovi recommends"
            anchors.top: tracksListRule.verticalCenter
            anchors.topMargin: 1
        }

        HorizontalRule {
            id: tracksListRule

            visible: recommendationsList.visible
            anchors.top: tracksList.bottom
            anchors.topMargin: 0
            width: parent.width
        }

        ListView {
            id: recommendationsList

            visible: (recommendationsModel.count > 0) ? true : false
            anchors.top: recommendationsHeader.bottom
            height: childrenRect.height
            width: parent.width
            model: recommendationsModel
            delegate: recommendationsItem
            interactive: false

            Component {
                id: recommendationsItem

                ProductLink {
                    id: productLink
                    linkText1: name
                    linkText2: artistName
                    linkText3: (duration == "") ? trackCount + " tracks" : DurationConverter.convert(duration)
                    packshotUrl: albumArt100
                    onClicked: appRoot.switchView("Product.qml", "forward", dataProductID);
                    //onClicked: console.log(typeof artistName);
                }
            }

        }
    }
}
